@@ -49,6 +49,7 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <util/exit_codes.h>
 #include <util/options.h>
 #include <util/unicode.h>
+#include <util/version.h>
 
 #include <goto-analyzer/static_show_domain.h>
 #include <goto-analyzer/static_simplifier.h>
@@ -59,7 +60,7 @@ Author: Daniel Kroening, kroening@kroening.com
 janalyzer_parse_optionst::janalyzer_parse_optionst(int argc, const char **argv)
   : parse_options_baset(JANALYZER_OPTIONS, argc, argv),
     messaget(ui_message_handler),
-    ui_message_handler(cmdline, "JANALYZER " CBMC_VERSION)
+    ui_message_handler(cmdline, std::string("JANALYZER ") + CBMC_VERSION)
 {
 }
 
@@ -341,7 +342,7 @@ int janalyzer_parse_optionst::doit()
   //
   // Print a banner
   //
-  status() << "JANALYZER version " CBMC_VERSION " " << sizeof(void *) * 8
+  status() << "JANALYZER version " << CBMC_VERSION << " " << sizeof(void *) * 8
            << "-bit " << config.this_architecture() << " "
            << config.this_operating_system() << eom;
 
@@ -586,7 +587,7 @@ int janalyzer_parse_optionst::perform_analysis(const optionst &options)
     if(options.get_bool_option("show"))
     {
       result = static_show_domain(
-        goto_model, *analyzer, options, get_message_handler(), out);
+        goto_model, *analyzer, options, out);
     }
     else if(options.get_bool_option("verify"))
     {
@@ -601,17 +602,17 @@ int janalyzer_parse_optionst::perform_analysis(const optionst &options)
     else if(options.get_bool_option("unreachable-instructions"))
     {
       result = static_unreachable_instructions(
-        goto_model, *analyzer, options, get_message_handler(), out);
+        goto_model, *analyzer, options, out);
     }
     else if(options.get_bool_option("unreachable-functions"))
     {
       result = static_unreachable_functions(
-        goto_model, *analyzer, options, get_message_handler(), out);
+        goto_model, *analyzer, options, out);
     }
     else if(options.get_bool_option("reachable-functions"))
     {
       result = static_reachable_functions(
-        goto_model, *analyzer, options, get_message_handler(), out);
+        goto_model, *analyzer, options, out);
     }
     else
     {
@@ -668,9 +669,9 @@ bool janalyzer_parse_optionst::process_goto_program(const optionst &options)
     remove_virtual_functions(goto_model);
     // remove Java throw and catch
     // This introduces instanceof, so order is important:
-    remove_exceptions(goto_model);
+    remove_exceptions(goto_model, get_message_handler());
     // remove rtti
-    remove_instanceof(goto_model);
+    remove_instanceof(goto_model, get_message_handler());
 
     // do partial inlining
     status() << "Partial Inlining" << eom;
