@@ -39,11 +39,13 @@ public:
     bool throw_assertion_error,
     optionalt<ci_lazy_methods_neededt> needed_lazy_methods,
     java_string_library_preprocesst &_string_preprocess,
-    const class_hierarchyt &class_hierarchy)
+    const class_hierarchyt &class_hierarchy,
+    bool threading_support)
     : messaget(_message_handler),
       symbol_table(symbol_table),
       max_array_length(_max_array_length),
       throw_assertion_error(throw_assertion_error),
+      threading_support(threading_support),
       needed_lazy_methods(std::move(needed_lazy_methods)),
       string_preprocess(_string_preprocess),
       slots_for_parameters(0),
@@ -67,6 +69,7 @@ protected:
   symbol_table_baset &symbol_table;
   const size_t max_array_length;
   const bool throw_assertion_error;
+  const bool threading_support;
   optionalt<ci_lazy_methods_neededt> needed_lazy_methods;
 
   /// Fully qualified name of the method under translation.
@@ -265,8 +268,6 @@ protected:
 
   codet convert_instructions(
     const methodt &,
-    const code_typet &,
-    const irep_idt &,
     const java_class_typet::java_lambda_method_handlest &);
 
   const bytecode_infot &get_bytecode_info(const irep_idt &statement);
@@ -420,14 +421,6 @@ protected:
     codet &c,
     exprt::operandst &results);
 
-  codet convert_monitorenter(
-    const source_locationt &location,
-    const exprt::operandst &op) const;
-
-  codet convert_monitorexit(
-    const source_locationt &location,
-    const exprt::operandst &op) const;
-
   codet &do_exception_handling(
     const methodt &method,
     const std::set<unsigned int> &working_set,
@@ -446,6 +439,11 @@ protected:
     codet &c,
     exprt::operandst &results) const;
 
+  codet convert_monitorenterexit(
+    const irep_idt &statement,
+    const exprt::operandst &op,
+    const source_locationt &source_location);
+
   codet &replace_call_to_cprover_assume(source_locationt location, codet &c);
 
   void convert_invoke(
