@@ -122,10 +122,10 @@ codet java_bytecode_instrumentt::throw_exception(
       ID_java,
       symbol_table);
 
-  side_effect_exprt new_instance(ID_java_new, exc_ptr_type);
+  side_effect_exprt new_instance(ID_java_new, exc_ptr_type, original_loc);
   code_assignt assign_new(new_symbol.symbol_expr(), new_instance);
 
-  side_effect_expr_throwt throw_expr;
+  side_effect_expr_throwt throw_expr(irept(), typet(), original_loc);
   throw_expr.copy_to_operands(new_symbol.symbol_expr());
 
   code_blockt throw_code;
@@ -446,8 +446,8 @@ void java_bytecode_instrumentt::instrument_code(codet &code)
     add_expr_instrumentation(block, code_function_call.lhs());
     add_expr_instrumentation(block, code_function_call.function());
 
-    const code_typet &function_type=
-      to_code_type(code_function_call.function().type());
+    const java_method_typet &function_type =
+      to_java_method_type(code_function_call.function().type());
 
     // Check for a null this-argument of a virtual call:
     if(function_type.has_this())
@@ -604,13 +604,14 @@ void java_bytecode_instrument_uncaught_exceptions(
   const source_locationt &source_location)
 {
   // check that there is no uncaught exception
-  code_assertt assert_no_exception;
-  assert_no_exception.assertion() = equal_exprt(
+  code_assertt assert_no_exception(equal_exprt(
     exc_symbol.symbol_expr(),
-    null_pointer_exprt(to_pointer_type(exc_symbol.type)));
+    null_pointer_exprt(to_pointer_type(exc_symbol.type))));
+
   source_locationt assert_location = source_location;
   assert_location.set_comment("no uncaught exception");
   assert_no_exception.add_source_location() = assert_location;
+
   init_code.move_to_operands(assert_no_exception);
 }
 
