@@ -22,9 +22,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include <goto-programs/class_hierarchy.h>
 
+#include "java_bytecode_concurrency_instrumentation.h"
 #include "java_bytecode_convert_class.h"
 #include "java_bytecode_convert_method.h"
-#include "java_bytecode_convert_threadblock.h"
 #include "java_bytecode_internal_additions.h"
 #include "java_bytecode_instrument.h"
 #include "java_bytecode_typecheck.h"
@@ -37,6 +37,7 @@ Author: Daniel Kroening, kroening@kroening.com
 #include "ci_lazy_methods.h"
 
 #include "expr2java.h"
+#include "load_method_by_regex.h"
 
 /// Consume options that are java bytecode specific.
 /// \param Command:line options
@@ -44,31 +45,54 @@ Author: Daniel Kroening, kroening@kroening.com
 void java_bytecode_languaget::get_language_options(const cmdlinet &cmd)
 {
   assume_inputs_non_null=cmd.isset("java-assume-inputs-non-null");
-  string_refinement_enabled=cmd.isset("refine-strings");
-  throw_runtime_exceptions=cmd.isset("java-throw-runtime-exceptions");
+  string_refinement_enabled = !cmd.isset("no-refine-strings");
+  throw_runtime_exceptions =
+    cmd.isset("java-throw-runtime-exceptions") || // will go away
+    cmd.isset("throw-runtime-exceptions");
   assert_uncaught_exceptions = !cmd.isset("disable-uncaught-exception-check");
   throw_assertion_error = cmd.isset("throw-assertion-error");
   threading_support = cmd.isset("java-threading");
 
-  if(cmd.isset("java-max-input-array-length"))
-    object_factory_parameters.max_nondet_array_length=
-      std::stoi(cmd.get_value("java-max-input-array-length"));
-  if(cmd.isset("java-max-input-tree-depth"))
-    object_factory_parameters.max_nondet_tree_depth=
-      std::stoi(cmd.get_value("java-max-input-tree-depth"));
-  if(cmd.isset("string-max-input-length"))
-    object_factory_parameters.max_nondet_string_length=
-      std::stoi(cmd.get_value("string-max-input-length"));
-  else if(cmd.isset("string-max-length"))
+  if(cmd.isset("java-max-input-array-length")) // will go away
+  {
+    object_factory_parameters.max_nondet_array_length =
+      safe_string2size_t(cmd.get_value("java-max-input-array-length"));
+  }
+  if(cmd.isset("max-nondet-array-length"))
+  {
+    object_factory_parameters.max_nondet_array_length =
+      safe_string2size_t(cmd.get_value("max-nondet-array-length"));
+  }
+
+  if(cmd.isset("java-max-input-tree-depth")) // will go away
+  {
+    object_factory_parameters.max_nondet_tree_depth =
+      safe_string2size_t(cmd.get_value("java-max-input-tree-depth"));
+  }
+  if(cmd.isset("max-nondet-tree-depth"))
+  {
+    object_factory_parameters.max_nondet_tree_depth =
+      safe_string2size_t(cmd.get_value("max-nondet-tree-depth"));
+  }
+
+  if(cmd.isset("string-max-input-length")) // will go away
+  {
     object_factory_parameters.max_nondet_string_length =
-      std::stoi(cmd.get_value("string-max-length"));
+      safe_string2size_t(cmd.get_value("string-max-input-length"));
+  }
+  if(cmd.isset("max-nondet-string-length"))
+  {
+    object_factory_parameters.max_nondet_string_length =
+      safe_string2size_t(cmd.get_value("max-nondet-string-length"));
+  }
 
   object_factory_parameters.string_printable = cmd.isset("string-printable");
   if(cmd.isset("java-max-vla-length"))
-    max_user_array_length=std::stoi(cmd.get_value("java-max-vla-length"));
+    max_user_array_length =
+      safe_string2size_t(cmd.get_value("java-max-vla-length"));
   if(cmd.isset("symex-driven-lazy-loading"))
     lazy_methods_mode=LAZY_METHODS_MODE_EXTERNAL_DRIVER;
-  else if(cmd.isset("lazy-methods"))
+  else if(!cmd.isset("no-lazy-methods"))
     lazy_methods_mode=LAZY_METHODS_MODE_CONTEXT_INSENSITIVE;
   else
     lazy_methods_mode=LAZY_METHODS_MODE_EAGER;
@@ -94,10 +118,11 @@ void java_bytecode_languaget::get_language_options(const cmdlinet &cmd)
 
   const std::list<std::string> &extra_entry_points=
     cmd.get_values("lazy-methods-extra-entry-point");
-  lazy_methods_extra_entry_points.insert(
-    lazy_methods_extra_entry_points.end(),
+  std::transform(
     extra_entry_points.begin(),
-    extra_entry_points.end());
+    extra_entry_points.end(),
+    std::back_inserter(extra_methods),
+    build_load_method_by_regex);
 
   if(cmd.isset("java-cp-include-files"))
   {
@@ -140,23 +165,23 @@ std::set<std::string> java_bytecode_languaget::extensions() const
   return { "class", "jar" };
 }
 
-void java_bytecode_languaget::modules_provided(std::set<std::string> &modules)
+void java_bytecode_languaget::modules_provided(std::set<std::string> &)
 {
   // modules.insert(translation_unit(parse_path));
 }
 
 /// ANSI-C preprocessing
 bool java_bytecode_languaget::preprocess(
-  std::istream &instream,
-  const std::string &path,
-  std::ostream &outstream)
+  std::istream &,
+  const std::string &,
+  std::ostream &)
 {
   // there is no preprocessing!
   return true;
 }
 
 bool java_bytecode_languaget::parse(
-  std::istream &instream,
+  std::istream &,
   const std::string &path)
 {
   PRECONDITION(language_options_initialized);
@@ -524,7 +549,6 @@ static void create_stub_global_symbols(
           get_inherited_component(
             class_id,
             component,
-            "java::" + id2string(parse_tree.parsed_class.name),
             symbol_table,
             class_hierarchy,
             true);
@@ -577,7 +601,7 @@ static void create_stub_global_symbols(
 
 bool java_bytecode_languaget::typecheck(
   symbol_tablet &symbol_table,
-  const std::string &module)
+  const std::string &)
 {
   PRECONDITION(language_options_initialized);
 
@@ -753,9 +777,12 @@ bool java_bytecode_languaget::typecheck(
   bool res = java_bytecode_typecheck(
     symbol_table, get_message_handler(), string_refinement_enabled);
 
-  // now instrument thread-blocks
+  // now instrument thread-blocks and synchronized methods.
   if(threading_support)
+  {
     convert_threadblock(symbol_table);
+    convert_synchronized_methods(symbol_table, get_message_handler());
+  }
 
   return res;
 }
@@ -815,7 +842,7 @@ bool java_bytecode_languaget::do_ci_lazy_method_conversion(
     symbol_table,
     main_class,
     main_jar_classes,
-    lazy_methods_extra_entry_points,
+    extra_methods,
     java_class_loader,
     java_load_classes,
     get_pointer_type_selector(),
@@ -840,7 +867,7 @@ const select_pointer_typet &
 void java_bytecode_languaget::methods_provided(
   std::unordered_set<irep_idt> &methods) const
 {
-  static std::string cprover_class_prefix = "java::org.cprover.CProver.";
+  const std::string cprover_class_prefix = "java::org.cprover.CProver.";
 
   // Add all string solver methods to map
   string_preprocess.get_all_function_names(methods);
@@ -1034,13 +1061,14 @@ bool java_bytecode_languaget::convert_single_method(
       throw_assertion_error,
       std::move(needed_lazy_methods),
       string_preprocess,
-      class_hierarchy);
+      class_hierarchy,
+      threading_support);
     return false;
   }
 
   // The return of an opaque function is a source of an otherwise invisible
   // instantiation, so here we ensure we've loaded the appropriate classes.
-  const code_typet function_type = to_code_type(symbol.type);
+  const java_method_typet function_type = to_java_method_type(symbol.type);
   if(
     const pointer_typet *pointer_return_type =
       type_try_dynamic_cast<pointer_typet>(function_type.return_type()))
@@ -1061,7 +1089,7 @@ bool java_bytecode_languaget::convert_single_method(
   return true;
 }
 
-bool java_bytecode_languaget::final(symbol_table_baset &symbol_table)
+bool java_bytecode_languaget::final(symbol_table_baset &)
 {
   PRECONDITION(language_options_initialized);
   return false;
