@@ -69,13 +69,15 @@ class java_object_factoryt
     const typet &target_type,
     allocation_typet alloc_type,
     size_t depth,
-    update_in_placet update_in_place);
+    update_in_placet update_in_place,
+    const source_locationt &location);
 
   void allocate_nondet_length_array(
     code_blockt &assignments,
     const exprt &lhs,
     const exprt &max_length_expr,
-    const typet &element_type);
+    const typet &element_type,
+    const source_locationt &location);
 
 public:
   java_object_factoryt(
@@ -102,7 +104,8 @@ public:
     code_blockt &assignments,
     const exprt &expr,
     size_t depth,
-    update_in_placet);
+    update_in_placet,
+    const source_locationt &location);
 
   void gen_nondet_init(
     code_blockt &assignments,
@@ -114,17 +117,18 @@ public:
     bool override_,
     const typet &override_type,
     size_t depth,
-    update_in_placet);
+    update_in_placet,
+    const source_locationt &location);
 
 private:
   void gen_nondet_pointer_init(
     code_blockt &assignments,
     const exprt &expr,
-    const irep_idt &class_identifier,
     allocation_typet alloc_type,
     const pointer_typet &pointer_type,
     size_t depth,
-    const update_in_placet &update_in_place);
+    const update_in_placet &update_in_place,
+    const source_locationt &location);
 
   void gen_nondet_struct_init(
     code_blockt &assignments,
@@ -135,13 +139,15 @@ private:
     allocation_typet alloc_type,
     const struct_typet &struct_type,
     size_t depth,
-    const update_in_placet &update_in_place);
+    const update_in_placet &update_in_place,
+    const source_locationt &location);
 
   symbol_exprt gen_nondet_subtype_pointer_init(
     code_blockt &assignments,
     allocation_typet alloc_type,
     const pointer_typet &substitute_pointer_type,
-    size_t depth);
+    size_t depth,
+    const source_locationt &location);
 };
 
 /// Generates code for allocating a dynamic object. This is used in
@@ -174,7 +180,8 @@ exprt allocate_dynamic_object(
   {
     INVARIANT(!object_size.is_nil(), "Size of Java objects should be known");
     // malloc expression
-    side_effect_exprt malloc_expr(ID_allocate, pointer_type(allocate_type));
+    side_effect_exprt malloc_expr(
+      ID_allocate, pointer_type(allocate_type), loc);
     malloc_expr.copy_to_operands(object_size);
     malloc_expr.copy_to_operands(false_exprt());
     // create a symbol for the malloc expression so we can initialize
@@ -372,7 +379,8 @@ void java_object_factoryt::gen_pointer_target_init(
   const typet &target_type,
   allocation_typet alloc_type,
   size_t depth,
-  update_in_placet update_in_place)
+  update_in_placet update_in_place,
+  const source_locationt &location)
 {
   PRECONDITION(expr.type().id()==ID_pointer);
   PRECONDITION(update_in_place!=update_in_placet::MAY_UPDATE_IN_PLACE);
@@ -383,10 +391,7 @@ void java_object_factoryt::gen_pointer_target_init(
        "java::array["))
   {
     gen_nondet_array_init(
-      assignments,
-      expr,
-      depth+1,
-      update_in_place);
+      assignments, expr, depth + 1, update_in_place, location);
   }
   else
   {
@@ -426,14 +431,15 @@ void java_object_factoryt::gen_pointer_target_init(
     gen_nondet_init(
       assignments,
       init_expr,
-      false,   // is_sub
-      "",      // class_identifier
-      false,   // skip_classid
+      false, // is_sub
+      "",    // class_identifier
+      false, // skip_classid
       alloc_type,
-      false,   // override
-      typet(), // override type immaterial
-      depth+1,
-      update_in_place);
+      false,
+      typet(),
+      depth + 1,
+      update_in_place,
+      location);
   }
 }
 
@@ -504,23 +510,28 @@ static mp_integer max_value(const typet &type)
 /// \return code allocation object and assigning `lhs`
 static codet make_allocate_code(const symbol_exprt &lhs, const exprt &size)
 {
-  side_effect_exprt alloc(ID_allocate, lhs.type());
+  side_effect_exprt alloc(ID_allocate, lhs.type(), lhs.source_location());
   alloc.copy_to_operands(size);
   alloc.copy_to_operands(false_exprt());
   return code_assignt(lhs, alloc);
 }
 
-/// Initialize a nondeterministic String structure
-/// \param obj: struct to initialize, must have been declared using
-///   code of the form:
-/// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-/// struct java.lang.String { struct \@java.lang.Object;
-///   int length; char *data; } tmp_object_factory$1;
-/// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+/// Check if a structure is a nondeterministic String structure, and if it is
+/// initialize its length and data fields.
+/// \param struct_expr [out]: struct that we may initialize
+/// \param code: block to add pre-requisite declarations (e.g. to allocate a
+///   data array)
 /// \param max_nondet_string_length: maximum length of strings to initialize
 /// \param loc: location in the source
+/// \param function_id: function ID to associate with auxiliary variables
 /// \param symbol_table: the symbol table
-/// \return code for initialization of the strings
+/// \param printable: if true, the nondet string must consist of printable
+///   characters only
+/// \return true if struct_expr's length and data fields have been set up,
+///         false if we took no action because struct_expr wasn't a CharSequence
+///         or didn't have the necessary fields.
+///
+/// The code produced is of the form:
 /// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 /// int tmp_object_factory$1;
 /// tmp_object_factory$1 = NONDET(int);
@@ -535,170 +546,125 @@ static codet make_allocate_code(const symbol_exprt &lhs, const exprt &size)
 ///   *string_data_pointer, *string_data_pointer);
 /// cprover_associate_length_to_array_func(
 ///   *string_data_pointer, tmp_object_factory);
-/// arg = { .@java.lang.Object={
-///   .@class_identifier=\"java::java.lang.String\", .@lock=false },
+///
+/// struct_expr is then adjusted to set
 ///   .length=tmp_object_factory,
-///   .data=*string_data_pointer };
+///   .data=*string_data_pointer
 /// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 /// Unit tests in `unit/java_bytecode/java_object_factory/` ensure
 /// it is the case.
-codet initialize_nondet_string_struct(
-  const exprt &obj,
+bool initialize_nondet_string_fields(
+  struct_exprt &struct_expr,
+  code_blockt &code,
   const std::size_t &max_nondet_string_length,
   const source_locationt &loc,
   const irep_idt &function_id,
   symbol_table_baset &symbol_table,
   bool printable)
 {
-  PRECONDITION(
-    java_string_library_preprocesst::implements_java_char_sequence(obj.type()));
+  if(!java_string_library_preprocesst::implements_java_char_sequence(
+       struct_expr.type()))
+  {
+    return false;
+  }
 
-  const namespacet ns(symbol_table);
-  code_blockt code;
+  namespacet ns(symbol_table);
+
+  const struct_typet &struct_type =
+    to_struct_type(ns.follow(struct_expr.type()));
+
+  // In case the type for String was not added to the symbol table,
+  // (typically when string refinement is not activated), `struct_type`
+  // just contains the standard Object fields (or may have some other model
+  // entirely), and in particular has no length and data fields.
+  if(!struct_type.has_component("length") || !struct_type.has_component("data"))
+    return false;
 
-  // `obj` is `*expr`
-  const struct_typet &struct_type = to_struct_type(ns.follow(obj.type()));
-  // @clsid = java::java.lang.String or similar.
   // We allow type StringBuffer and StringBuilder to be initialized
   // in the same way has String, because they have the same structure and
   // are treated in the same way by CBMC.
+
   // Note that CharSequence cannot be used as classid because it's abstract,
   // so it is replaced by String.
   // \todo allow StringBuffer and StringBuilder as classid for Charsequence
-  const irep_idt &class_id =
-    struct_type.get_tag() == "java.lang.CharSequence"
-    ? "java::java.lang.String"
-    : "java::" + id2string(struct_type.get_tag());
-
-  // @lock = false:
-  const symbol_typet jlo_symbol("java::java.lang.Object");
-  const struct_typet &jlo_type = to_struct_type(ns.follow(jlo_symbol));
-  struct_exprt jlo_init(jlo_symbol);
-  java_root_class_init(jlo_init, jlo_type, false, class_id);
-
-  struct_exprt struct_expr(obj.type());
-  struct_expr.copy_to_operands(jlo_init);
-
-  // In case the type for string was not added to the symbol table,
-  // (typically when string refinement is not activated), `struct_type`
-  // just contains the standard Object field and no length and data fields.
-  if(struct_type.has_component("length"))
+  if(struct_type.get_tag() == "java.lang.CharSequence")
   {
-    /// \todo Refactor with make_nondet_string_expr
-    // length_expr = nondet(int);
-    const symbolt length_sym = get_fresh_aux_symbol(
-      java_int_type(),
-      id2string(function_id),
-      "tmp_object_factory",
-      loc,
-      ID_java,
-      symbol_table);
-    const symbol_exprt length_expr = length_sym.symbol_expr();
-    const side_effect_expr_nondett nondet_length(length_expr.type());
-    code.add(code_declt(length_expr));
-    code.add(code_assignt(length_expr, nondet_length));
-
-    // assume (length_expr >= 0);
-    code.add(
-      code_assumet(
-        binary_relation_exprt(
-          length_expr, ID_ge, from_integer(0, java_int_type()))));
-
-    // assume (length_expr <= max_input_length)
-    if(max_nondet_string_length <= max_value(length_expr.type()))
-    {
-      exprt max_length =
-        from_integer(max_nondet_string_length, length_expr.type());
-      code.add(
-        code_assumet(binary_relation_exprt(length_expr, ID_le, max_length)));
-    }
-
-    // char (*array_data_init)[INFINITY];
-    const typet data_ptr_type = pointer_type(
-      array_typet(java_char_type(), infinity_exprt(java_int_type())));
-
-    symbolt &data_pointer_sym = get_fresh_aux_symbol(
-      data_ptr_type, "", "string_data_pointer", loc, ID_java, symbol_table);
-    const auto data_pointer = data_pointer_sym.symbol_expr();
-    code.add(code_declt(data_pointer));
-
-    // Dynamic allocation: `data array = allocate char[INFINITY]`
-    code.add(make_allocate_code(data_pointer, infinity_exprt(java_int_type())));
-
-    // `data_expr` is `*data_pointer`
-    // data_expr = nondet(char[INFINITY]) // we use infinity for variable size
-    const dereference_exprt data_expr(data_pointer);
-    const exprt nondet_array =
-      make_nondet_infinite_char_array(symbol_table, loc, function_id, code);
-    code.add(code_assignt(data_expr, nondet_array));
-
-    struct_expr.copy_to_operands(length_expr);
-
-    const address_of_exprt array_pointer(
-      index_exprt(data_expr, from_integer(0, java_int_type())));
-
-    add_pointer_to_array_association(
-      array_pointer, data_expr, symbol_table, loc, code);
-
-    add_array_to_length_association(
-      data_expr, length_expr, symbol_table, loc, code);
-
-    struct_expr.copy_to_operands(array_pointer);
-
-    // Printable ASCII characters are between ' ' and '~'.
-    if(printable)
-    {
-      add_character_set_constraint(
-        array_pointer, length_expr, " -~", symbol_table, loc, code);
-    }
+    set_class_identifier(
+      struct_expr, ns, symbol_typet("java::java.lang.String"));
   }
 
-  // tmp_object = struct_expr;
-  code.add(code_assignt(obj, struct_expr));
-  return code;
-}
+  // OK, this is a String type with the expected fields -- add code to `code`
+  // to set up pre-requisite variables and assign them in `struct_expr`.
 
-/// Add code for the initialization of a string using a nondeterministic
-/// content and association of its address to the pointer `expr`.
-/// \param expr: pointer to be affected
-/// \param max_nondet_string_length: maximum length of strings to initialize
-/// \param printable: Boolean, true to force content to be printable
-/// \param symbol_table: the symbol table
-/// \param loc: location in the source
-/// \param [out] code: code block in which initialization code is added
-/// \return false if code was added, true to signal an error when the given
-///         object does not implement CharSequence or does not have data and
-///         length fields, in which case it should be initialized another way.
-static bool add_nondet_string_pointer_initialization(
-  const exprt &expr,
-  const std::size_t &max_nondet_string_length,
-  bool printable,
-  symbol_table_baset &symbol_table,
-  const source_locationt &loc,
-  const irep_idt &function_id,
-  code_blockt &code)
-{
-  const namespacet ns(symbol_table);
-  const dereference_exprt obj(expr, expr.type().subtype());
-  const struct_typet &struct_type =
-    to_struct_type(ns.follow(to_symbol_type(obj.type())));
-
-  // if no String model is loaded then we cannot construct a String object
-  if(struct_type.get_bool(ID_incomplete_class))
-    return true;
-
-  const exprt malloc_site = allocate_dynamic_object_with_decl(
-    expr, symbol_table, loc, function_id, code);
+  /// \todo Refactor with make_nondet_string_expr
+  // length_expr = nondet(int);
+  const symbolt length_sym = get_fresh_aux_symbol(
+    java_int_type(),
+    id2string(function_id),
+    "tmp_object_factory",
+    loc,
+    ID_java,
+    symbol_table);
+  const symbol_exprt length_expr = length_sym.symbol_expr();
+  const side_effect_expr_nondett nondet_length(length_expr.type(), loc);
+  code.add(code_declt(length_expr));
+  code.add(code_assignt(length_expr, nondet_length));
 
+  // assume (length_expr >= 0);
   code.add(
-    initialize_nondet_string_struct(
-      dereference_exprt(malloc_site, struct_type),
-      max_nondet_string_length,
-      loc,
-      function_id,
-      symbol_table,
-      printable));
-  return false;
+    code_assumet(
+      binary_relation_exprt(
+        length_expr, ID_ge, from_integer(0, java_int_type()))));
+
+  // assume (length_expr <= max_input_length)
+  if(max_nondet_string_length <= max_value(length_expr.type()))
+  {
+    exprt max_length =
+      from_integer(max_nondet_string_length, length_expr.type());
+    code.add(
+      code_assumet(binary_relation_exprt(length_expr, ID_le, max_length)));
+  }
+
+  // char (*array_data_init)[INFINITY];
+  const typet data_ptr_type = pointer_type(
+    array_typet(java_char_type(), infinity_exprt(java_int_type())));
+
+  symbolt &data_pointer_sym = get_fresh_aux_symbol(
+    data_ptr_type, "", "string_data_pointer", loc, ID_java, symbol_table);
+  const auto data_pointer = data_pointer_sym.symbol_expr();
+  code.add(code_declt(data_pointer));
+
+  // Dynamic allocation: `data array = allocate char[INFINITY]`
+  code.add(make_allocate_code(data_pointer, infinity_exprt(java_int_type())));
+
+  // `data_expr` is `*data_pointer`
+  // data_expr = nondet(char[INFINITY]) // we use infinity for variable size
+  const dereference_exprt data_expr(data_pointer);
+  const exprt nondet_array =
+    make_nondet_infinite_char_array(symbol_table, loc, function_id, code);
+  code.add(code_assignt(data_expr, nondet_array));
+
+  struct_expr.operands()[struct_type.component_number("length")] = length_expr;
+
+  const address_of_exprt array_pointer(
+    index_exprt(data_expr, from_integer(0, java_int_type())));
+
+  add_pointer_to_array_association(
+    array_pointer, data_expr, symbol_table, loc, code);
+
+  add_array_to_length_association(
+    data_expr, length_expr, symbol_table, loc, code);
+
+  struct_expr.operands()[struct_type.component_number("data")] = array_pointer;
+
+  // Printable ASCII characters are between ' ' and '~'.
+  if(printable)
+  {
+    add_character_set_constraint(
+      array_pointer, length_expr, " -~", symbol_table, loc, code);
+  }
+
+  return true;
 }
 
 /// Initializes a pointer \p expr of type \p pointer_type to a primitive-typed
@@ -710,9 +676,6 @@ static bool add_nondet_string_pointer_initialization(
 ///   The code block we are building with initialization code.
 /// \param expr:
 ///   Pointer-typed lvalue expression to initialize.
-/// \param class_identifier:
-///   Name of the parent class. Used to initialize the `@class_identifier` among
-///   others.
 /// \param alloc_type:
 ///   Allocation type (global, local or dynamic)
 /// \param depth:
@@ -728,11 +691,11 @@ static bool add_nondet_string_pointer_initialization(
 void java_object_factoryt::gen_nondet_pointer_init(
   code_blockt &assignments,
   const exprt &expr,
-  const irep_idt &class_identifier,
   allocation_typet alloc_type,
   const pointer_typet &pointer_type,
   size_t depth,
-  const update_in_placet &update_in_place)
+  const update_in_placet &update_in_place,
+  const source_locationt &location)
 {
   PRECONDITION(expr.type().id()==ID_pointer);
   const pointer_typet &replacement_pointer_type =
@@ -754,7 +717,7 @@ void java_object_factoryt::gen_nondet_pointer_init(
       replacement_pointer_type, ns.follow(replacement_pointer_type.subtype()));
 
     const symbol_exprt real_pointer_symbol = gen_nondet_subtype_pointer_init(
-      assignments, alloc_type, replacement_pointer_type, depth);
+      assignments, alloc_type, replacement_pointer_type, depth, location);
 
     // Having created a pointer to object of type replacement_pointer_type
     // we now assign it back to the original pointer with a cast
@@ -816,7 +779,8 @@ void java_object_factoryt::gen_nondet_pointer_init(
       subtype,
       alloc_type,
       depth,
-      update_in_placet::MUST_UPDATE_IN_PLACE);
+      update_in_placet::MUST_UPDATE_IN_PLACE,
+      location);
   }
 
   // if we MUST_UPDATE_IN_PLACE, then the job is done, we copy the code emitted
@@ -832,35 +796,14 @@ void java_object_factoryt::gen_nondet_pointer_init(
   // and asign to `expr` the address of such object
   code_blockt non_null_inst;
 
-  // Note string-type-specific initialization might fail, e.g. if java.lang.CharSequence does not
-  // have the expected fields (typically this happens if --refine-strings was not passed). In this
-  // case we fall back to normal pointer target init.
-  bool string_init_succeeded = false;
-
-  if(java_string_library_preprocesst::implements_java_char_sequence_pointer(
-       expr.type()))
-  {
-    string_init_succeeded =
-      !add_nondet_string_pointer_initialization(
-        expr,
-        object_factory_parameters.max_nondet_string_length,
-        object_factory_parameters.string_printable,
-        symbol_table,
-        loc,
-        object_factory_parameters.function_id,
-        assignments);
-  }
-
-  if(!string_init_succeeded)
-  {
-    gen_pointer_target_init(
-      non_null_inst,
-      expr,
-      subtype,
-      alloc_type,
-      depth,
-      update_in_placet::NO_UPDATE_IN_PLACE);
-  }
+  gen_pointer_target_init(
+    non_null_inst,
+    expr,
+    subtype,
+    alloc_type,
+    depth,
+    update_in_placet::NO_UPDATE_IN_PLACE,
+    location);
 
   auto set_null_inst=get_null_assignment(expr, pointer_type);
 
@@ -895,7 +838,7 @@ void java_object_factoryt::gen_nondet_pointer_init(
     //             tmp$<temporary_counter>>
     // }
     code_ifthenelset null_check;
-    null_check.cond()=side_effect_expr_nondett(bool_typet());
+    null_check.cond() = side_effect_expr_nondett(bool_typet(), location);
     null_check.then_case()=set_null_inst;
     null_check.else_case()=non_null_inst;
 
@@ -914,7 +857,8 @@ void java_object_factoryt::gen_nondet_pointer_init(
       "No-update and must-update should have already been resolved");
 
     code_ifthenelset update_check;
-    update_check.cond()=side_effect_expr_nondett(bool_typet());
+    update_check.cond() =
+      side_effect_expr_nondett(bool_typet(), expr.source_location());
     update_check.then_case()=update_in_place_assignments;
     update_check.else_case()=new_object_assignments;
 
@@ -950,7 +894,8 @@ symbol_exprt java_object_factoryt::gen_nondet_subtype_pointer_init(
   code_blockt &assignments,
   allocation_typet alloc_type,
   const pointer_typet &replacement_pointer,
-  size_t depth)
+  size_t depth,
+  const source_locationt &location)
 {
   symbolt new_symbol = get_fresh_aux_symbol(
     replacement_pointer,
@@ -964,14 +909,15 @@ symbol_exprt java_object_factoryt::gen_nondet_subtype_pointer_init(
   gen_nondet_init(
     assignments,
     new_symbol.symbol_expr(),
-    false,   // is_sub
-    "",      // class_identifier
-    false,   // skip_classid
+    false, // is_sub
+    "",    // class_identifier
+    false, // skip_classid
     alloc_type,
     false,   // override
     typet(), // override_type
     depth,
-    update_in_placet::NO_UPDATE_IN_PLACE);
+    update_in_placet::NO_UPDATE_IN_PLACE,
+    location);
 
   return new_symbol.symbol_expr();
 }
@@ -1014,7 +960,8 @@ void java_object_factoryt::gen_nondet_struct_init(
   allocation_typet alloc_type,
   const struct_typet &struct_type,
   size_t depth,
-  const update_in_placet &update_in_place)
+  const update_in_placet &update_in_place,
+  const source_locationt &location)
 {
   PRECONDITION(ns.follow(expr.type()).id()==ID_struct);
   PRECONDITION(struct_type.id()==ID_struct);
@@ -1031,6 +978,8 @@ void java_object_factoryt::gen_nondet_struct_init(
   //   case they will set `skip_classid`
   // * Not if we're re-initializing an existing object (i.e. update_in_place)
 
+  bool skip_special_string_fields = false;
+
   if(!is_sub &&
      !skip_classid &&
      update_in_place != update_in_placet::MUST_UPDATE_IN_PLACE)
@@ -1043,15 +992,28 @@ void java_object_factoryt::gen_nondet_struct_init(
 
     // This code mirrors the `remove_java_new` pass:
     null_message_handlert nullout;
-    exprt zero_object=
+    exprt initial_object =
       zero_initializer(
         struct_type, source_locationt(), ns, nullout);
     irep_idt qualified_clsid = "java::" + id2string(class_identifier);
     set_class_identifier(
-      to_struct_expr(zero_object), ns, symbol_typet(qualified_clsid));
+      to_struct_expr(initial_object), ns, symbol_typet(qualified_clsid));
+
+    // If the initialised type is a special-cased String type (one with length
+    // and data fields introduced by string-library preprocessing), initialise
+    // those fields with nondet values:
+    skip_special_string_fields =
+      initialize_nondet_string_fields(
+        to_struct_expr(initial_object),
+        assignments,
+        object_factory_parameters.max_nondet_string_length,
+        loc,
+        object_factory_parameters.function_id,
+        symbol_table,
+        object_factory_parameters.string_printable);
 
     assignments.copy_to_operands(
-      code_assignt(expr, zero_object));
+      code_assignt(expr, initial_object));
   }
 
   for(const auto &component : components)
@@ -1065,8 +1027,22 @@ void java_object_factoryt::gen_nondet_struct_init(
     {
       continue;
     }
-    else if(name=="@lock")
+    else if(name == "cproverMonitorCount")
     {
+      // Zero-initialize 'cproverMonitorCount' field as it is not meant to be
+      // nondet. This field is only present when the java core models are
+      // included in the class-path. It is used to implement a critical section,
+      // which is necessary to support concurrency.
+      if(update_in_place == update_in_placet::MUST_UPDATE_IN_PLACE)
+        continue;
+      code_assignt code(me, from_integer(0, me.type()));
+      code.add_source_location() = loc;
+      assignments.copy_to_operands(code);
+    }
+    else if(skip_special_string_fields && (name == "length" || name == "data"))
+    {
+      // In this case these were set up by initialise_nondet_string_fields
+      // above.
       continue;
     }
     else
@@ -1087,12 +1063,13 @@ void java_object_factoryt::gen_nondet_struct_init(
         me,
         _is_sub,
         class_identifier,
-        false,   // skip_classid
+        false, // skip_classid
         alloc_type,
         false,   // override
         typet(), // override_type
         depth,
-        substruct_in_place);
+        substruct_in_place,
+        location);
     }
   }
 
@@ -1107,7 +1084,7 @@ void java_object_factoryt::gen_nondet_struct_init(
 
   if(const auto func = symbol_table.lookup(init_method_name))
   {
-    const code_typet &type = to_code_type(func->type);
+    const java_method_typet &type = to_java_method_type(func->type);
     code_function_callt fun_call;
     fun_call.function() = func->symbol_expr();
     if(type.has_this())
@@ -1160,7 +1137,8 @@ void java_object_factoryt::gen_nondet_init(
   bool override_,
   const typet &override_type,
   size_t depth,
-  update_in_placet update_in_place)
+  update_in_placet update_in_place,
+  const source_locationt &location)
 {
   const typet &type=
     override_ ? ns.follow(override_type) : ns.follow(expr.type());
@@ -1182,11 +1160,11 @@ void java_object_factoryt::gen_nondet_init(
     gen_nondet_pointer_init(
       assignments,
       expr,
-      class_identifier,
       alloc_type,
       pointer_type,
       depth,
-      update_in_place);
+      update_in_place,
+      location);
   }
   else if(type.id()==ID_struct)
   {
@@ -1215,15 +1193,15 @@ void java_object_factoryt::gen_nondet_init(
       alloc_type,
       struct_type,
       depth,
-      update_in_place);
+      update_in_place,
+      location);
   }
   else
   {
     // types different from pointer or structure:
     // bool, int, float, byte, char, ...
-    exprt rhs=type.id()==ID_c_bool?
-      get_nondet_bool(type):
-      side_effect_expr_nondett(type);
+    exprt rhs = type.id() == ID_c_bool ? get_nondet_bool(type)
+                                       : side_effect_expr_nondett(type, loc);
     code_assignt assign(expr, rhs);
     assign.add_source_location()=loc;
 
@@ -1248,7 +1226,8 @@ void java_object_factoryt::allocate_nondet_length_array(
   code_blockt &assignments,
   const exprt &lhs,
   const exprt &max_length_expr,
-  const typet &element_type)
+  const typet &element_type,
+  const source_locationt &location)
 {
   symbolt &length_sym = get_fresh_aux_symbol(
     java_int_type(),
@@ -1271,7 +1250,8 @@ void java_object_factoryt::allocate_nondet_length_array(
     false,                   // override
     typet(),                 // override type is immaterial
     0,                       // depth is immaterial, always non-null
-    update_in_placet::NO_UPDATE_IN_PLACE);
+    update_in_placet::NO_UPDATE_IN_PLACE,
+    location);
 
   // Insert assumptions to bound its length:
   binary_relation_exprt
@@ -1283,10 +1263,10 @@ void java_object_factoryt::allocate_nondet_length_array(
   assignments.move_to_operands(assume_inst1);
   assignments.move_to_operands(assume_inst2);
 
-  side_effect_exprt java_new_array(ID_java_new_array, lhs.type());
+  side_effect_exprt java_new_array(ID_java_new_array, lhs.type(), loc);
   java_new_array.copy_to_operands(length_sym_expr);
   java_new_array.set(ID_length_upper_bound, max_length_expr);
-  java_new_array.type().subtype().set(ID_C_element_type, element_type);
+  java_new_array.type().subtype().set(ID_element_type, element_type);
   code_assignt assign(lhs, java_new_array);
   assign.add_source_location()=loc;
   assignments.copy_to_operands(assign);
@@ -1302,7 +1282,8 @@ void java_object_factoryt::gen_nondet_array_init(
   code_blockt &assignments,
   const exprt &expr,
   size_t depth,
-  update_in_placet update_in_place)
+  update_in_placet update_in_place,
+  const source_locationt &location)
 {
   PRECONDITION(expr.type().id()==ID_pointer);
   PRECONDITION(expr.type().subtype().id()==ID_symbol);
@@ -1310,8 +1291,8 @@ void java_object_factoryt::gen_nondet_array_init(
 
   const typet &type=ns.follow(expr.type().subtype());
   const struct_typet &struct_type=to_struct_type(type);
-  const typet &element_type=
-    static_cast<const typet &>(expr.type().subtype().find(ID_C_element_type));
+  const typet &element_type =
+    static_cast<const typet &>(expr.type().subtype().find(ID_element_type));
 
   auto max_length_expr=from_integer(
     object_factory_parameters.max_nondet_array_length, java_int_type());
@@ -1321,10 +1302,7 @@ void java_object_factoryt::gen_nondet_array_init(
   if(update_in_place==update_in_placet::NO_UPDATE_IN_PLACE)
   {
     allocate_nondet_length_array(
-      assignments,
-      expr,
-      max_length_expr,
-      element_type);
+      assignments, expr, max_length_expr, element_type, location);
   }
 
   // Otherwise we're updating the array in place, and use the
@@ -1414,15 +1392,16 @@ void java_object_factoryt::gen_nondet_array_init(
   gen_nondet_init(
     assignments,
     arraycellref,
-    false, // is_sub
+    false,      // is_sub
     irep_idt(), // class_identifier
-    false, // skip_classid
+    false,      // skip_classid
     // These are variable in number, so use dynamic allocator:
     allocation_typet::DYNAMIC,
-    true,  // override
+    true, // override
     element_type,
     depth,
-    child_update_in_place);
+    child_update_in_place,
+    location);
 
   exprt java_one=from_integer(1, java_int_type());
   code_assignt incr(counter_expr, plus_exprt(counter_expr, java_one));
@@ -1513,7 +1492,8 @@ exprt object_factory(
     false,   // override
     typet(), // override_type is immaterial
     1,       // initial depth
-    update_in_placet::NO_UPDATE_IN_PLACE);
+    update_in_placet::NO_UPDATE_IN_PLACE,
+    loc);
 
   declare_created_symbols(symbols_created, loc, init_code);
 
@@ -1586,7 +1566,8 @@ void gen_nondet_init(
     false,   // override
     typet(), // override_type is immaterial
     1,       // initial depth
-    update_in_place);
+    update_in_place,
+    loc);
 
   declare_created_symbols(symbols_created, loc, init_code);
 
