@@ -88,10 +88,12 @@ public:
   explicit remove_exceptionst(
     symbol_table_baset &_symbol_table,
     function_may_throwt _function_may_throw,
-    bool remove_added_instanceof)
+    bool remove_added_instanceof,
+    message_handlert &message_handler)
     : symbol_table(_symbol_table),
       function_may_throw(_function_may_throw),
-      remove_added_instanceof(remove_added_instanceof)
+      remove_added_instanceof(remove_added_instanceof),
+      message_handler(message_handler)
   {
   }
 
@@ -102,6 +104,7 @@ protected:
   symbol_table_baset &symbol_table;
   function_may_throwt function_may_throw;
   bool remove_added_instanceof;
+  message_handlert &message_handler;
 
   symbol_exprt get_inflight_exception_global();
 
@@ -342,7 +345,7 @@ void remove_exceptionst::add_exception_dispatch_sequence(
         t_exc->guard=check;
 
         if(remove_added_instanceof)
-          remove_instanceof(t_exc, goto_program, symbol_table);
+          remove_instanceof(t_exc, goto_program, symbol_table, message_handler);
       }
     }
   }
@@ -574,6 +577,7 @@ void remove_exceptionst::operator()(goto_programt &goto_program)
 void remove_exceptions(
   symbol_table_baset &symbol_table,
   goto_functionst &goto_functions,
+  message_handlert &message_handler,
   remove_exceptions_typest type)
 {
   const namespacet ns(symbol_table);
@@ -586,7 +590,8 @@ void remove_exceptions(
   remove_exceptionst remove_exceptions(
     symbol_table,
     function_may_throw,
-    type == remove_exceptions_typest::REMOVE_ADDED_INSTANCEOF);
+    type == remove_exceptions_typest::REMOVE_ADDED_INSTANCEOF,
+    message_handler);
   remove_exceptions(goto_functions);
 }
 
@@ -600,26 +605,33 @@ void remove_exceptions(
 /// \param symbol_table: global symbol table. The `@inflight_exception` global
 ///   may be added if not already present. It will not be initialised; that is
 ///   the caller's responsibility.
+/// \param message_handler: logging output
 /// \param type: specifies whether instanceof operations generated by this pass
 ///   should be lowered to class-identifier comparisons (using
 ///   remove_instanceof).
 void remove_exceptions(
   goto_programt &goto_program,
   symbol_table_baset &symbol_table,
+  message_handlert &message_handler,
   remove_exceptions_typest type)
 {
   remove_exceptionst::function_may_throwt any_function_may_throw =
-    [](const irep_idt &id) { return true; };
+    [](const irep_idt &) { return true; };
 
   remove_exceptionst remove_exceptions(
     symbol_table,
     any_function_may_throw,
-    type == remove_exceptions_typest::REMOVE_ADDED_INSTANCEOF);
+    type == remove_exceptions_typest::REMOVE_ADDED_INSTANCEOF,
+    message_handler);
   remove_exceptions(goto_program);
 }
 
 /// removes throws/CATCH-POP/CATCH-PUSH
-void remove_exceptions(goto_modelt &goto_model, remove_exceptions_typest type)
+void remove_exceptions(
+  goto_modelt &goto_model,
+  message_handlert &message_handler,
+  remove_exceptions_typest type)
 {
-  remove_exceptions(goto_model.symbol_table, goto_model.goto_functions, type);
+  remove_exceptions(
+    goto_model.symbol_table, goto_model.goto_functions, message_handler, type);
 }
