@@ -20,6 +20,7 @@ Author: Peter Schrammel
 #include <util/exit_codes.h>
 #include <util/make_unique.h>
 #include <util/options.h>
+#include <util/version.h>
 
 #include <langapi/language.h>
 
@@ -63,7 +64,7 @@ Author: Peter Schrammel
 jdiff_parse_optionst::jdiff_parse_optionst(int argc, const char **argv)
   : parse_options_baset(JDIFF_OPTIONS, argc, argv),
     jdiff_languagest(cmdline, ui_message_handler),
-    ui_message_handler(cmdline, "JDIFF " CBMC_VERSION),
+    ui_message_handler(cmdline, std::string("JDIFF ") + CBMC_VERSION),
     languages2(cmdline, ui_message_handler)
 {
 }
@@ -74,7 +75,7 @@ jdiff_parse_optionst::jdiff_parse_optionst(int argc, const char **argv)
   const std::string &extra_options)
   : parse_options_baset(JDIFF_OPTIONS + extra_options, argc, argv),
     jdiff_languagest(cmdline, ui_message_handler),
-    ui_message_handler(cmdline, "JDIFF " CBMC_VERSION),
+    ui_message_handler(cmdline, std::string("JDIFF ") + CBMC_VERSION),
     languages2(cmdline, ui_message_handler)
 {
 }
@@ -87,6 +88,12 @@ void jdiff_parse_optionst::get_command_line_options(optionst &options)
     exit(1);
   }
 
+  // TODO: improve this when language front ends have been
+  //   disentangled from command line parsing
+  // we always require these options
+  cmdline.set("no-lazy-methods");
+  cmdline.set("no-refine-strings");
+
   if(cmdline.isset("cover"))
     parse_cover_options(cmdline, options);
 
@@ -199,8 +206,8 @@ int jdiff_parse_optionst::doit()
   //
   // Print a banner
   //
-  status() << "JDIFF version " CBMC_VERSION " " << sizeof(void *) * 8 << "-bit "
-           << config.this_architecture() << " "
+  status() << "JDIFF version " << CBMC_VERSION << " " << sizeof(void *) * 8
+           << "-bit " << config.this_architecture() << " "
            << config.this_operating_system() << eom;
 
   if(cmdline.args.size() != 2)
@@ -344,9 +351,9 @@ bool jdiff_parse_optionst::process_goto_program(
     // Java virtual functions -> explicit dispatch tables:
     remove_virtual_functions(goto_model);
     // remove catch and throw
-    remove_exceptions(goto_model);
+    remove_exceptions(goto_model, get_message_handler());
     // Java instanceof -> clsid comparison:
-    remove_instanceof(goto_model);
+    remove_instanceof(goto_model, get_message_handler());
 
     mm_io(goto_model);
 
