@@ -316,8 +316,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -345,8 +345,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 3);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 3);
 
     THEN("The inputs are of correct type")
     {
@@ -381,8 +381,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -412,8 +412,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -442,8 +442,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -476,8 +476,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -508,8 +508,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -544,8 +544,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -576,8 +576,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of the correct type")
     {
@@ -609,8 +609,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of the correct type")
     {
@@ -642,8 +642,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs should be of the correct type")
     {
@@ -672,8 +672,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -699,8 +699,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -729,8 +729,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -758,8 +758,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -790,8 +790,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -820,8 +820,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -854,8 +854,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -885,8 +885,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -917,8 +917,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
@@ -949,8 +949,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type should be correct")
     {
