@@ -417,8 +417,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -455,8 +455,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of oorrect type")
     {
@@ -493,8 +493,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -538,8 +538,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -583,8 +583,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs are of correct type")
     {
@@ -624,8 +624,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -665,8 +665,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -706,8 +706,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -751,8 +751,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -796,8 +796,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -841,8 +841,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -882,8 +882,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -929,8 +929,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 2);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 2);
 
     THEN("The inputs have correct type")
     {
@@ -976,8 +976,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1012,8 +1012,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1048,8 +1048,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1090,8 +1090,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1132,8 +1132,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1171,8 +1171,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1210,8 +1210,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1249,8 +1249,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1292,8 +1292,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1335,8 +1335,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1378,8 +1378,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1417,8 +1417,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
@@ -1462,8 +1462,8 @@ SCENARIO(
     const symbolt &function_symbol =
       new_symbol_table.lookup_ref(process_func_name);
 
-    const code_typet &function_call =
-      require_type::require_code(function_symbol.type, 1);
+    const java_method_typet &function_call =
+      require_type::require_java_method(function_symbol.type, 1);
 
     THEN("The return type is correct")
     {
