@@ -1,15 +1,19 @@
 #include <assert.h>
-#include <string.h> 
-void free(void *);
+#include <string.h>
+#include <stdlib.h>
 
 int main()
 {
-  char str[500]="Hello"; 
+  char str[500]="Hello";
 
   assert(strcmp(str, "Hello")==0);
-  assert(strncmp(str, "Hello", 5)==0); 
+  assert(strncmp(str, "Hello", 5)==0);
+
+  #ifndef _MSC_VER
   assert(strcasecmp(str, "HELLO")==0);
   assert(strncasecmp(str, "HELLO", 5)==0);
+  #endif
+
   assert(strcmp(str, "\xff")<0);
   assert(strncmp("ASDxx", "ASDyy", 3)==0);
 
