@@ -21,28 +21,12 @@ my $has_thread_pool = eval
 #
 # runs a test and check its output
 
-my $color_output_enabled;
-sub with_color {
-  my ($text, $color) = @_;
-  if ($color_output_enabled) {
-    colored($text, $color);
-  } else {
-    $text;
-  }
-}
-
 sub run($$$$$) {
   my ($name, $input, $cmd, $options, $output) = @_;
-  my $cmdline;
-  if(length($input)) {
-    $cmdline = "$cmd $options '$input' >'$output' 2>&1";
-  } else {
-    $cmdline = "$cmd $options >'$output' 2>&1";
-  }
+  my $cmdline = "$cmd $options '$input' >'$output' 2>&1";
 
   print LOG "Running $cmdline\n";
-  # see https://github.com/git-for-windows/msys2-runtime/pull/11/files
-  system("bash", "-c", "cd '$name' ; MSYS_NO_PATHCONV=1 $cmdline");
+  system("bash", "-c", "cd '$name' ; $cmdline");
   my $exit_value = $? >> 8;
   my $signal_num = $? & 127;
   my $dumped_core = $? & 128;
@@ -59,7 +43,10 @@ sub run($$$$$) {
     }
   }
 
-  system("bash", "-c", "cd '$name' ; echo '\nEXIT=$exit_value\nSIGNAL=$signal_num\n' >> '$output'");
+  open my $FH, ">>$name/$output";
+  print $FH "EXIT=$exit_value\n";
+  print $FH "SIGNAL=$signal_num\n";
+  close $FH;
 
   if($signal_num == 2) {
     print "\nProgram under test interrupted; stopping\n";
@@ -69,29 +56,24 @@ sub run($$$$$) {
   return $failed;
 }
 
-sub load($$) {
-  my ($fname, $exit_signal_checks) = @_;
+sub load($) {
+  my ($fname) = @_;
 
   open FILE, "<$fname";
   my @data = grep { !/^\/\// } <FILE>;
   close FILE;
 
-  s/\R$// for @data;
-  if($exit_signal_checks) {
-    grep { /^\^EXIT=[\(\|\d]*\d+\)?\$$/ } @data or die "$fname: Missing EXIT test\n";
-    grep { /^\^SIGNAL=\d+\$$/ } @data or die "$fname: Missing SIGNAL test\n";
-  }
+  chomp @data;
   return @data;
 }
 
-sub test($$$$$$$$$$$) {
-  my ($name, $test, $t_level, $cmd, $ign, $dry_run, $defines, $include_tags, $exclude_tags, $output_suffix, $exit_signal_checks) = @_;
-  my ($level_and_tags, $input, $options, $grep_options, @results) = load("$test", $exit_signal_checks);
+sub test($$$$$$$$$$) {
+  my ($name, $test, $t_level, $cmd, $ign, $dry_run, $defines, $include_tags, $exclude_tags, $output_suffix) = @_;
+  my ($level_and_tags, $input, $options, $grep_options, @results) = load("$test");
   my @keys = keys %{$defines};
   foreach my $key (@keys) {
     my $value = $defines->{$key};
     $options =~ s/(\$$key$|\$$key )/$value /g;
-    $options =~ s/\$$key([:;])/$value$1/g; # Variables in --classpath are separated by (semi)colons
   }
   if (scalar @keys) {
     foreach my $word (split(/\s/, $options)) {
@@ -139,9 +121,6 @@ sub test($$$$$$$$$$$) {
     $output .= "-";
     $output .= $output_suffix;
   }
-  if(our $opt_f) {
-    substr($options, 0, 0) = "$output "
-  }
   $output .= ".out";
 
   if($output eq $input) {
@@ -282,7 +261,6 @@ Usage: test.pl -c CMD [OPTIONS] [DIRECTORIES ...]
   the current location will be used.
 
   -c CMD     run tests on CMD - required option
-  -e         require EXIT and SIGNAL patterns in test specifications
   -i <regex> options in test.desc matching the specified perl regex are ignored
   -j <num>   run <num> tests in parallel (requires Thread::Pool::Simple)
              if present, the environment variable TESTPL_JOBS is used as the default
@@ -301,11 +279,6 @@ Usage: test.pl -c CMD [OPTIONS] [DIRECTORIES ...]
              testing of the same desc file with different commands or options,
              as runs with different suffixes will operate independently and keep
              independent logs.
-  -f         forward the test name to CMD
-
-  --[no]color enable/disable color output; enabled by default unless
-              TESTPL_COLOR_OUTPUT is set to 0, in which case it is
-              disabled by default.
 
 test.pl expects a test.desc file in each subdirectory. The file test.desc
 follows the format specified below. Any line starting with // will be ignored.
@@ -329,7 +302,6 @@ where
                                   case then each of the rules will be matched over multiple lines (so can contain)
                                   the new line symbol (\\n) inside them.
   <required patterns>             one or more lines of regualar expressions that must occur in the output
-                                  if -e is set, the patterns ^EXIT=...\$ and ^SIGNAL=...\$ are mandatory
   <disallowed patterns>           one or more lines of expressions that must not occur in output
   <comment text>                  free form text
 
@@ -341,17 +313,9 @@ use Getopt::Std;
 use Getopt::Long qw(:config pass_through bundling);
 $main::VERSION = 0.1;
 $Getopt::Std::STANDARD_HELP_VERSION = 1;
-our ($opt_c, $opt_e, $opt_f, $opt_i, $opt_j, $opt_n, $opt_p, $opt_h, $opt_C, $opt_T, $opt_F, $opt_K, $opt_s, $opt_S, %defines, @include_tags, @exclude_tags); # the variables for getopt
-
-# this needs to come before GetOptions to ensure the
-# default -> environment -> flag override priority
-$color_output_enabled = 1;
-if (exists $ENV{'TESTPL_COLOR_OUTPUT'}) {
-  $color_output_enabled = $ENV{'TESTPL_COLOR_OUTPUT'};
-}
-
-GetOptions("D=s" => \%defines, "X=s" => \@exclude_tags, "I=s" => \@include_tags, 'color!' => \$color_output_enabled);
-getopts('c:efi:j:nphCTFKs:S:') or &main::HELP_MESSAGE(\*STDOUT, "", $main::VERSION, "");
+our ($opt_c, $opt_i, $opt_j, $opt_n, $opt_p, $opt_h, $opt_C, $opt_T, $opt_F, $opt_K, $opt_s, %defines, @include_tags, @exclude_tags); # the variables for getopt
+GetOptions("D=s" => \%defines, "X=s" => \@exclude_tags, "I=s" => \@include_tags);
+getopts('c:i:j:nphCTFKs:') or &main::HELP_MESSAGE(\*STDOUT, "", $main::VERSION, "");
 $opt_c or &main::HELP_MESSAGE(\*STDOUT, "", $main::VERSION, "");
 $opt_j = $opt_j || $ENV{'TESTPL_JOBS'} || 0;
 if($opt_j && $opt_j != 1 && !$has_thread_pool) {
@@ -365,10 +329,8 @@ $t_level += 2 if($opt_T);
 $t_level += 4 if($opt_F);
 $t_level += 8 if($opt_K);
 $t_level += 1 if($opt_C || 0 == $t_level);
-
 my $dry_run = $opt_n;
 my $log_suffix = $opt_s;
-my $exit_signal_checks = defined($opt_e);
 
 my $logfile_name = "tests";
 if($log_suffix) {
@@ -403,7 +365,7 @@ sub do_test($)
     defined($pool) or print "  Running $files[$_]";
     my $start_time = time();
     $failed_skipped = test(
-      $test, $files[$_], $t_level, $opt_c, $opt_i, $dry_run, \%defines, \@include_tags, \@exclude_tags, $log_suffix, $exit_signal_checks);
+      $test, $files[$_], $t_level, $opt_c, $opt_i, $dry_run, \%defines, \@include_tags, \@exclude_tags, $log_suffix);
     my $runtime = time() - $start_time;
 
     lock($skips);
@@ -412,10 +374,10 @@ sub do_test($)
       $skips++;
       print "  [SKIPPED]\n";
     } elsif(0 == $failed_skipped) {
-      print "  [" . with_color("OK", "green") . "] in $runtime seconds\n";
+      print "  [" . colored("OK", "green") . "] in $runtime seconds\n";
     } else {
       $failures++;
-      print "  [" . with_color("FAILED", "red") . "]\n";
+      print "  [" . colored("FAILED", "red") . "]\n";
     }
   }
 }
@@ -453,9 +415,9 @@ defined($pool) and $pool->join();
 print "\n";
 
 if($failures == 0) {
-  print with_color("All tests were successful", "green");
+  print colored("All tests were successful", "green");
 } else {
-  print with_color("Tests failed", "red") . "\n";
+  print colored("Tests failed", "red") . "\n";
   print "  $failures of $count " . (1==$count?"test":"tests") . " failed";
 }
 print ", $skips " . (1==$skips?"test":"tests") . " skipped" if($skips > 0);
