@@ -16,11 +16,12 @@ Author: Peter Schrammel
 #include <util/format_expr.h>
 #endif
 
-#include <util/ieee_float.h>
-#include <util/find_symbols.h>
 #include <util/arith_tools.h>
-#include <util/simplify_expr.h>
+#include <util/base_type.h>
 #include <util/cprover_prefix.h>
+#include <util/find_symbols.h>
+#include <util/ieee_float.h>
+#include <util/simplify_expr.h>
 
 #include <langapi/language_util.h>
 
@@ -31,18 +32,27 @@ void constant_propagator_domaint::assign_rec(
   valuest &values,
   const exprt &lhs,
   const exprt &rhs,
-  const namespacet &ns)
+  const namespacet &ns,
+  const constant_propagator_ait *cp)
 {
   if(lhs.id()!=ID_symbol)
     return;
 
+  if(cp && !cp->should_track_value(lhs, ns))
+    return;
+
   const symbol_exprt &s=to_symbol_expr(lhs);
 
   exprt tmp=rhs;
   partial_evaluate(tmp, ns);
 
   if(tmp.is_constant())
+  {
+    DATA_INVARIANT(
+      base_type_eq(ns.lookup(s).type, tmp.type(), ns),
+      "type of constant to be replaced should match");
     values.set_to(s, tmp);
+  }
   else
     values.set_to_top(s);
 }
@@ -89,11 +99,11 @@ void constant_propagator_domaint::transform(
     const code_assignt &assignment=to_code_assign(from->code);
     const exprt &lhs=assignment.lhs();
     const exprt &rhs=assignment.rhs();
-    assign_rec(values, lhs, rhs, ns);
+    assign_rec(values, lhs, rhs, ns, cp);
   }
   else if(from->is_assume())
   {
-    two_way_propagate_rec(from->guard, ns);
+    two_way_propagate_rec(from->guard, ns, cp);
   }
   else if(from->is_goto())
   {
@@ -110,7 +120,7 @@ void constant_propagator_domaint::transform(
      values.set_to_bottom();
     else
     {
-      two_way_propagate_rec(g, ns);
+      two_way_propagate_rec(g, ns, cp);
       // If two way propagate is enabled then it may be possible to detect
       // that the branch condition is infeasible and thus the domain should
       // be set to bottom.  Without it the domain will only be set to bottom
@@ -175,7 +185,7 @@ void constant_propagator_domaint::transform(
             break;
 
           const symbol_exprt parameter_expr(p_it->get_identifier(), arg.type());
-          assign_rec(values, parameter_expr, arg, ns);
+          assign_rec(values, parameter_expr, arg, ns, cp);
 
           ++p_it;
         }
@@ -220,7 +230,8 @@ void constant_propagator_domaint::transform(
 /// handles equalities and conjunctions containing equalities
 bool constant_propagator_domaint::two_way_propagate_rec(
   const exprt &expr,
-  const namespacet &ns)
+  const namespacet &,
+  const constant_propagator_ait *cp)
 {
 #ifdef DEBUG
   std::cout << "two_way_propagate_rec: " << format(expr) << '\n';
@@ -238,7 +249,7 @@ bool constant_propagator_domaint::two_way_propagate_rec(
       change = false;
 
       forall_operands(it, expr)
-        if(two_way_propagate_rec(*it, ns))
+        if(two_way_propagate_rec(*it, ns, cp))
           change=true;
     }
     while(change);
@@ -253,7 +264,7 @@ bool constant_propagator_domaint::two_way_propagate_rec(
     assign_rec(copy_values, lhs, rhs, ns);
     if(!values.is_constant(rhs) || values.is_constant(lhs))
        assign_rec(values, rhs, lhs, ns);
-    change=values.meet(copy_values);
+    change = values.meet(copy_values, ns);
   }
 #endif
 
@@ -386,7 +397,7 @@ void constant_propagator_domaint::valuest::output(
 
 void constant_propagator_domaint::output(
   std::ostream &out,
-  const ai_baset &ai,
+  const ai_baset &,
   const namespacet &ns) const
 {
   values.output(out, ns);
@@ -464,7 +475,9 @@ bool constant_propagator_domaint::valuest::merge(const valuest &src)
 
 /// meet
 /// \return Return true if "this" has changed.
-bool constant_propagator_domaint::valuest::meet(const valuest &src)
+bool constant_propagator_domaint::valuest::meet(
+  const valuest &src,
+  const namespacet &ns)
 {
   if(src.is_bottom || is_bottom)
     return false;
@@ -487,6 +500,9 @@ bool constant_propagator_domaint::valuest::meet(const valuest &src)
     }
     else
     {
+      DATA_INVARIANT(
+        base_type_eq(ns.lookup(m.first).type, m.second.type(), ns),
+        "type of constant to be stored should match");
       set_to(m.first, m.second);
       changed=true;
     }
@@ -498,8 +514,8 @@ bool constant_propagator_domaint::valuest::meet(const valuest &src)
 /// \return Return true if "this" has changed.
 bool constant_propagator_domaint::merge(
   const constant_propagator_domaint &other,
-  locationt from,
-  locationt to)
+  locationt,
+  locationt)
 {
   return values.merge(other.values);
 }
@@ -587,43 +603,45 @@ void constant_propagator_ait::replace(
 {
   Forall_goto_program_instructions(it, goto_function.body)
   {
-    state_mapt::iterator s_it=state_map.find(it);
+    // Works because this is a location (but not history) sensitive domain
+    const constant_propagator_domaint &d = (*this)[it];
 
-    if(s_it==state_map.end())
+    if(d.is_bottom())
       continue;
 
-    replace_types_rec(s_it->second.values.replace_const, it->code);
-    replace_types_rec(s_it->second.values.replace_const, it->guard);
+    replace_types_rec(d.values.replace_const, it->code);
+    replace_types_rec(d.values.replace_const, it->guard);
 
     if(it->is_goto() || it->is_assume() || it->is_assert())
     {
-      s_it->second.partial_evaluate(it->guard, ns);
+      d.partial_evaluate(it->guard, ns);
     }
     else if(it->is_assign())
     {
       exprt &rhs=to_code_assign(it->code).rhs();
-      s_it->second.partial_evaluate(rhs, ns);
+      d.partial_evaluate(rhs, ns);
+
       if(rhs.id()==ID_constant)
         rhs.add_source_location()=it->code.op0().source_location();
     }
     else if(it->is_function_call())
     {
       exprt &function = to_code_function_call(it->code).function();
-      s_it->second.partial_evaluate(function, ns);
+      d.partial_evaluate(function, ns);
 
       exprt::operandst &args=
         to_code_function_call(it->code).arguments();
 
       for(auto &arg : args)
       {
-        s_it->second.partial_evaluate(arg, ns);
+        d.partial_evaluate(arg, ns);
       }
     }
     else if(it->is_other())
     {
       if(it->code.get_statement()==ID_expression)
       {
-        s_it->second.partial_evaluate(it->code, ns);
+        d.partial_evaluate(it->code, ns);
       }
     }
   }
