@@ -18,6 +18,8 @@ Author: Peter Schrammel
 #include "ai.h"
 #include "dirty.h"
 
+class constant_propagator_ait;
+
 class constant_propagator_domaint:public ai_domain_baset
 {
 public:
@@ -68,15 +70,12 @@ public:
 
   struct valuest
   {
-  public:
-    valuest():is_bottom(true) {}
-
     // maps variables to constants
     replace_symbolt replace_const;
-    bool is_bottom;
+    bool is_bottom = true;
 
     bool merge(const valuest &src);
-    bool meet(const valuest &src);
+    bool meet(const valuest &src, const namespacet &ns);
 
     // set whole state
 
@@ -143,12 +142,15 @@ public:
 protected:
   void assign_rec(
     valuest &values,
-    const exprt &lhs, const exprt &rhs,
-    const namespacet &ns);
+    const exprt &lhs,
+    const exprt &rhs,
+    const namespacet &ns,
+    const constant_propagator_ait *cp);
 
   bool two_way_propagate_rec(
     const exprt &expr,
-    const namespacet &ns);
+    const namespacet &ns,
+    const constant_propagator_ait *cp);
 
   bool partial_evaluate_with_all_rounding_modes(
     exprt &expr,
@@ -160,13 +162,35 @@ protected:
 class constant_propagator_ait:public ait<constant_propagator_domaint>
 {
 public:
-  explicit constant_propagator_ait(const goto_functionst &goto_functions):
-    dirty(goto_functions)
+  typedef std::function<bool(const exprt &, const namespacet &)>
+    should_track_valuet;
+
+  static bool track_all_values(const exprt &, const namespacet &)
+  {
+    return true;
+  }
+
+  explicit constant_propagator_ait(
+    const goto_functionst &goto_functions,
+    should_track_valuet should_track_value = track_all_values):
+    dirty(goto_functions),
+    should_track_value(should_track_value)
+  {
+  }
+
+  explicit constant_propagator_ait(
+    const goto_functiont &goto_function,
+    should_track_valuet should_track_value = track_all_values):
+    dirty(goto_function),
+    should_track_value(should_track_value)
   {
   }
 
   constant_propagator_ait(
-    goto_modelt &goto_model):dirty(goto_model.goto_functions)
+    goto_modelt &goto_model,
+    should_track_valuet should_track_value = track_all_values):
+    dirty(goto_model.goto_functions),
+    should_track_value(should_track_value)
   {
     const namespacet ns(goto_model.symbol_table);
     operator()(goto_model.goto_functions, ns);
@@ -175,7 +199,10 @@ public:
 
   constant_propagator_ait(
     goto_functionst::goto_functiont &goto_function,
-    const namespacet &ns):dirty(goto_function)
+    const namespacet &ns,
+    should_track_valuet should_track_value = track_all_values):
+    dirty(goto_function),
+    should_track_value(should_track_value)
   {
     operator()(goto_function, ns);
     replace(goto_function, ns);
@@ -197,6 +224,8 @@ protected:
   void replace_types_rec(
     const replace_symbolt &replace_const,
     exprt &expr);
+
+  should_track_valuet should_track_value;
 };
 
 #endif // CPROVER_ANALYSES_CONSTANT_PROPAGATOR_H
