@@ -163,9 +163,9 @@ void escape_domaint::get_rhs_aliases_address_of(
 
 void escape_domaint::transform(
   locationt from,
-  locationt to,
-  ai_baset &ai,
-  const namespacet &ns)
+  locationt,
+  ai_baset &,
+  const namespacet &)
 {
   if(has_values.is_false())
     return;
@@ -255,8 +255,8 @@ void escape_domaint::transform(
 
 void escape_domaint::output(
   std::ostream &out,
-  const ai_baset &ai,
-  const namespacet &ns) const
+  const ai_baset &,
+  const namespacet &) const
 {
   if(has_values.is_known())
   {
@@ -301,8 +301,8 @@ void escape_domaint::output(
 
 bool escape_domaint::merge(
   const escape_domaint &b,
-  locationt from,
-  locationt to)
+  locationt,
+  locationt)
 {
   bool changed=has_values.is_false();
   has_values=tvt::unknown();
