@@ -13,20 +13,21 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include <algorithm>
 
-#include <util/simplify_expr.h>
-#include <util/array_name.h>
-#include <util/ieee_float.h>
 #include <util/arith_tools.h>
+#include <util/array_name.h>
+#include <util/base_type.h>
+#include <util/cprover_prefix.h>
+#include <util/c_types.h>
 #include <util/expr_util.h>
 #include <util/find_symbols.h>
-#include <util/std_expr.h>
-#include <util/std_types.h>
 #include <util/guard.h>
-#include <util/base_type.h>
+#include <util/ieee_float.h>
+#include <util/options.h>
 #include <util/pointer_offset_size.h>
 #include <util/pointer_predicates.h>
-#include <util/cprover_prefix.h>
-#include <util/options.h>
+#include <util/simplify_expr.h>
+#include <util/std_expr.h>
+#include <util/std_types.h>
 
 #include <langapi/language.h>
 #include <langapi/mode.h>
@@ -86,23 +87,34 @@ protected:
     bool address);
   void check(const exprt &expr);
 
-  void bounds_check(const index_exprt &expr, const guardt &guard);
-  void div_by_zero_check(const div_exprt &expr, const guardt &guard);
-  void mod_by_zero_check(const mod_exprt &expr, const guardt &guard);
-  void undefined_shift_check(const shift_exprt &expr, const guardt &guard);
-  void pointer_rel_check(const exprt &expr, const guardt &guard);
-  void pointer_overflow_check(const exprt &expr, const guardt &guard);
-  void pointer_validity_check(
-    const dereference_exprt &expr,
-    const guardt &guard,
-    const exprt &access_lb,
-    const exprt &access_ub);
-  void integer_overflow_check(const exprt &expr, const guardt &guard);
-  void conversion_check(const exprt &expr, const guardt &guard);
-  void float_overflow_check(const exprt &expr, const guardt &guard);
-  void nan_check(const exprt &expr, const guardt &guard);
+  struct conditiont
+  {
+    conditiont(const exprt &_assertion, const std::string &_description)
+      : assertion(_assertion), description(_description)
+    {
+    }
 
-  std::string array_name(const exprt &expr);
+    exprt assertion;
+    std::string description;
+  };
+
+  using conditionst = std::list<conditiont>;
+
+  void bounds_check(const index_exprt &, const guardt &);
+  void div_by_zero_check(const div_exprt &, const guardt &);
+  void mod_by_zero_check(const mod_exprt &, const guardt &);
+  void undefined_shift_check(const shift_exprt &, const guardt &);
+  void pointer_rel_check(const exprt &, const guardt &);
+  void pointer_overflow_check(const exprt &, const guardt &);
+  void pointer_validity_check(const dereference_exprt &, const guardt &);
+  conditionst address_check(const exprt &address, const exprt &size);
+  void integer_overflow_check(const exprt &, const guardt &);
+  void conversion_check(const exprt &, const guardt &);
+  void float_overflow_check(const exprt &, const guardt &);
+  void nan_check(const exprt &, const guardt &);
+  void rw_ok_check(exprt &);
+
+  std::string array_name(const exprt &);
 
   void add_guarded_claim(
     const exprt &expr,
@@ -139,6 +151,8 @@ protected:
   typedef optionst::value_listt error_labelst;
   error_labelst error_labels;
 
+  // the first element of the pair is the base address,
+  // and the second is the size of the region
   typedef std::pair<exprt, exprt> allocationt;
   typedef std::list<allocationt> allocationst;
   allocationst allocations;
@@ -918,163 +932,137 @@ void goto_checkt::pointer_overflow_check(
 
 void goto_checkt::pointer_validity_check(
   const dereference_exprt &expr,
-  const guardt &guard,
-  const exprt &access_lb,
-  const exprt &access_ub)
+  const guardt &guard)
 {
   if(!enable_pointer_check)
     return;
 
-  const exprt &pointer=expr.op0();
-  const pointer_typet &pointer_type=
-    to_pointer_type(ns.follow(pointer.type()));
+  const exprt &pointer=expr.pointer();
 
-  assert(base_type_eq(pointer_type.subtype(), expr.type(), ns));
+  auto conditions =
+    address_check(pointer, size_of_expr(expr.type(), ns));
 
-  local_bitvector_analysist::flagst flags=
-    local_bitvector_analysis->get(t, pointer);
+  for(const auto &c : conditions)
+  {
+    add_guarded_claim(
+      c.assertion,
+      "dereference failure: "+c.description,
+      "pointer dereference",
+      expr.find_source_location(),
+      expr,
+      guard);
+  }
+}
 
-  const typet &dereference_type=pointer_type.subtype();
+goto_checkt::conditionst
+goto_checkt::address_check(const exprt &address, const exprt &size)
+{
+  if(!enable_pointer_check)
+    return {};
+
+  PRECONDITION(address.type().id() == ID_pointer);
+  const auto &pointer_type = to_pointer_type(address.type());
+
+  local_bitvector_analysist::flagst flags =
+    local_bitvector_analysis->get(t, address);
 
   // For Java, we only need to check for null
-  if(mode==ID_java)
+  if(mode == ID_java)
   {
     if(flags.is_unknown() || flags.is_null())
     {
-      notequal_exprt not_eq_null(pointer, null_pointer_exprt(pointer_type));
+      notequal_exprt not_eq_null(address, null_pointer_exprt(pointer_type));
 
-      add_guarded_claim(
-        not_eq_null,
-        "reference is null",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+      return {conditiont(not_eq_null, "reference is null")};
     }
+    else
+      return {};
   }
   else
   {
-    exprt allocs=false_exprt();
+    conditionst conditions;
+    exprt::operandst alloc_disjuncts;
 
-    if(!allocations.empty())
+    for(const auto &a : allocations)
     {
-      exprt::operandst disjuncts;
+      typecast_exprt int_ptr(address, a.first.type());
 
-      for(const auto &a : allocations)
-      {
-        typecast_exprt int_ptr(pointer, a.first.type());
+      binary_relation_exprt lb_check(a.first, ID_le, int_ptr);
 
-        exprt lb(int_ptr);
-        if(access_lb.is_not_nil())
-        {
-          if(!base_type_eq(lb.type(), access_lb.type(), ns))
-            lb=plus_exprt(lb, typecast_exprt(access_lb, lb.type()));
-          else
-            lb=plus_exprt(lb, access_lb);
-        }
+      plus_exprt ub(int_ptr, size, int_ptr.type());
 
-        binary_relation_exprt lb_check(a.first, ID_le, lb);
+      binary_relation_exprt ub_check(ub, ID_le, plus_exprt(a.first, a.second));
 
-        exprt ub(int_ptr);
-        if(access_ub.is_not_nil())
-        {
-          if(!base_type_eq(ub.type(), access_ub.type(), ns))
-            ub=plus_exprt(ub, typecast_exprt(access_ub, ub.type()));
-          else
-            ub=plus_exprt(ub, access_ub);
-        }
-
-        binary_relation_exprt ub_check(
-          ub, ID_le, plus_exprt(a.first, a.second));
-
-        disjuncts.push_back(and_exprt(lb_check, ub_check));
-      }
-
-      allocs=disjunction(disjuncts);
+      alloc_disjuncts.push_back(and_exprt(lb_check, ub_check));
     }
 
+    const exprt allocs = disjunction(alloc_disjuncts);
+
     if(flags.is_unknown() || flags.is_null())
     {
-      add_guarded_claim(
-        or_exprt(allocs, not_exprt(null_pointer(pointer))),
-        "dereference failure: pointer NULL",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+      conditions.push_back(conditiont(
+        or_exprt(allocs, not_exprt(null_pointer(address))), "pointer NULL"));
     }
 
     if(flags.is_unknown())
-      add_guarded_claim(
-        or_exprt(allocs, not_exprt(invalid_pointer(pointer))),
-        "dereference failure: pointer invalid",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+    {
+      conditions.push_back(conditiont(
+        not_exprt(invalid_pointer(address)),
+        "pointer invalid"));
+    }
 
     if(flags.is_uninitialized())
-      add_guarded_claim(
-        or_exprt(allocs, not_exprt(invalid_pointer(pointer))),
-        "dereference failure: pointer uninitialized",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+    {
+      conditions.push_back(conditiont(
+        or_exprt(allocs, not_exprt(invalid_pointer(address))),
+        "pointer uninitialized"));
+    }
 
     if(flags.is_unknown() || flags.is_dynamic_heap())
-      add_guarded_claim(
-        or_exprt(allocs, not_exprt(deallocated(pointer, ns))),
-        "dereference failure: deallocated dynamic object",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+    {
+      conditions.push_back(conditiont(
+        not_exprt(deallocated(address, ns)),
+        "deallocated dynamic object"));
+    }
 
     if(flags.is_unknown() || flags.is_dynamic_local())
-      add_guarded_claim(
-        or_exprt(allocs, not_exprt(dead_object(pointer, ns))),
-        "dereference failure: dead object",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+    {
+      conditions.push_back(conditiont(
+        not_exprt(dead_object(address, ns)), "dead object"));
+    }
 
     if(flags.is_unknown() || flags.is_dynamic_heap())
     {
-      const or_exprt dynamic_bounds(
-        dynamic_object_lower_bound(pointer, ns, access_lb),
-        dynamic_object_upper_bound(pointer, dereference_type, ns, access_ub));
+      const or_exprt dynamic_bounds_violation(
+        dynamic_object_lower_bound(address, ns, nil_exprt()),
+        dynamic_object_upper_bound(address, ns, size));
 
-      add_guarded_claim(
-        or_exprt(
-          allocs,
-          implies_exprt(
-            malloc_object(pointer, ns),
-            not_exprt(dynamic_bounds))),
-        "dereference failure: pointer outside dynamic object bounds",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+      conditions.push_back(conditiont(
+        implies_exprt(malloc_object(address, ns), not_exprt(dynamic_bounds_violation)),
+        "pointer outside dynamic object bounds"));
     }
 
-    if(flags.is_unknown() ||
-       flags.is_dynamic_local() ||
-       flags.is_static_lifetime())
+    if(
+      flags.is_unknown() || flags.is_dynamic_local() ||
+      flags.is_static_lifetime())
     {
-      const or_exprt object_bounds(
-        object_lower_bound(pointer, ns, access_lb),
-        object_upper_bound(pointer, dereference_type, ns, access_ub));
+      const or_exprt object_bounds_violation(
+        object_lower_bound(address, ns, nil_exprt()),
+        object_upper_bound(address, ns, size));
 
-      add_guarded_claim(
-        or_exprt(allocs, dynamic_object(pointer), not_exprt(object_bounds)),
-        "dereference failure: pointer outside object bounds",
-        "pointer dereference",
-        expr.find_source_location(),
-        expr,
-        guard);
+      conditions.push_back(conditiont(
+        implies_exprt(not_exprt(dynamic_object(address)), not_exprt(object_bounds_violation)),
+        "pointer outside object bounds"));
     }
+
+    if(flags.is_unknown() || flags.is_integer_address())
+    {
+      conditions.push_back(conditiont(
+        implies_exprt(integer_address(address), allocs),
+        "invalid integer address"));
+    }
+
+    return conditions;
   }
 }
 
@@ -1404,24 +1392,42 @@ void goto_checkt::check_rec(const exprt &expr, guardt &guard, bool address)
     const dereference_exprt &deref=
       to_dereference_expr(member.struct_op());
 
-    check_rec(deref.op0(), guard, false);
+    check_rec(deref.pointer(), guard, false);
 
     // avoid building the following expressions when pointer_validity_check
     // would return immediately anyway
     if(!enable_pointer_check)
       return;
 
-    exprt access_ub=nil_exprt();
+    // we rewrite s->member into *(s+member_offset)
+    // to avoid requiring memory safety of the entire struct
 
     exprt member_offset=member_offset_expr(member, ns);
-    exprt size=size_of_expr(expr.type(), ns);
 
-    if(member_offset.is_not_nil() && size.is_not_nil())
-      access_ub=plus_exprt(member_offset, size);
+    if(member_offset.is_not_nil())
+    {
+      pointer_typet new_pointer_type = to_pointer_type(deref.pointer().type());
+      new_pointer_type.subtype() = expr.type();
 
-    pointer_validity_check(deref, guard, member_offset, access_ub);
+      const exprt char_pointer =
+        typecast_exprt::conditional_cast(
+          deref.pointer(), pointer_type(char_type()));
 
-    return;
+      const exprt new_address = typecast_exprt(
+        plus_exprt(
+          char_pointer,
+          typecast_exprt::conditional_cast(member_offset, pointer_diff_type())),
+        char_pointer.type());
+
+      const exprt new_address_casted =
+        typecast_exprt::conditional_cast(new_address, new_pointer_type);
+
+      dereference_exprt new_deref(new_address_casted, expr.type());
+      new_deref.add_source_location() = deref.source_location();
+      pointer_validity_check(new_deref, guard);
+
+      return;
+    }
   }
 
   forall_operands(it, expr)
@@ -1483,11 +1489,9 @@ void goto_checkt::check_rec(const exprt &expr, guardt &guard, bool address)
           expr.id()==ID_ge || expr.id()==ID_gt)
     pointer_rel_check(expr, guard);
   else if(expr.id()==ID_dereference)
-    pointer_validity_check(
-      to_dereference_expr(expr),
-      guard,
-      nil_exprt(),
-      size_of_expr(expr.type(), ns));
+  {
+    pointer_validity_check(to_dereference_expr(expr), guard);
+  }
 }
 
 void goto_checkt::check(const exprt &expr)
@@ -1496,6 +1500,27 @@ void goto_checkt::check(const exprt &expr)
   check_rec(expr, guard, false);
 }
 
+/// expand the r_ok and w_ok predicates
+void goto_checkt::rw_ok_check(exprt &expr)
+{
+  for(auto &op : expr.operands())
+    rw_ok_check(op);
+
+  if(expr.id() == ID_r_ok || expr.id() == ID_w_ok)
+  {
+    // these get an address as first argument and a size as second
+    DATA_INVARIANT(
+      expr.operands().size() == 2, "r/w_ok must have two operands");
+
+    const auto conditions = address_check(expr.op0(), expr.op1());
+    exprt::operandst conjuncts;
+    for(const auto &c : conditions)
+      conjuncts.push_back(c.assertion);
+
+    expr = conjunction(conjuncts);
+  }
+}
+
 void goto_checkt::goto_check(
   goto_functiont &goto_function,
   const irep_idt &_mode)
@@ -1645,6 +1670,9 @@ void goto_checkt::goto_check(
     else if(i.is_assert())
     {
       bool is_user_provided=i.source_location.get_bool("user-provided");
+
+      rw_ok_check(i.guard);
+
       if((is_user_provided && !enable_assertions &&
           i.source_location.get_property_class()!="error label") ||
          (!is_user_provided && !enable_built_in_assertions))
@@ -1678,7 +1706,7 @@ void goto_checkt::goto_check(
           if(!base_type_eq(lhs.type(), address_of_expr.type(), ns))
             address_of_expr.make_typecast(lhs.type());
           const if_exprt rhs(
-            side_effect_expr_nondett(bool_typet()),
+            side_effect_expr_nondett(bool_typet(), i.source_location),
             address_of_expr,
             lhs,
             lhs.type());
