@@ -93,7 +93,7 @@ void static_analysis_baset::output(
 
 void static_analysis_baset::output(
   const goto_programt &goto_program,
-  const irep_idt &identifier,
+  const irep_idt &,
   std::ostream &out) const
 {
   forall_goto_program_instructions(i_it, goto_program)
@@ -248,7 +248,7 @@ void static_analysis_baset::do_function_call(
   locationt l_call, locationt l_return,
   const goto_functionst &goto_functions,
   const goto_functionst::function_mapt::const_iterator f_it,
-  const exprt::operandst &arguments,
+  const exprt::operandst &,
   statet &new_state)
 {
   const goto_functionst::goto_functiont &goto_function=f_it->second;
