@@ -6,16 +6,15 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_ANSI_C_PARSER_H
-#define CPROVER_ANSI_C_PARSER_H
+
+#ifndef CPROVER_ANSI_C_ANSI_C_PARSER_H
+#define CPROVER_ANSI_C_ANSI_C_PARSER_H
 
 #include <cassert>
 
 #include <util/parser.h>
 #include <util/expr.h>
-#include <util/hash_cont.h>
 #include <util/string_hash.h>
-#include <util/i2string.h>
 #include <util/mp_arith.h>
 #include <util/config.h>
 
@@ -28,31 +27,38 @@ class ansi_c_parsert:public parsert
 {
 public:
   ansi_c_parse_treet parse_tree;
-  
+
   ansi_c_parsert():
-    cpp98(false), cpp11(false),
-    for_has_scope(false)
+    tag_following(false),
+    asm_block_following(false),
+    parenthesis_counter(0),
+    mode(modet::NONE),
+    cpp98(false),
+    cpp11(false),
+    for_has_scope(false),
+    ts_18661_3_Floatn_types(false),
+    Float128_type(false)
   {
   }
-  
+
   virtual bool parse() override
   {
     return yyansi_cparse()!=0;
   }
 
-  virtual void clear() override 
+  virtual void clear() override
   {
     parsert::clear();
     parse_tree.clear();
-    
+
     // scanner state
     tag_following=false;
     asm_block_following=false;
     parenthesis_counter=0;
     string_literal.clear();
     pragma_pack.clear();
-    
-    // setup global scope
+
+    // set up global scope
     scopes.clear();
     scopes.push_back(scopet());
   }
@@ -67,40 +73,46 @@ public:
   typedef configt::ansi_ct::flavourt modet;
   modet mode;
 
-  // recognize C++98 and C++11 keywords  
+  // recognize C++98 and C++11 keywords
   bool cpp98, cpp11;
-  
+
   // in C99 and upwards, for(;;) has a scope
   bool for_has_scope;
 
-  typedef ansi_c_identifiert identifiert;  
+  // ISO/IEC TS 18661-3:2015
+  bool ts_18661_3_Floatn_types;
+
+  // Does the compiler version emulated provide _Float128?
+  bool Float128_type;
+
+  typedef ansi_c_identifiert identifiert;
   typedef ansi_c_scopet scopet;
 
   typedef std::list<scopet> scopest;
   scopest scopes;
-  
+
   scopet &root_scope()
   {
     return scopes.front();
   }
-  
+
   const scopet &root_scope() const
   {
     return scopes.front();
   }
-  
+
   void pop_scope()
   {
     scopes.pop_back();
   }
-   
+
   scopet &current_scope()
   {
     assert(!scopes.empty());
     return scopes.back();
   }
 
-  typedef enum { TAG, MEMBER, PARAMETER, OTHER } decl_typet;
+  enum class decl_typet { TAG, MEMBER, PARAMETER, OTHER };
 
   // convert a declarator and then add it to existing an declaration
   void add_declarator(exprt &declaration, irept &declarator);
@@ -113,7 +125,7 @@ public:
     assert(declaration.id()==ID_declaration);
     parse_tree.items.push_back(declaration);
   }
-   
+
   void new_scope(const std::string &prefix)
   {
     const scopet &current=current_scope();
@@ -128,7 +140,7 @@ public:
     bool label);
 
   static ansi_c_id_classt get_class(const typet &type);
-  
+
   irep_idt lookup_label(const irep_idt base_name)
   {
     irep_idt identifier;
@@ -142,4 +154,4 @@ extern ansi_c_parsert ansi_c_parser;
 int yyansi_cerror(const std::string &error);
 void ansi_c_scanner_init();
 
-#endif
+#endif // CPROVER_ANSI_C_ANSI_C_PARSER_H
