@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_ANSI_C_TYPECHECK_H
-#define CPROVER_ANSI_C_TYPECHECK_H
+/// \file
+/// ANSI-C Language Type Checking
+
+#ifndef CPROVER_ANSI_C_ANSI_C_TYPECHECK_H
+#define CPROVER_ANSI_C_ANSI_C_TYPECHECK_H
 
 #include "c_typecheck_base.h"
 #include "ansi_c_parse_tree.h"
@@ -56,4 +59,4 @@ protected:
   ansi_c_parse_treet &parse_tree;
 };
 
-#endif
+#endif // CPROVER_ANSI_C_ANSI_C_TYPECHECK_H
