@@ -6,34 +6,23 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/arith_tools.h>
-#include <util/config.h>
-#include <util/type_eq.h>
-#include <util/std_types.h>
-#include <util/expr_util.h>
-#include <util/simplify_expr.h>
-#include <util/cprover_prefix.h>
-#include <util/prefix.h>
+/// \file
+/// ANSI-C Conversion / Type Checking
 
-#include <linking/zero_initializer.h>
-
-#include "c_types.h"
 #include "c_typecheck_base.h"
-#include "string_constant.h"
+
+#include <util/arith_tools.h>
+#include <util/c_types.h>
+#include <util/cprover_prefix.h>
+#include <util/expr_initializer.h>
+#include <util/prefix.h>
+#include <util/simplify_expr.h>
+#include <util/std_types.h>
+#include <util/string_constant.h>
+#include <util/type_eq.h>
+
 #include "anonymous_member.h"
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::do_initializer
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void c_typecheck_baset::do_initializer(
   exprt &initializer,
   const typet &type,
@@ -43,11 +32,11 @@ void c_typecheck_baset::do_initializer(
 
   if(type.id()==ID_array)
   {
-    // any arrays must have a size
     const typet &result_type=follow(result.type());
-    assert(result_type.id()==ID_array &&
-           to_array_type(result_type).size().is_not_nil());
-           
+    DATA_INVARIANT(result_type.id()==ID_array &&
+                   to_array_type(result_type).size().is_not_nil(),
+                   "any array must have a size");
+
     // we don't allow initialisation with symbols of array type
     if(result.id()!=ID_array)
     {
@@ -57,30 +46,18 @@ void c_typecheck_baset::do_initializer(
       throw 0;
     }
   }
-    
+
   initializer=result;
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::do_initializer_rec
-
-  Inputs:
-
- Outputs:
-
- Purpose: initialize something of type `type' with given
-          value `value'
-
-\*******************************************************************/
-
+/// initialize something of type `type' with given value `value'
 exprt c_typecheck_baset::do_initializer_rec(
   const exprt &value,
   const typet &type,
   bool force_constant)
 {
   const typet &full_type=follow(type);
-  
+
   if(full_type.id()==ID_incomplete_struct)
   {
     err_location(value);
@@ -88,10 +65,10 @@ exprt c_typecheck_baset::do_initializer_rec(
             << "' is still incomplete -- cannot initialize" << eom;
     throw 0;
   }
-  
+
   if(value.id()==ID_initializer_list)
     return do_initializer_list(value, type, force_constant);
-    
+
   if(value.id()==ID_array &&
      value.get_bool(ID_C_string_constant) &&
      full_type.id()==ID_array &&
@@ -103,7 +80,7 @@ exprt c_typecheck_baset::do_initializer_rec(
 
     // adjust char type
     tmp.type().subtype()=full_type.subtype();
-    
+
     Forall_operands(it, tmp)
       it->type()=full_type.subtype();
 
@@ -119,7 +96,7 @@ exprt c_typecheck_baset::do_initializer_rec(
                 << to_string(to_array_type(full_type).size()) << eom;
         throw 0;
       }
-      
+
       if(array_size<0)
       {
         err_location(value);
@@ -137,15 +114,19 @@ exprt c_typecheck_baset::do_initializer_rec(
       {
         // fill up
         tmp.type()=type;
-        exprt zero=zero_initializer(full_type.subtype(), value.source_location(),
-                                    *this, get_message_handler());
+        exprt zero=
+          zero_initializer(
+            full_type.subtype(),
+            value.source_location(),
+            *this,
+            get_message_handler());
         tmp.operands().resize(integer2size_t(array_size), zero);
       }
     }
-    
+
     return tmp;
   }
-  
+
   if(value.id()==ID_string_constant &&
      full_type.id()==ID_array &&
      (full_type.subtype().id()==ID_signedbv ||
@@ -153,7 +134,7 @@ exprt c_typecheck_baset::do_initializer_rec(
       full_type.subtype().get(ID_width)==char_type().get(ID_width))
   {
     // will go away, to be replaced by the above block
-  
+
     string_constantt tmp1=to_string_constant(value);
     // adjust char type
     tmp1.type().subtype()=full_type.subtype();
@@ -172,7 +153,7 @@ exprt c_typecheck_baset::do_initializer_rec(
                 << to_string(to_array_type(full_type).size()) << eom;
         throw 0;
       }
-      
+
       if(array_size<0)
       {
         err_location(value);
@@ -190,15 +171,19 @@ exprt c_typecheck_baset::do_initializer_rec(
       {
         // fill up
         tmp2.type()=type;
-        exprt zero=zero_initializer(full_type.subtype(), value.source_location(),
-                                    *this, get_message_handler());
+        exprt zero=
+          zero_initializer(
+            full_type.subtype(),
+            value.source_location(),
+            *this,
+            get_message_handler());
         tmp2.operands().resize(integer2size_t(array_size), zero);
       }
     }
-    
+
     return tmp2;
   }
-  
+
   if(full_type.id()==ID_array &&
      to_array_type(full_type).size().is_nil())
   {
@@ -223,18 +208,6 @@ exprt c_typecheck_baset::do_initializer_rec(
   return result;
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::do_initializer
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void c_typecheck_baset::do_initializer(symbolt &symbol)
 {
   // this one doesn't need initialization
@@ -269,7 +242,7 @@ void c_typecheck_baset::do_initializer(symbolt &symbol)
     {
       typecheck_expr(symbol.value);
       do_initializer(symbol.value, symbol.type, true);
-      
+
       // need to adjust size?
       if(follow(symbol.type).id()==ID_array &&
          to_array_type(follow(symbol.type)).size().is_nil())
@@ -278,34 +251,22 @@ void c_typecheck_baset::do_initializer(symbolt &symbol)
   }
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::designator_enter
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void c_typecheck_baset::designator_enter(
   const typet &type,
   designatort &designator)
 {
-  designatort::entryt entry;
-  entry.type=type;
-  entry.index=0;
+  designatort::entryt entry(type);
 
   const typet &full_type=follow(type);
-  
+
   if(full_type.id()==ID_struct)
   {
     const struct_typet &struct_type=to_struct_type(full_type);
 
     entry.size=struct_type.components().size();
     entry.subtype.make_nil();
+    // only a top-level struct may end with a variable-length array
+    entry.vla_permitted=designator.empty();
 
     for(struct_typet::componentst::const_iterator
         it=struct_type.components().begin();
@@ -333,7 +294,7 @@ void c_typecheck_baset::designator_enter(
     }
     else
     {
-      // The default is to unitialize using the first member of the
+      // The default is to initialize using the first member of the
       // union.
       entry.size=1;
       entry.subtype=union_type.components().front().type();
@@ -382,46 +343,42 @@ void c_typecheck_baset::designator_enter(
     entry.subtype=vector_type.subtype();
   }
   else
-    assert(false);
+    UNREACHABLE;
 
   designator.push_entry(entry);
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::do_designated_initializer
-
-  Inputs: pre-initialized result, designator
-
- Outputs: sets result
-
- Purpose:
-
-\*******************************************************************/
-
-void c_typecheck_baset::do_designated_initializer(
+/// \param pre:initialized result, designator
+/// \return sets result
+exprt::operandst::const_iterator c_typecheck_baset::do_designated_initializer(
   exprt &result,
   designatort &designator,
-  const exprt &value,
+  const exprt &initializer_list,
+  exprt::operandst::const_iterator init_it,
   bool force_constant)
 {
+  // copy the value, we may need to adjust it
+  exprt value=*init_it;
+
   assert(!designator.empty());
-  
+
   if(value.id()==ID_designated_initializer)
   {
     assert(value.operands().size()==1);
 
-    designator=    
+    designator=
       make_designator(
         designator.front().type,
         static_cast<const exprt &>(value.find(ID_designator)));
-        
+
     assert(!designator.empty());
-  
-    return do_designated_initializer(
-      result, designator, value.op0(), force_constant);
+
+    // discard the return value
+    do_designated_initializer(
+      result, designator, value, value.operands().begin(), force_constant);
+    return ++init_it;
   }
-  
+
   exprt *dest=&result;
 
   // first phase: follow given designator
@@ -442,9 +399,14 @@ void c_typecheck_baset::do_designated_initializer(
             to_array_type(full_type).size().is_nil()))
         {
           // we are willing to grow an incomplete or zero-sized array
-          exprt zero=zero_initializer(full_type.subtype(), value.source_location(), *this, get_message_handler());
+          exprt zero=
+            zero_initializer(
+              full_type.subtype(),
+              value.source_location(),
+              *this,
+              get_message_handler());
           dest->operands().resize(integer2size_t(index)+1, zero);
-          
+
           // todo: adjust type!
         }
         else
@@ -473,9 +435,11 @@ void c_typecheck_baset::do_designated_initializer(
         throw 0;
       }
 
-      assert(index<components.size());
-      assert(components[index].type().id()!=ID_code &&
-             !components[index].get_is_padding());
+      DATA_INVARIANT(index<components.size(),
+                     "member designator is bounded by components size");
+      DATA_INVARIANT(components[index].type().id()!=ID_code &&
+                     !components[index].get_is_padding(),
+                     "member designator points at data member");
 
       dest=&(dest->operands()[index]);
     }
@@ -486,7 +450,8 @@ void c_typecheck_baset::do_designated_initializer(
       const union_typet::componentst &components=
         union_type.components();
 
-      assert(index<components.size());
+      DATA_INVARIANT(index<components.size(),
+                     "member designator is bounded by components size");
 
       const union_typet::componentt &component=union_type.components()[index];
 
@@ -501,7 +466,12 @@ void c_typecheck_baset::do_designated_initializer(
         // Note that gcc issues a warning if the union component is switched.
         // Build a union expression from given component.
         union_exprt union_expr(type);
-        union_expr.op()=zero_initializer(component.type(), value.source_location(), *this, get_message_handler());
+        union_expr.op()=
+          zero_initializer(
+            component.type(),
+            value.source_location(),
+            *this,
+            get_message_handler());
         union_expr.add_source_location()=value.source_location();
         union_expr.set_component_name(component.get_name());
         *dest=union_expr;
@@ -510,12 +480,12 @@ void c_typecheck_baset::do_designated_initializer(
       dest=&(dest->op0());
     }
     else
-      assert(false);
+      UNREACHABLE;
   }
-  
+
   // second phase: assign value
   // for this, we may need to go down, adding to the designator
-  
+
   while(true)
   {
     // see what type we have to initialize
@@ -532,7 +502,7 @@ void c_typecheck_baset::do_designated_initializer(
     {
       // The initializer for a scalar shall be a single expression,
       // * optionally enclosed in braces. *
-      
+
       if(value.id()==ID_initializer_list &&
          value.operands().size()==1)
         *dest=do_initializer_rec(value.op0(), type, force_constant);
@@ -540,10 +510,10 @@ void c_typecheck_baset::do_designated_initializer(
         *dest=do_initializer_rec(value, type, force_constant);
 
       assert(full_type==follow(dest->type()));
-      
-      return; // done
+
+      return ++init_it; // done
     }
-    
+
     // union? The component in the zero initializer might
     // not be the first one.
     if(full_type.id()==ID_union)
@@ -555,10 +525,16 @@ void c_typecheck_baset::do_designated_initializer(
 
       if(!components.empty())
       {
-        const union_typet::componentt &component=union_type.components().front();
+        const union_typet::componentt &component=
+          union_type.components().front();
 
         union_exprt union_expr(type);
-        union_expr.op()=zero_initializer(component.type(), value.source_location(), *this, get_message_handler());
+        union_expr.op()=
+          zero_initializer(
+            component.type(),
+            value.source_location(),
+            *this,
+            get_message_handler());
         union_expr.add_source_location()=value.source_location();
         union_expr.set_component_name(component.get_name());
         *dest=union_expr;
@@ -569,7 +545,7 @@ void c_typecheck_baset::do_designated_initializer(
     if(value.id()==ID_initializer_list)
     {
       *dest=do_initializer_rec(value, type, force_constant);
-      return; // done
+      return ++init_it; // done
     }
     else if(value.id()==ID_string_constant)
     {
@@ -581,7 +557,7 @@ void c_typecheck_baset::do_designated_initializer(
           follow(full_type.subtype()).id()==ID_unsignedbv))
       {
         *dest=do_initializer_rec(value, type, force_constant);
-        return; // done
+        return ++init_it; // done
       }
     }
     else if(follow(value.type())==full_type)
@@ -594,7 +570,7 @@ void c_typecheck_baset::do_designated_initializer(
          full_type.id()==ID_vector)
       {
         *dest=value;
-        return; // done
+        return ++init_it; // done
       }
     }
 
@@ -602,39 +578,55 @@ void c_typecheck_baset::do_designated_initializer(
            full_type.id()==ID_union ||
            full_type.id()==ID_array ||
            full_type.id()==ID_vector);
-    
+
     // we are initializing a compound type, and enter it!
-    // this may change the type, full_type might not be valid anymore
+    // this may change the type, full_type might not be valid any more
     const typet dest_type=full_type;
+    const bool vla_permitted=designator.back().vla_permitted;
     designator_enter(type, designator);
-    
+
+    // GCC permits (though issuing a warning with -Wall) composite
+    // types built from flat initializer lists
     if(dest->operands().empty())
     {
-      err_location(value);
-      error() << "cannot initialize type `"
-              << to_string(dest_type) << "' using value `"
-              << to_string(value) << "'" << eom;
-      throw 0;
+      warning().source_location=value.find_source_location();
+      warning() << "initialisation of " << dest_type.id()
+                << " requires initializer list, found " << value.id()
+                << " instead" << eom;
+
+      // in case of a variable-length array consume all remaining
+      // initializer elements
+      if(vla_permitted &&
+         dest_type.id()==ID_array &&
+         (to_array_type(dest_type).size().is_zero() ||
+          to_array_type(dest_type).size().is_nil()))
+      {
+        value.id(ID_initializer_list);
+        value.operands().clear();
+        for( ; init_it!=initializer_list.operands().end(); ++init_it)
+          value.copy_to_operands(*init_it);
+        *dest=do_initializer_rec(value, dest_type, force_constant);
+
+        return init_it;
+      }
+      else
+      {
+        err_location(value);
+        error() << "cannot initialize type `"
+          << to_string(dest_type) << "' using value `"
+          << to_string(value) << "'" << eom;
+        throw 0;
+      }
     }
 
     dest=&(dest->op0());
 
     // we run into another loop iteration
   }
+
+  return ++init_it;
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::increment_designator
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void c_typecheck_baset::increment_designator(designatort &designator)
 {
   assert(!designator.empty());
@@ -645,7 +637,7 @@ void c_typecheck_baset::increment_designator(designatort &designator)
     const typet &full_type=follow(entry.type);
 
     entry.index++;
-    
+
     if(full_type.id()==ID_array &&
        to_array_type(full_type).size().is_nil())
       return; // we will keep going forever
@@ -659,7 +651,7 @@ void c_typecheck_baset::increment_designator(designatort &designator)
       const struct_typet::componentst &components=
         struct_type.components();
       assert(components.size()==entry.size);
-      
+
       // we skip over any padding or code
       while(entry.index<entry.size &&
             (components[entry.index].get_is_padding() ||
@@ -670,29 +662,19 @@ void c_typecheck_baset::increment_designator(designatort &designator)
         entry.subtype=components[entry.index].type();
     }
 
-    if(entry.index<entry.size) return; // done
-    
-    if(designator.size()==1) return; // done
-    
+    if(entry.index<entry.size)
+      return; // done
+
+    if(designator.size()==1)
+      return; // done
+
     // pop entry
     designator.pop_entry();
-    
+
     assert(!designator.empty());
   }
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::make_designator
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 designatort c_typecheck_baset::make_designator(
   const typet &src_type,
   const exprt &src)
@@ -701,12 +683,11 @@ designatort c_typecheck_baset::make_designator(
 
   typet type=src_type;
   designatort designator;
-  
+
   forall_operands(it, src)
   {
     const exprt &d_op=*it;
-    designatort::entryt entry;
-    entry.type=type;
+    designatort::entryt entry(type);
     const typet &full_type=follow(entry.type);
 
     if(full_type.id()==ID_array)
@@ -739,7 +720,7 @@ designatort c_typecheck_baset::make_designator(
         error() << "expected constant array size" << eom;
         throw 0;
       }
-      
+
       entry.index=integer2size_t(index);
       entry.size=integer2size_t(size);
       entry.subtype=full_type.subtype();
@@ -747,8 +728,9 @@ designatort c_typecheck_baset::make_designator(
     else if(full_type.id()==ID_struct ||
             full_type.id()==ID_union)
     {
-      const struct_union_typet &struct_union_type=to_struct_union_type(full_type);
-    
+      const struct_union_typet &struct_union_type=
+        to_struct_union_type(full_type);
+
       if(d_op.id()!=ID_member)
       {
         err_location(d_op);
@@ -769,14 +751,14 @@ designatort c_typecheck_baset::make_designator(
       {
         // We will search for anonymous members,
         // in a loop. This isn't supported by gcc, but icc does allow it.
-        
+
         bool found=false, repeat;
         typet tmp_type=entry.type;
-        
+
         do
         {
           repeat=false;
-          unsigned number=0;        
+          unsigned number=0;
           const struct_union_typet::componentst &components=
             to_struct_union_type(follow(tmp_type)).components();
 
@@ -811,7 +793,7 @@ designatort c_typecheck_baset::make_designator(
           }
         }
         while(repeat);
-      
+
         if(!found)
         {
           err_location(d_op);
@@ -830,27 +812,15 @@ designatort c_typecheck_baset::make_designator(
       throw 0;
     }
 
-    type=entry.subtype;    
+    type=entry.subtype;
     designator.push_entry(entry);
   }
-  
+
   assert(!designator.empty());
-  
+
   return designator;
 }
 
-/*******************************************************************\
-
-Function: c_typecheck_baset::do_initializer_list
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 exprt c_typecheck_baset::do_initializer_list(
   const exprt &value,
   const typet &type,
@@ -866,7 +836,9 @@ exprt c_typecheck_baset::do_initializer_list(
      full_type.id()==ID_vector)
   {
     // start with zero everywhere
-    result=zero_initializer(type, value.source_location(), *this, get_message_handler());
+    result=
+      zero_initializer(
+        type, value.source_location(), *this, get_message_handler());
   }
   else if(full_type.id()==ID_array)
   {
@@ -879,7 +851,9 @@ exprt c_typecheck_baset::do_initializer_list(
     else
     {
       // start with zero everywhere
-      result=zero_initializer(type, value.source_location(), *this, get_message_handler());
+      result=
+        zero_initializer(
+          type, value.source_location(), *this, get_message_handler());
     }
 
     // 6.7.9, 14: An array of character type may be initialized by a character
@@ -906,7 +880,7 @@ exprt c_typecheck_baset::do_initializer_list(
 
     if(value.operands().size()==1)
       return do_initializer_rec(value.op0(), type, force_constant);
-    
+
     err_location(value);
     error() << "cannot initialize `" << to_string(full_type)
             << "' with an initializer list" << eom;
@@ -914,15 +888,17 @@ exprt c_typecheck_baset::do_initializer_list(
   }
 
   designatort current_designator;
-  
+
   designator_enter(type, current_designator);
 
-  forall_operands(it, value)
+  const exprt::operandst &operands=value.operands();
+  for(exprt::operandst::const_iterator it=operands.begin();
+      it!=operands.end(); ) // no ++it
   {
-    do_designated_initializer(
-      result, current_designator, *it, force_constant);
+    it=do_designated_initializer(
+      result, current_designator, value, it, force_constant);
 
-    // increase designator -- might go up    
+    // increase designator -- might go up
     increment_designator(current_designator);
   }
 
@@ -932,7 +908,7 @@ exprt c_typecheck_baset::do_initializer_list(
     assert(result.operands().size()==
            to_struct_type(full_type).components().size());
   }
-  
+
   if(full_type.id()==ID_array &&
      to_array_type(full_type).size().is_nil())
   {
@@ -941,6 +917,6 @@ exprt c_typecheck_baset::do_initializer_list(
     result.type().id(ID_array);
     result.type().set(ID_size, from_integer(size, index_type()));
   }
-  
+
   return result;
 }
