@@ -5,6 +5,8 @@
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
+int __VERIFIER_nondet_int();
+
 inline int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int type)
 {
   __CPROVER_HIDE:;
@@ -17,7 +19,7 @@ inline int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int type)
   (void)type;
   #endif
 
-  int result;
+  int result=__VERIFIER_nondet_int();
   return result;
 }
 
@@ -28,6 +30,8 @@ inline int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int type)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
+int __VERIFIER_nondet_int();
+
 inline int pthread_cancel(pthread_t thread)
 {
   __CPROVER_HIDE:;
@@ -38,7 +42,7 @@ inline int pthread_cancel(pthread_t thread)
                    "pthread_cancel must be given valid thread ID");
   #endif
 
-  int result;
+  int result=__VERIFIER_nondet_int();
   return result;
 }
 
@@ -75,7 +79,7 @@ inline int pthread_mutex_init(
   __CPROVER_HIDE:;
   *((__CPROVER_mutex_t *)mutex)=0;
   if(mutexattr!=0) (void)*mutexattr;
-  
+
   #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_cleanup(mutex, pthread_mutex_cleanup);
   __CPROVER_set_must(mutex, "mutex-init");
@@ -219,7 +223,7 @@ inline int pthread_mutex_unlock(pthread_mutex_t *mutex)
                    "mutex must not be destroyed");
 
   __CPROVER_clear_may(mutex, "mutex-locked");
-  
+
   #else
 
   // the fence must be before the unlock
@@ -380,8 +384,8 @@ inline int pthread_rwlock_destroy(pthread_rwlock_t *lock)
   __CPROVER_assert(*((signed char *)lock)==0,
     "rwlock held upon destroy");
   *((signed char *)lock)=-1;
-  
-  #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS   
+
+  #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_set_must(lock, "rwlock_destroyed");
   #endif
 
@@ -395,7 +399,7 @@ inline int pthread_rwlock_destroy(pthread_rwlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-#ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS  
+#ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
 inline void pthread_rwlock_cleanup(void *p)
 {
   __CPROVER_HIDE:;
@@ -404,14 +408,14 @@ inline void pthread_rwlock_cleanup(void *p)
 }
 #endif
 
-inline int pthread_rwlock_init(pthread_rwlock_t *lock, 
+inline int pthread_rwlock_init(pthread_rwlock_t *lock,
   const pthread_rwlockattr_t *attr)
 {
   __CPROVER_HIDE:;
   (*(signed char *)lock)=0;
   if(attr!=0) (void)*attr;
 
-  #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS    
+  #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_cleanup(lock, pthread_rwlock_cleanup);
   #endif
 
@@ -448,7 +452,7 @@ inline int pthread_rwlock_tryrdlock(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_atomic_begin();
-  if((*(signed char *)lock & 2)!=0) { __CPROVER_atomic_end(); return 1; }
+  if((*(signed char *)lock &2)!=0) { __CPROVER_atomic_end(); return 1; }
   (*(signed char *)lock)|=1;
   __CPROVER_atomic_end();
   return 0;
@@ -519,36 +523,29 @@ extern __CPROVER_thread_local unsigned long __CPROVER_thread_id;
 extern unsigned long __CPROVER_next_thread_id;
 
 inline int pthread_create(
-  pthread_t *thread,
-  const pthread_attr_t *attr,
-  void * (*start_routine)(void *),
-  void *arg)
+  pthread_t *thread, // must not be null
+  const pthread_attr_t *attr, // may be null
+  void * (*start_routine)(void *), // must not be null
+  void *arg) // may be null
 {
   __CPROVER_HIDE:;
   unsigned long this_thread_id;
   __CPROVER_atomic_begin();
   this_thread_id=++__CPROVER_next_thread_id;
   __CPROVER_atomic_end();
-  
-  if(thread)
-  {
-    #ifdef __APPLE__
-    // pthread_t is a pointer type on the Mac
-    *thread=(pthread_t)this_thread_id;
-    #else
-    *thread=this_thread_id;
-    #endif
-  }
+
+  // pthread_t is a pointer type on some systems
+  *thread=(pthread_t)this_thread_id;
 
   #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_set_must(thread, "pthread-id");
   #endif
 
   if(attr) (void)*attr;
-  
+
   __CPROVER_ASYNC_1:
     __CPROVER_thread_id=this_thread_id,
-    #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS    
+    #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
     // Clear all locked mutexes; locking must happen in same thread.
     __CPROVER_clear_must(0, "mutex-locked"),
     __CPROVER_clear_may(0, "mutex-locked"),
@@ -660,7 +657,7 @@ int pthread_spin_lock(pthread_spinlock_t *lock)
   __CPROVER_assume(!*((unsigned *)lock));
   (*((unsigned *)lock))=1;
   __CPROVER_atomic_end();
-  
+
   __CPROVER_fence("WWfence", "RRfence", "RWfence", "WRfence",
                   "WWcumul", "RRcumul", "RWcumul", "WRcumul");
   return 0;
@@ -715,7 +712,7 @@ int pthread_spin_trylock(pthread_spinlock_t *lock)
     (*((unsigned *)lock))=1;
   }
   __CPROVER_atomic_end();
-  
+
   __CPROVER_fence("WWfence", "RRfence", "RWfence", "WRfence",
                   "WWcumul", "RRcumul", "RWcumul", "WRcumul");
   return result;
@@ -729,6 +726,8 @@ int pthread_spin_trylock(pthread_spinlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
+int __VERIFIER_nondet_int();
+
 // no pthread_barrier_t on the Mac
 #ifndef __APPLE__
 inline int pthread_barrier_init(
@@ -739,15 +738,15 @@ inline int pthread_barrier_init(
   (void)barrier;
   (void)attr;
   (void)count;
-  
+
   #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_set_must(barrier, "barrier-init");
   __CPROVER_clear_may(barrier, "barrier-destroyed");
   #endif
-  
-  int result;
+
+  int result=__VERIFIER_nondet_int();
   return result;
-}       
+}
 #endif
 
 /* FUNCTION: pthread_barrier_destroy */
@@ -757,14 +756,16 @@ inline int pthread_barrier_init(
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
+int __VERIFIER_nondet_int();
+
 // no pthread_barrier_t on the Mac
 #ifndef __APPLE__
 inline int pthread_barrier_destroy(pthread_barrier_t *barrier)
 {
   __CPROVER_HIDE:;
-  
+
   (void)barrier;
-  
+
   #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_assert(__CPROVER_get_must(barrier, "barrier-init"),
                    "pthread barrier must be initialized");
@@ -773,7 +774,7 @@ inline int pthread_barrier_destroy(pthread_barrier_t *barrier)
   __CPROVER_set_may(barrier, "barrier-destroyed");
   #endif
 
-  int result;
+  int result=__VERIFIER_nondet_int();
   return result;
 }
 #endif
@@ -785,14 +786,16 @@ inline int pthread_barrier_destroy(pthread_barrier_t *barrier)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
+int __VERIFIER_nondet_int();
+
 // no pthread_barrier_t on the Mac
 #ifndef __APPLE__
 inline int pthread_barrier_wait(pthread_barrier_t *barrier)
 {
   __CPROVER_HIDE:;
-  
+
   (void)barrier;
-  
+
   #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
   __CPROVER_assert(__CPROVER_get_must(barrier, "barrier-init"),
                    "pthread barrier must be initialized");
@@ -800,7 +803,7 @@ inline int pthread_barrier_wait(pthread_barrier_t *barrier)
                    "pthread barrier must not be destroyed");
   #endif
 
-  int result;
+  int result=__VERIFIER_nondet_int();
   return result;
 }
 #endif
