@@ -6,8 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_ASSEMBLER_PARSER_H
-#define CPROVER_ASSEMBLER_PARSER_H
+
+#ifndef CPROVER_ASSEMBLER_ASSEMBLER_PARSER_H
+#define CPROVER_ASSEMBLER_ASSEMBLER_PARSER_H
 
 #include <util/parser.h>
 #include <util/expr.h>
@@ -21,7 +22,7 @@ class assembler_parsert:public parsert
 public:
   typedef std::vector<irept> instructiont;
   std::list<instructiont> instructions;
-  
+
   void add_token(const irept &irep)
   {
     if(instructions.empty())
@@ -29,16 +30,16 @@ public:
 
     instructions.back().push_back(irep);
   }
-  
+
   void new_instruction()
   {
     instructions.push_back(instructiont());
   }
-  
+
   assembler_parsert()
   {
   }
-  
+
   virtual bool parse()
   {
     yyassemblerlex();
@@ -49,10 +50,10 @@ public:
   {
     parsert::clear();
     instructions.clear();
-    //assembler_scanner_init();
+    // assembler_scanner_init();
   }
 };
 
 extern assembler_parsert assembler_parser;
 
-#endif
+#endif // CPROVER_ASSEMBLER_ASSEMBLER_PARSER_H
