@@ -6,6 +6,7 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
 #ifndef CPROVER_CBMC_BV_CBMC_H
 #define CPROVER_CBMC_BV_CBMC_H
 
@@ -27,4 +28,4 @@ protected:
   virtual bvt convert_waitfor_symbol(const exprt &expr);
 };
 
-#endif
+#endif // CPROVER_CBMC_BV_CBMC_H
