@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_CBMC_DIMACS_H
-#define CPROVER_CBMC_DIMACS_H
+/// \file
+/// Writing DIMACS Files
+
+#ifndef CPROVER_CBMC_CBMC_DIMACS_H
+#define CPROVER_CBMC_CBMC_DIMACS_H
 
 #include "bv_cbmc.h"
 
@@ -34,4 +37,4 @@ protected:
   bool write_dimacs(std::ostream &);
 };
 
-#endif
+#endif // CPROVER_CBMC_CBMC_DIMACS_H
