@@ -104,8 +104,7 @@ bool fault_localizationt::check(const lpointst &lpoints,
   return true;
 }
 
-void fault_localizationt::update_scores(lpointst &lpoints,
-                                        const lpoints_valuet &value)
+void fault_localizationt::update_scores(lpointst &lpoints)
 {
   for(auto &l : lpoints)
   {
@@ -131,10 +130,10 @@ void fault_localizationt::localize_linear(lpointst &lpoints)
   {
     v[i]=tvt(tvt::tv_enumt::TV_TRUE);
     if(!check(lpoints, v))
-      update_scores(lpoints, v);
+      update_scores(lpoints);
     v[i]=tvt(tvt::tv_enumt::TV_FALSE);
     if(!check(lpoints, v))
-      update_scores(lpoints, v);
+      update_scores(lpoints);
     v[i]=tvt(tvt::tv_enumt::TV_UNKNOWN);
   }
 }
@@ -281,7 +280,7 @@ safety_checkert::resultt fault_localizationt::stop_on_fail()
     {
       if(options.get_bool_option("beautify"))
         counterexample_beautificationt()(
-          dynamic_cast<bv_cbmct &>(bmc.prop_conv), bmc.equation, bmc.ns);
+          dynamic_cast<bv_cbmct &>(bmc.prop_conv), bmc.equation);
 
       bmc.error_trace();
     }
@@ -337,10 +336,8 @@ void fault_localizationt::goal_covered(
       if(solver.l_get(cond).is_false())
       {
         goal_pair.second.status=goalt::statust::FAILURE;
-        symex_target_equationt::SSA_stepst::iterator next=inst;
-        next++; // include the assertion
         build_goto_trace(
-          bmc.equation, next, solver, bmc.ns, goal_pair.second.goto_trace);
+          bmc.equation, inst, solver, bmc.ns, goal_pair.second.goto_trace);
 
         // localize faults
         run(goal_pair.first);
