@@ -6,11 +6,16 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#ifndef CPROVER_CPP_CONVERT_TYPE_H
-#define CPROVER_CPP_CONVERT_TYPE_H
+/// \file
+/// C++ Language Conversion
+
+#ifndef CPROVER_CPP_CPP_CONVERT_TYPE_H
+#define CPROVER_CPP_CPP_CONVERT_TYPE_H
 
 #include <util/type.h>
 
-void cpp_convert_plain_type(typet &type);
+void cpp_convert_plain_type(typet &);
 
-#endif
+void cpp_convert_auto(typet &dest, const typet &src);
+
+#endif // CPROVER_CPP_CPP_CONVERT_TYPE_H
