@@ -6,22 +6,13 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#include <ostream>
-#include <cassert>
+/// \file
+/// C++ Language Type Checking
 
 #include "cpp_declarator.h"
 
-/*******************************************************************\
-
-Function: cpp_declaratort::output
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <ostream>
+#include <cassert>
 
 void cpp_declaratort::output(std::ostream &out) const
 {
@@ -32,18 +23,6 @@ void cpp_declaratort::output(std::ostream &out) const
   out << "  method_qualifier: " << method_qualifier().pretty() << "\n";
 }
 
-/*******************************************************************\
-
-Function: cpp_declaratort::merge_type
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 typet cpp_declaratort::merge_type(const typet &declaration_type) const
 {
   typet dest_type=type();
@@ -70,7 +49,7 @@ typet cpp_declaratort::merge_type(const typet &declaration_type) const
     }
     else
     {
-      assert(t.id()!=irep_idt());
+      assert(!t.id().empty());
       p=&t.subtype();
     }
   }
