@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#ifndef CPROVER_CPP_LINKAGE_SPEC_H
-#define CPROVER_CPP_LINKAGE_SPEC_H
+/// \file
+/// C++ Language Type Checking
+
+#ifndef CPROVER_CPP_CPP_LINKAGE_SPEC_H
+#define CPROVER_CPP_CPP_LINKAGE_SPEC_H
 
 class cpp_linkage_spect:public exprt
 {
@@ -15,7 +18,7 @@ public:
   cpp_linkage_spect():exprt(ID_cpp_linkage_spec)
   {
   }
-  
+
   typedef std::vector<class cpp_itemt> itemst;
 
   const itemst &items() const
@@ -27,7 +30,7 @@ public:
   {
     return (itemst &)operands();
   }
-  
+
   irept &linkage()
   {
     return add(ID_linkage);
@@ -39,4 +42,4 @@ public:
   }
 };
 
-#endif
+#endif // CPROVER_CPP_CPP_LINKAGE_SPEC_H
