@@ -6,23 +6,15 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#include <ostream>
+/// \file
+/// C++ Language Type Checking
 
 #include "cpp_namespace_spec.h"
+
+#include <ostream>
+
 #include "cpp_item.h"
 
-/*******************************************************************\
-
-Function: cpp_namespace_spect::output
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void cpp_namespace_spect::output(std::ostream &out) const
 {
   out << "  namespace: " << get_namespace() << "\n";
