@@ -6,11 +6,16 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#ifndef CPROVER_CPP_PARSE_TREE_H
-#define CPROVER_CPP_PARSE_TREE_H
+/// \file
+/// C++ Parser
+
+#ifndef CPROVER_CPP_CPP_PARSE_TREE_H
+#define CPROVER_CPP_CPP_PARSE_TREE_H
 
 #include "cpp_item.h"
 
+#include <list>
+
 class cpp_parse_treet
 {
 public:
@@ -23,4 +28,4 @@ public:
   void clear();
 };
 
-#endif
+#endif // CPROVER_CPP_CPP_PARSE_TREE_H
