@@ -6,24 +6,15 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#include <util/config.h>
+/// \file
+/// C++ Parser
 
 #include "cpp_parser.h"
 
+#include <util/config.h>
+
 cpp_parsert cpp_parser;
 
-/*******************************************************************\
-
-Function: cpp_parsert::parse
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bool cpp_parse();
 
 bool cpp_parsert::parse()
@@ -33,6 +24,8 @@ bool cpp_parsert::parse()
   ansi_c_parser.cpp11=
     config.cpp.cpp_standard==configt::cppt::cpp_standardt::CPP11 ||
     config.cpp.cpp_standard==configt::cppt::cpp_standardt::CPP14;
+  ansi_c_parser.ts_18661_3_Floatn_types=false;
+  ansi_c_parser.Float128_type = false;
   ansi_c_parser.in=in;
   ansi_c_parser.mode=mode;
   ansi_c_parser.set_file(get_file());
@@ -40,4 +33,3 @@ bool cpp_parsert::parse()
 
   return cpp_parse();
 }
-
