@@ -6,8 +6,9 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#ifndef CPROVER_CPP_TEMPLATE_PARAMETER_H
-#define CPROVER_CPP_TEMPLATE_PARAMETER_H
+
+#ifndef CPROVER_CPP_CPP_TEMPLATE_PARAMETER_H
+#define CPROVER_CPP_CPP_TEMPLATE_PARAMETER_H
 
 #include <util/expr.h>
 
@@ -22,7 +23,7 @@ public:
   {
   }
 
-  #if 0  
+  #if 0
   bool get_is_type() const
   {
     return get_bool(ID_is_type);
@@ -32,12 +33,12 @@ public:
   {
     set(ID_is_type, value);
   }
-  
+
   irep_idt get_identifier() const
   {
     return get(ID_identifier);
   }
-  
+
   void set_identifier(const irep_idt &identifier)
   {
     return set(ID_identifier, identifier);
@@ -55,20 +56,20 @@ public:
   }
   #endif
 
-  inline exprt &default_argument()
+  exprt &default_argument()
   {
     return static_cast<exprt &>(add(ID_C_default_value));
   }
 
-  inline const exprt &default_argument() const
+  const exprt &default_argument() const
   {
     return static_cast<const exprt &>(find(ID_C_default_value));
   }
-  
+
   bool has_default_argument() const
   {
     return find(ID_C_default_value).is_not_nil();
   }
 };
 
-#endif
+#endif // CPROVER_CPP_CPP_TEMPLATE_PARAMETER_H
