@@ -338,13 +338,10 @@ protected:
   };
 
   typedef std::list<method_bodyt> method_bodiest;
+  std::set<irep_idt> methods_seen;
   method_bodiest method_bodies;
 
-  void add_method_body(symbolt *_method_symbol)
-  {
-    method_bodies.push_back(method_bodyt(
-      _method_symbol, template_map, instantiation_stack));
-  }
+  void add_method_body(symbolt *_method_symbol);
 
   bool builtin_factory(const irep_idt &);
 
@@ -382,9 +379,9 @@ protected:
 
   void put_compound_into_scope(const struct_union_typet::componentt &component);
   void typecheck_compound_body(symbolt &symbol);
-  void typecheck_compound_body(struct_union_typet &type) { UNREACHABLE; }
+  void typecheck_compound_body(struct_union_typet &) { UNREACHABLE; }
   void typecheck_enum_body(symbolt &symbol);
-  void typecheck_method_bodies(method_bodiest &);
+  void typecheck_method_bodies();
   void typecheck_compound_bases(struct_typet &type);
   void add_anonymous_members_to_scope(const symbolt &struct_union_symbol);
 
@@ -432,7 +429,6 @@ protected:
 
   codet cpp_destructor(
       const source_locationt &source_location,
-      const typet &type,
       const exprt &object);
 
   // expressions
@@ -591,6 +587,8 @@ public:
     exprt &new_expr,
     bool check_constantness=true);
 
+  bool contains_cpp_name(const exprt &expr);
+
 private:
   typedef std::list<irep_idt> dynamic_initializationst;
   dynamic_initializationst dynamic_initializations;
