@@ -432,6 +432,7 @@ bool cpp_typecheckt::overloadable(const exprt &expr)
       t=t.subtype();
 
     if(t.id()==ID_struct ||
+       t.id() == ID_incomplete_struct ||
        t.id()==ID_union ||
        t.id()==ID_c_enum || t.id() == ID_c_enum_tag)
       return true;
@@ -602,6 +603,7 @@ bool cpp_typecheckt::operator_is_overloaded(exprt &expr)
       // We try and fail silently, maybe conversions will work
       // instead.
 
+      // TODO: need to resolve an incomplete struct (template) here
       // go into scope of first operand
       if(expr.op0().type().id()==ID_symbol &&
          follow(expr.op0().type()).id()==ID_struct)
@@ -1073,7 +1075,6 @@ void cpp_typecheckt::typecheck_expr_delete(exprt &expr)
 
   codet destructor_code=cpp_destructor(
     expr.source_location(),
-    pointer_type.subtype(),
     new_object);
 
   // this isn't typechecked yet
@@ -1083,7 +1084,7 @@ void cpp_typecheckt::typecheck_expr_delete(exprt &expr)
   expr.set(ID_destructor, destructor_code);
 }
 
-void cpp_typecheckt::typecheck_expr_typecast(exprt &expr)
+void cpp_typecheckt::typecheck_expr_typecast(exprt &)
 {
   // should not be called
   #if 0
@@ -1968,10 +1969,10 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
     if(expr.arguments().empty())
     {
       // create temporary object
-      side_effect_exprt tmp_object_expr(ID_temporary_object, pod);
+      side_effect_exprt tmp_object_expr(
+        ID_temporary_object, pod, expr.source_location());
       tmp_object_expr.set(ID_C_lvalue, true);
       tmp_object_expr.set(ID_mode, ID_cpp);
-      tmp_object_expr.add_source_location()=expr.source_location();
       expr.swap(tmp_object_expr);
     }
     else if(expr.arguments().size()==1)
@@ -2016,8 +2017,8 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
   {
     if(expr.function().type().find("to-member").is_not_nil())
     {
-      const exprt &bound=
-        static_cast<const exprt &>(expr.function().type().find("#bound"));
+      const exprt &bound =
+        static_cast<const exprt &>(expr.function().type().find(ID_C_bound));
 
       if(bound.is_nil())
       {
@@ -2031,7 +2032,7 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
       expr.arguments().insert(expr.arguments().begin(), bound);
 
       // we don't need the object any more
-      expr.function().type().remove("#bound");
+      expr.function().type().remove(ID_C_bound);
     }
 
     // do implicit dereference
@@ -2059,8 +2060,7 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
   }
   else if(expr.function().type().id()==ID_code)
   {
-    if(expr.function().type().get_bool("#is_virtual") &&
-       !is_qualified)
+    if(expr.function().type().get_bool(ID_C_is_virtual) && !is_qualified)
     {
       exprt vtptr_member;
       if(op0.id()==ID_member || op0.id()==ID_ptrmember)
@@ -2092,9 +2092,9 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
       vtptr_member.set(ID_component_name, vtable_name);
 
       // look for the right entry
-      irep_idt vtentry_component_name=
-        vt_compo.type().subtype().get_string(ID_identifier)+"::"+
-        expr.function().type().get_string("#virtual_name");
+      irep_idt vtentry_component_name =
+        vt_compo.type().subtype().get_string(ID_identifier) +
+        "::" + expr.function().type().get_string(ID_C_virtual_name);
 
       exprt vtentry_member(ID_ptrmember);
       vtentry_member.copy_to_operands(vtptr_member);
@@ -2171,10 +2171,10 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
     expr.type()=this_type.subtype();
 
     // create temporary object
-    side_effect_exprt tmp_object_expr(ID_temporary_object, this_type.subtype());
+    side_effect_exprt tmp_object_expr(
+      ID_temporary_object, this_type.subtype(), expr.source_location());
     tmp_object_expr.set(ID_C_lvalue, true);
     tmp_object_expr.set(ID_mode, ID_cpp);
-    tmp_object_expr.add_source_location()=expr.source_location();
 
     exprt member;
 
@@ -2189,10 +2189,10 @@ void cpp_typecheckt::typecheck_side_effect_function_call(
                   member);
 
     // special case for the initialization of parents
-    if(member.get_bool("#not_accessible"))
+    if(member.get_bool(ID_C_not_accessible))
     {
       assert(member.get(ID_C_access)!="");
-      tmp_object_expr.set("#not_accessible", true);
+      tmp_object_expr.set(ID_C_not_accessible, true);
       tmp_object_expr.set(ID_C_access, member.get(ID_C_access));
     }
 
@@ -2306,7 +2306,7 @@ void cpp_typecheckt::typecheck_function_call_arguments(
   exprt::operandst::iterator arg_it=expr.arguments().begin();
   for(const auto &parameter : parameters)
   {
-    if(parameter.get_bool("#call_by_value"))
+    if(parameter.get_bool(ID_C_call_by_value))
     {
       assert(is_reference(parameter.type()));
 
@@ -2381,14 +2381,34 @@ void cpp_typecheckt::typecheck_method_application(
   member_expr.swap(expr.function());
 
   const symbolt &symbol=lookup(member_expr.get(ID_component_name));
-  add_method_body(&symbol_table.get_writeable_ref(symbol.name));
+  symbolt &method_symbol=symbol_table.get_writeable_ref(symbol.name);
+  const symbolt &tag_symbol = lookup(symbol.type.get(ID_C_member_name));
+
+  // build the right template map
+  // if this is an instantiated template class method
+  if(tag_symbol.type.find(ID_C_template)!=irept())
+  {
+    cpp_saved_template_mapt saved_map(template_map);
+    const irept &template_type = tag_symbol.type.find(ID_C_template);
+    const irept &template_args = tag_symbol.type.find(ID_C_template_arguments);
+    template_map.build(
+      static_cast<const template_typet &>(template_type),
+      static_cast<const cpp_template_args_tct &>(template_args));
+    add_method_body(&method_symbol);
+#ifdef DEBUG
+    std::cout << "MAP for " << symbol << ":" << std::endl;
+    template_map.print(std::cout);
+#endif
+  }
+  else
+    add_method_body(&method_symbol);
 
   // build new function expression
   exprt new_function(cpp_symbol_expr(symbol));
   new_function.add_source_location()=member_expr.source_location();
   expr.function().swap(new_function);
 
-  if(!expr.function().type().get_bool("#is_static"))
+  if(!expr.function().type().get_bool(ID_C_is_static))
   {
     const code_typet &func_type=to_code_type(symbol.type);
     typet this_type=func_type.parameters().front().type();
@@ -2396,7 +2416,7 @@ void cpp_typecheckt::typecheck_method_application(
     // Special case. Make it a reference.
     assert(this_type.id()==ID_pointer);
     this_type.set(ID_C_reference, true);
-    this_type.set("#this", true);
+    this_type.set(ID_C_this, true);
 
     if(expr.arguments().size()==func_type.parameters().size())
     {
@@ -2669,7 +2689,7 @@ void cpp_typecheckt::convert_pmop(exprt &expr)
   }
 
   exprt tmp(expr.op1());
-  tmp.type().set("#bound", expr.op0());
+  tmp.type().set(ID_C_bound, expr.op0());
   expr.swap(tmp);
   return;
 }
@@ -2693,8 +2713,7 @@ void cpp_typecheckt::typecheck_expr_function_identifier(exprt &expr)
 
 void cpp_typecheckt::typecheck_expr(exprt &expr)
 {
-  bool override_constantness=
-    expr.get_bool("#override_constantness");
+  bool override_constantness = expr.get_bool(ID_C_override_constantness);
 
   // We take care of an ambiguity in the C++ grammar.
   // Needs to be done before the operands!
