@@ -6,29 +6,17 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#include <util/i2string.h>
-#include <util/identifier.h>
-#include <util/expr_util.h>
+/// \file
+/// C++ Language Type Checking
+
+#include "cpp_typecheck.h"
 
 #include <ansi-c/c_qualifiers.h>
 
 #include "cpp_template_type.h"
-#include "cpp_typecheck.h"
 #include "cpp_type2name.h"
 #include "cpp_util.h"
 
-/*******************************************************************\
-
-Function: cpp_typecheckt::convert_parameter
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void cpp_typecheckt::convert_parameter(
   const irep_idt &mode,
   code_typet::parametert &parameter)
@@ -37,7 +25,7 @@ void cpp_typecheckt::convert_parameter(
 
   if(base_name.empty())
   {
-    base_name="#anon_arg"+i2string(anon_counter++);
+    base_name="#anon_arg"+std::to_string(anon_counter++);
     parameter.set_base_name(base_name);
   }
 
@@ -46,6 +34,11 @@ void cpp_typecheckt::convert_parameter(
 
   parameter.set_identifier(identifier);
 
+  // the parameter may already have been set up if dealing with virtual methods
+  const symbolt *check_symbol;
+  if(!lookup(identifier, check_symbol))
+    return;
+
   symbolt symbol;
 
   symbol.name=identifier;
@@ -56,8 +49,9 @@ void cpp_typecheckt::convert_parameter(
   symbol.type=parameter.type();
   symbol.is_state_var=true;
   symbol.is_lvalue=!is_reference(symbol.type);
+  symbol.is_parameter=true;
 
-  assert(!symbol.base_name.empty());
+  INVARIANT(!symbol.base_name.empty(), "parameter has base name");
 
   symbolt *new_symbol;
 
@@ -73,18 +67,6 @@ void cpp_typecheckt::convert_parameter(
   cpp_scopes.put_into_scope(*new_symbol);
 }
 
-/*******************************************************************\
-
-Function: cpp_typecheckt::convert_parameters
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void cpp_typecheckt::convert_parameters(
   const irep_idt &mode,
   code_typet &function_type)
@@ -99,18 +81,6 @@ void cpp_typecheckt::convert_parameters(
     convert_parameter(mode, *it);
 }
 
-/*******************************************************************\
-
-Function: cpp_typecheckt::convert_function
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void cpp_typecheckt::convert_function(symbolt &symbol)
 {
   code_typet &function_type=
@@ -128,7 +98,12 @@ void cpp_typecheckt::convert_function(symbolt &symbol)
     assert(symbol.value.id()==ID_code);
     assert(symbol.value.get(ID_statement)==ID_block);
 
-    symbol.value.copy_to_operands(dtor(msymb));
+    if(
+      !symbol.value.has_operands() || !symbol.value.op0().has_operands() ||
+      symbol.value.op0().op0().id() != ID_already_typechecked)
+    {
+      symbol.value.copy_to_operands(dtor(msymb));
+    }
   }
 
   // enter appropriate scope
@@ -149,7 +124,8 @@ void cpp_typecheckt::convert_function(symbolt &symbol)
     assert(parameters.size()>=1);
     code_typet::parametert &this_parameter_expr=parameters.front();
     function_scope.this_expr=exprt(ID_symbol, this_parameter_expr.type());
-    function_scope.this_expr.set(ID_identifier, this_parameter_expr.get(ID_C_identifier));
+    function_scope.this_expr.set(
+      ID_identifier, this_parameter_expr.get(ID_C_identifier));
   }
   else
     function_scope.this_expr.make_nil();
@@ -166,26 +142,15 @@ void cpp_typecheckt::convert_function(symbolt &symbol)
   if(return_type.id()==ID_constructor ||
      return_type.id()==ID_destructor)
     return_type=empty_typet();
-  
+
   typecheck_code(to_code(symbol.value));
 
   symbol.value.type()=symbol.type;
-  
+
   return_type = old_return_type;
 }
 
-/*******************************************************************\
-
-Function: cpp_typecheckt::function_identifier
-
-  Inputs:
-
- Outputs:
-
- Purpose: for function overloading
-
-\*******************************************************************/
-
+/// for function overloading
 irep_idt cpp_typecheckt::function_identifier(const typet &type)
 {
   const code_typet &function_type=
@@ -212,8 +177,10 @@ irep_idt cpp_typecheckt::function_identifier(const typet &type)
   {
     const typet &pointer=it->type();
     const typet &symbol =pointer.subtype();
-    if(symbol.get_bool(ID_C_constant)) result+="const$";
-    if(symbol.get_bool(ID_C_volatile)) result+="volatile$";
+    if(symbol.get_bool(ID_C_constant))
+      result += "$const";
+    if(symbol.get_bool(ID_C_volatile))
+      result += "$volatile";
     result+="this";
     first=false;
     it++;
@@ -223,7 +190,10 @@ irep_idt cpp_typecheckt::function_identifier(const typet &type)
 
   for(; it!=parameters.end(); it++)
   {
-    if(first) first=false; else result+=',';
+    if(first)
+      first=false;
+    else
+      result+=',';
     typet tmp_type=it->type();
     result+=cpp_type2name(it->type());
   }
