@@ -11,6 +11,10 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 #include "cpp_typecheck_resolve.h"
 
+#ifdef DEBUG
+#include <iostream>
+#endif
+
 #include <cstdlib>
 #include <algorithm>
 
@@ -37,7 +41,6 @@ cpp_typecheck_resolvet::cpp_typecheck_resolvet(cpp_typecheckt &_cpp_typecheck):
 
 void cpp_typecheck_resolvet::convert_identifiers(
   const cpp_scopest::id_sett &id_set,
-  const wantt want,
   const cpp_typecheck_fargst &fargs,
   resolve_identifierst &identifiers)
 {
@@ -47,7 +50,7 @@ void cpp_typecheck_resolvet::convert_identifiers(
       it++)
   {
     const cpp_idt &identifier=**it;
-    exprt e=convert_identifier(identifier, want, fargs);
+    exprt e=convert_identifier(identifier, fargs);
 
     if(e.is_not_nil())
     {
@@ -190,6 +193,11 @@ void cpp_typecheck_resolvet::remove_duplicates(
 exprt cpp_typecheck_resolvet::convert_template_parameter(
   const cpp_idt &identifier)
 {
+#ifdef DEBUG
+  std::cout << "RESOLVE MAP:" << std::endl;
+  cpp_typecheck.template_map.print(std::cout);
+#endif
+
   // look up the parameter in the template map
   exprt e=cpp_typecheck.template_map.lookup(identifier.identifier);
 
@@ -210,7 +218,6 @@ exprt cpp_typecheck_resolvet::convert_template_parameter(
 
 exprt cpp_typecheck_resolvet::convert_identifier(
   const cpp_idt &identifier,
-  const wantt want,
   const cpp_typecheck_fargst &fargs)
 {
   if(identifier.id_class==cpp_scopet::id_classt::TEMPLATE_PARAMETER)
@@ -670,8 +677,23 @@ void cpp_typecheck_resolvet::make_constructors(
   identifiers.swap(new_identifiers);
 }
 
+void cpp_typecheck_resolvet::resolve_argument(
+  exprt &argument,
+  const cpp_typecheck_fargst &fargs)
+{
+  if(argument.id()=="ambiguous") // could come from a template parameter
+  {
+    // this must be resolved in the template scope
+    cpp_save_scopet save_scope(cpp_typecheck.cpp_scopes);
+    cpp_typecheck.cpp_scopes.go_to(*original_scope);
+
+    argument = resolve(to_cpp_name(argument.type()), wantt::VAR, fargs, false);
+  }
+}
+
 exprt cpp_typecheck_resolvet::do_builtin(
   const irep_idt &base_name,
+  const cpp_typecheck_fargst &fargs,
   const cpp_template_args_non_tct &template_args)
 {
   exprt dest;
@@ -691,7 +713,7 @@ exprt cpp_typecheck_resolvet::do_builtin(
       throw 0;
     }
 
-    const exprt &argument=arguments.front();
+    exprt argument=arguments.front(); // copy
 
     if(argument.id()==ID_type)
     {
@@ -702,6 +724,8 @@ exprt cpp_typecheck_resolvet::do_builtin(
       throw 0;
     }
 
+    resolve_argument(argument, fargs);
+
     mp_integer i;
     if(to_integer(argument, i))
     {
@@ -734,8 +758,10 @@ exprt cpp_typecheck_resolvet::do_builtin(
       throw 0;
     }
 
-    const exprt &argument0=arguments[0];
-    const exprt &argument1=arguments[1];
+    exprt argument0=arguments[0];
+    resolve_argument(argument0, fargs);
+    exprt argument1=arguments[1];
+    resolve_argument(argument1, fargs);
 
     if(argument0.id()==ID_type)
     {
@@ -903,12 +929,13 @@ cpp_scopet &cpp_typecheck_resolvet::resolve_scope(
           cpp_idt::id_classt::TEMPLATE,
           id_set);
 
-        // std::cout << "S: "
-        //           << cpp_typecheck.cpp_scopes.current_scope().identifier
-        //           << '\n';
-        // cpp_typecheck.cpp_scopes.current_scope().print(std::cout);
-        // std::cout << "X: " << id_set.size() << '\n';
-
+#ifdef DEBUG
+        std::cout << "S: "
+                  << cpp_typecheck.cpp_scopes.current_scope().identifier
+                  << '\n';
+        cpp_typecheck.cpp_scopes.current_scope().print(std::cout);
+        std::cout << "X: " << id_set.size() << '\n';
+#endif
         symbol_typet instance=
           disambiguate_template_classes(final_base_name, id_set, template_args);
 
@@ -1382,6 +1409,14 @@ exprt cpp_typecheck_resolvet::resolve(
   // this changes the scope
   resolve_scope(cpp_name, base_name, template_args);
 
+#ifdef DEBUG
+  std::cout << "base name: " << base_name << std::endl;
+  std::cout << "template args: " << template_args.pretty() << std::endl;
+  std::cout << "original-scope: " << original_scope->prefix << std::endl;
+  std::cout << "scope: "
+            << cpp_typecheck.cpp_scopes.current_scope().prefix << std::endl;
+#endif
+
   const source_locationt &source_location=cpp_name.source_location();
   bool qualified=cpp_name.is_qualified();
 
@@ -1389,7 +1424,7 @@ exprt cpp_typecheck_resolvet::resolve(
   if(qualified)
   {
     if(cpp_typecheck.cpp_scopes.current_scope().identifier=="__CPROVER")
-      return do_builtin(base_name, template_args);
+      return do_builtin(base_name, fargs, template_args);
   }
   else
   {
@@ -1510,13 +1545,16 @@ exprt cpp_typecheck_resolvet::resolve(
     {
       typet instance=
         disambiguate_template_classes(base_name, id_set, template_args);
+
+      cpp_typecheck.elaborate_class_template(instance);
+
       identifiers.push_back(exprt(ID_type, instance));
     }
     else
     {
       // methods and functions
       convert_identifiers(
-        id_set, want, fargs, identifiers);
+        id_set, fargs, identifiers);
 
       apply_template_args(
         identifiers, template_args, fargs);
@@ -1525,7 +1563,7 @@ exprt cpp_typecheck_resolvet::resolve(
   else
   {
     convert_identifiers(
-      id_set, want, fargs, identifiers);
+      id_set, fargs, identifiers);
   }
 
   // change types into constructors if we want a constructor
@@ -1659,7 +1697,7 @@ exprt cpp_typecheck_resolvet::resolve(
   }
 
   // we do some checks before we return
-  if(result.get_bool("#not_accessible"))
+  if(result.get_bool(ID_C_not_accessible))
   {
     #if 0
     if(!fail_with_exception)
@@ -2185,8 +2223,9 @@ bool cpp_typecheck_resolvet::disambiguate_functions(
       }
       else
       {
-        if(expr.type().get_bool("#is_operator") &&
-           fargs.operands.size() == parameters.size())
+        if(
+          expr.type().get_bool(ID_C_is_operator) &&
+          fargs.operands.size() == parameters.size())
         {
           return fargs.match(type, args_distance, cpp_typecheck);
         }
