@@ -6,29 +6,23 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
+/// \file
+/// C++ Language Type Checking
+
+#include "cpp_typecheck.h"
+
 #include <util/source_location.h>
+#include <util/simplify_expr.h>
+#include <util/c_types.h>
 
 #include <ansi-c/c_qualifiers.h>
 
-#include "cpp_typecheck.h"
 #include "cpp_convert_type.h"
 #include "expr2cpp.h"
 
-/*******************************************************************\
-
-Function: cpp_typecheckt::typecheck_type
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void cpp_typecheckt::typecheck_type(typet &type)
 {
-  assert(type.id()!=irep_idt());
+  assert(!type.id().empty());
   assert(type.is_not_nil());
 
   try
@@ -59,7 +53,7 @@ void cpp_typecheckt::typecheck_type(typet &type)
 
     exprt symbol_expr=resolve(
       cpp_name,
-      cpp_typecheck_resolvet::TYPE,
+      cpp_typecheck_resolvet::wantt::TYPE,
       cpp_typecheck_fargst());
 
     if(symbol_expr.id()!=ID_type)
@@ -68,7 +62,7 @@ void cpp_typecheckt::typecheck_type(typet &type)
       error() << "error: expected type" << eom;
       throw 0;
     }
-    
+
     type=symbol_expr.type();
     assert(type.is_not_nil());
 
@@ -84,7 +78,10 @@ void cpp_typecheckt::typecheck_type(typet &type)
   }
   else if(type.id()==ID_pointer)
   {
-    // the pointer might have a qualifier, but do subtype first
+    c_qualifierst qualifiers(type);
+
+    // the pointer/reference might have a qualifier,
+    // but do subtype first
     typecheck_type(type.subtype());
 
     // Check if it is a pointer-to-member
@@ -114,19 +111,26 @@ void cpp_typecheckt::typecheck_type(typet &type)
           // Add 'this' to the parameters
           exprt a0(ID_parameter);
           a0.set(ID_C_base_name, ID_this);
-          a0.type().id(ID_pointer);
-          a0.type().subtype() = class_object;
+          a0.type()=pointer_type(class_object);
           parameters.insert(parameters.begin(), a0);
         }
       }
     }
+
+    if(type.get_bool(ID_C_constant))
+      qualifiers.is_constant = true;
+
+    qualifiers.write(type);
   }
   else if(type.id()==ID_array)
   {
     exprt &size_expr=to_array_type(type).size();
 
     if(size_expr.is_not_nil())
+    {
       typecheck_expr(size_expr);
+      simplify(size_expr, *this);
+    }
 
     typecheck_type(type.subtype());
 
@@ -136,6 +140,10 @@ void cpp_typecheckt::typecheck_type(typet &type)
     if(type.subtype().get_bool(ID_C_volatile))
       type.set(ID_C_volatile, true);
   }
+  else if(type.id()==ID_vector)
+  {
+    typecheck_vector_type(to_vector_type(type));
+  }
   else if(type.id()==ID_code)
   {
     code_typet &code_type=to_code_type(type);
@@ -143,15 +151,15 @@ void cpp_typecheckt::typecheck_type(typet &type)
 
     code_typet::parameterst &parameters=code_type.parameters();
 
-    for(auto & it : parameters)
+    for(auto &param : parameters)
     {
-      typecheck_type(it.type());
+      typecheck_type(param.type());
 
       // see if there is a default value
-      if(it.has_default_value())
+      if(param.has_default_value())
       {
-        typecheck_expr(it.default_value());
-        implicit_typecast(it.default_value(), it.type());
+        typecheck_expr(param.default_value());
+        implicit_typecast(param.default_value(), param.type());
       }
     }
   }
@@ -209,7 +217,7 @@ void cpp_typecheckt::typecheck_type(typet &type)
 
         exprt symbol_expr=resolve(
           to_cpp_name(static_cast<const irept &>(tmp_type)),
-          cpp_typecheck_resolvet::BOTH,
+          cpp_typecheck_resolvet::wantt::BOTH,
           fargs);
 
         type=symbol_expr.type();
@@ -230,7 +238,11 @@ void cpp_typecheckt::typecheck_type(typet &type)
   {
     exprt e=static_cast<const exprt &>(type.find(ID_expr_arg));
     typecheck_expr(e);
-    type=e.type();
+
+    if(e.type().id() == ID_c_bit_field)
+      type = e.type().subtype();
+    else
+      type = e.type();
   }
   else if(type.id()==ID_unassigned)
   {
@@ -244,16 +256,23 @@ void cpp_typecheckt::typecheck_type(typet &type)
   {
     // This is an Apple extension for lambda-like constructs.
     // http://thirdcog.eu/pwcblocks/
+    // we just treat them as references to functions
+    type.id(ID_frontend_pointer);
+    typecheck_type(type);
   }
   else if(type.id()==ID_nullptr)
   {
   }
+  else if(type.id()==ID_already_typechecked)
+  {
+    c_typecheck_baset::typecheck_type(type);
+  }
   else
   {
     error().source_location=type.source_location();
     error() << "unexpected cpp type: " << type.pretty() << eom;
     throw 0;
   }
-  
+
   assert(type.is_not_nil());
 }
