@@ -6,66 +6,45 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
+#include "expr2cpp.h"
+
 #include <cassert>
 
 #include <util/std_types.h>
 #include <util/std_expr.h>
 #include <util/symbol.h>
-#include <util/hash_cont.h>
-#include <util/c_misc.h>
 #include <util/lispirep.h>
 #include <util/lispexpr.h>
+#include <util/namespace.h>
 
+#include <ansi-c/c_misc.h>
+#include <ansi-c/c_qualifiers.h>
 #include <ansi-c/expr2c_class.h>
 
-#include "expr2cpp.h"
-
 class expr2cppt:public expr2ct
 {
 public:
-  expr2cppt(const namespacet &_ns):expr2ct(_ns) { }
-
-  virtual std::string convert(const exprt &src)
-  {
-    return expr2ct::convert(src);
-  }
-
-  virtual std::string convert(const typet &src)
-  {
-    return expr2ct::convert(src);
-  }
+  explicit expr2cppt(const namespacet &_ns):expr2ct(_ns) { }
 
 protected:
-  virtual std::string convert(const exprt &src, unsigned &precedence);
-  virtual std::string convert_cpp_this(const exprt &src, unsigned precedence);
-  virtual std::string convert_cpp_new(const exprt &src, unsigned precedence);
-  virtual std::string convert_extractbit(const exprt &src, unsigned precedence);
-  virtual std::string convert_extractbits(const exprt &src, unsigned precedence);
-  virtual std::string convert_code_cpp_delete(const exprt &src, unsigned precedence);
-  virtual std::string convert_struct(const exprt &src, unsigned &precedence);
-  virtual std::string convert_code(const codet &src, unsigned indent);
-  virtual std::string convert_constant(const constant_exprt &src, unsigned &precedence);
+  std::string convert_with_precedence(
+    const exprt &src, unsigned &precedence) override;
+  std::string convert_cpp_this(const exprt &src, unsigned precedence);
+  std::string convert_cpp_new(const exprt &src, unsigned precedence);
+  std::string convert_extractbit(const exprt &src, unsigned precedence);
+  std::string convert_extractbits(const exprt &src, unsigned precedence);
+  std::string convert_code_cpp_delete(const exprt &src, unsigned precedence);
+  std::string convert_struct(const exprt &src, unsigned &precedence) override;
+  std::string convert_code(const codet &src, unsigned indent) override;
+  // NOLINTNEXTLINE(whitespace/line_length)
+  std::string convert_constant(const constant_exprt &src, unsigned &precedence) override;
 
-  virtual std::string convert_rec(
+  std::string convert_rec(
     const typet &src,
-    const c_qualifierst &qualifiers,
-    const std::string &declarator);
-
-  typedef hash_set_cont<std::string, string_hash> id_sett;
+    const qualifierst &qualifiers,
+    const std::string &declarator) override;
 };
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_struct
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_struct(
   const exprt &src,
   unsigned &precedence)
@@ -130,18 +109,6 @@ std::string expr2cppt::convert_struct(
   return dest;
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_constant
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_constant(
   const constant_exprt &src,
   unsigned &precedence)
@@ -158,29 +125,18 @@ std::string expr2cppt::convert_constant(
   return expr2ct::convert_constant(src, precedence);
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_rec
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_rec(
   const typet &src,
-  const c_qualifierst &qualifiers,
+  const qualifierst &qualifiers,
   const std::string &declarator)
 {
-  c_qualifierst new_qualifiers(qualifiers);
+  std::unique_ptr<qualifierst> clone = qualifiers.clone();
+  qualifierst &new_qualifiers = *clone;
   new_qualifiers.read(src);
-  
+
   const std::string d=
     declarator==""?declarator:(" "+declarator);
-    
+
   const std::string q=
     new_qualifiers.as_string();
 
@@ -192,7 +148,7 @@ std::string expr2cppt::convert_rec(
   {
     return q+convert(src.subtype())+" &&"+d;
   }
-  else if(src.get(ID_C_c_type)!=irep_idt())
+  else if(!src.get(ID_C_c_type).empty())
   {
     const irep_idt c_type=src.get(ID_C_c_type);
 
@@ -242,7 +198,7 @@ std::string expr2cppt::convert_rec(
        symbol.type.id()==ID_incomplete_struct)
     {
       std::string dest=q;
-      
+
       if(symbol.type.get_bool(ID_C_class))
         dest+="class";
       else if(symbol.type.get_bool(ID_C_interface))
@@ -250,7 +206,7 @@ std::string expr2cppt::convert_rec(
       else
         dest+="struct";
 
-      if(symbol.pretty_name!=irep_idt())
+      if(!symbol.pretty_name.empty())
         dest+=" "+id2string(symbol.pretty_name);
 
       dest+=d;
@@ -263,7 +219,7 @@ std::string expr2cppt::convert_rec(
 
       dest+="enum";
 
-      if(symbol.pretty_name!=irep_idt())
+      if(!symbol.pretty_name.empty())
         dest+=" "+id2string(symbol.pretty_name);
 
       dest+=d;
@@ -309,7 +265,8 @@ std::string expr2cppt::convert_rec(
 
     forall_irep(it, arguments)
     {
-      if(it!=arguments.begin()) dest+=", ";
+      if(it!=arguments.begin())
+        dest+=", ";
 
       const exprt &argument=(const exprt &)*it;
 
@@ -342,26 +299,27 @@ std::string expr2cppt::convert_rec(
     typet member;
     member.swap(tmp.add("to-member"));
 
-    std::string dest = "(" + convert_rec(member, c_qualifierst(), "") + ":: *)";
+    std::string dest="("+convert_rec(member, c_qualifierst(), "")+":: *)";
 
     if(src.subtype().id()==ID_code)
     {
-      const code_typet& code_type = to_code_type(src.subtype());
-      const typet& return_type = code_type.return_type();
-      dest = convert_rec(return_type, c_qualifierst(), "") +" " + dest;
+      const code_typet &code_type = to_code_type(src.subtype());
+      const typet &return_type = code_type.return_type();
+      dest=convert_rec(return_type, c_qualifierst(), "")+" "+dest;
 
       const code_typet::parameterst &args = code_type.parameters();
-      dest += "(";
+      dest+="(";
 
       for(code_typet::parameterst::const_iterator it=args.begin();
           it!=args.end();
           ++it)
       {
-        if(it!=args.begin()) dest+=", ";
+        if(it!=args.begin())
+          dest+=", ";
         dest+=convert_rec(it->type(), c_qualifierst(), "");
       }
 
-      dest += ")";
+      dest+=")";
       dest+=d;
     }
     else
@@ -380,9 +338,9 @@ std::string expr2cppt::convert_rec(
 
     // C doesn't really have syntax for function types,
     // so we use C++11 trailing return types!
-  
+
     std::string dest="auto";
-    
+
     // qualifiers, declarator?
     if(d.empty())
       dest+=' ';
@@ -402,15 +360,16 @@ std::string expr2cppt::convert_rec(
 
       dest+=convert(it->type());
     }
-    
+
     if(code_type.has_ellipsis())
     {
-      if(!parameters.empty()) dest+=", ";
+      if(!parameters.empty())
+        dest+=", ";
       dest+="...";
     }
 
     dest+=')';
-    
+
     const typet &return_type=code_type.return_type();
     dest+=" -> "+convert(return_type);
 
@@ -425,18 +384,6 @@ std::string expr2cppt::convert_rec(
     return expr2ct::convert_rec(src, qualifiers, declarator);
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_cpp_this
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_cpp_this(
   const exprt &src,
   unsigned precedence)
@@ -444,18 +391,6 @@ std::string expr2cppt::convert_cpp_this(
   return "this";
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_cpp_new
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_cpp_new(
   const exprt &src,
   unsigned precedence)
@@ -481,18 +416,6 @@ std::string expr2cppt::convert_cpp_new(
   return dest;
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_code_cpp_delete
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_code_cpp_delete(
   const exprt &src,
   unsigned indent)
@@ -512,19 +435,7 @@ std::string expr2cppt::convert_code_cpp_delete(
   return dest;
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
-std::string expr2cppt::convert(
+std::string expr2cppt::convert_with_precedence(
   const exprt &src,
   unsigned &precedence)
 {
@@ -541,10 +452,10 @@ std::string expr2cppt::convert(
   else if(src.id()==ID_side_effect &&
           src.get(ID_statement)==ID_throw)
     return convert_function(src, "throw", precedence=16);
-  else if(src.is_constant() && src.type().id() == ID_verilog_signedbv)
-    return "'" + id2string(src.get(ID_value)) + "'";
-  else if(src.is_constant() && src.type().id() == ID_verilog_unsignedbv)
-    return "'" + id2string(src.get(ID_value)) + "'";
+  else if(src.is_constant() && src.type().id()==ID_verilog_signedbv)
+    return "'"+id2string(src.get(ID_value))+"'";
+  else if(src.is_constant() && src.type().id()==ID_verilog_unsignedbv)
+    return "'"+id2string(src.get(ID_value))+"'";
   else if(src.is_constant() && to_constant_expr(src).get_value()==ID_nullptr)
     return "nullptr";
   else if(src.id()==ID_unassigned)
@@ -552,21 +463,9 @@ std::string expr2cppt::convert(
   else if(src.id()=="pod_constructor")
     return "pod_constructor";
   else
-    return expr2ct::convert(src, precedence);
+    return expr2ct::convert_with_precedence(src, precedence);
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_code
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_code(
   const codet &src,
   unsigned indent)
@@ -579,64 +478,29 @@ std::string expr2cppt::convert_code(
 
   if(statement==ID_cpp_new ||
      statement==ID_cpp_new_array)
-    return convert_cpp_new(src,indent);
+    return convert_cpp_new(src, indent);
 
   return expr2ct::convert_code(src, indent);
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_extractbit
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_extractbit(
   const exprt &src,
   unsigned precedence)
 {
-  assert(src.operands().size() == 2);
-  return convert(src.op0()) + "[" + convert(src.op1()) + "]";
+  assert(src.operands().size()==2);
+  return convert(src.op0())+"["+convert(src.op1())+"]";
 }
 
-/*******************************************************************\
-
-Function: expr2cppt::convert_extractbits
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cppt::convert_extractbits(
   const exprt &src,
   unsigned precedence)
 {
-  assert(src.operands().size() == 3);
-  return convert(src.op0()) + ".range(" + convert(src.op1()) + ","
-         + convert(src.op2()) + ")";
+  assert(src.operands().size()==3);
+  return
+    convert(src.op0())+".range("+convert(src.op1())+ ","+
+    convert(src.op2())+")";
 }
 
-/*******************************************************************\
-
-Function: expr2cpp
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string expr2cpp(const exprt &expr, const namespacet &ns)
 {
   expr2cppt expr2cpp(ns);
@@ -644,18 +508,6 @@ std::string expr2cpp(const exprt &expr, const namespacet &ns)
   return expr2cpp.convert(expr);
 }
 
-/*******************************************************************\
-
-Function: type2cpp
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string type2cpp(const typet &type, const namespacet &ns)
 {
   expr2cppt expr2cpp(ns);
