@@ -1,31 +1,24 @@
 /*******************************************************************\
 
-Module: Goto-Analyser Main Module 
+Module: Goto-Analyser Main Module
 
 Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/unicode.h>
+/// \file
+/// Goto-Analyser Main Module
 
 #include "goto_analyzer_parse_options.h"
 
-/*******************************************************************\
-
-Function: main / wmain
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <util/unicode.h>
 
 #ifdef _MSC_VER
 int wmain(int argc, const wchar_t **argv_wide)
 {
-  const char **argv=narrow_argv(argc, argv_wide);
+  auto vec=narrow_argv(argc, argv_wide);
+  auto narrow=to_c_str_array(std::begin(vec), std::end(vec));
+  auto argv=narrow.data();
 #else
 int main(int argc, const char **argv)
 {
