@@ -24,20 +24,21 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include <jsil/jsil_language.h>
 
+#include <goto-programs/adjust_float_expressions.h>
+#include <goto-programs/goto_convert_functions.h>
+#include <goto-programs/goto_inline.h>
 #include <goto-programs/initialize_goto_model.h>
-#include <goto-programs/set_properties.h>
+#include <goto-programs/link_to_library.h>
+#include <goto-programs/read_goto_binary.h>
+#include <goto-programs/remove_asm.h>
+#include <goto-programs/remove_complex.h>
 #include <goto-programs/remove_function_pointers.h>
-#include <goto-programs/remove_virtual_functions.h>
 #include <goto-programs/remove_returns.h>
 #include <goto-programs/remove_vector.h>
-#include <goto-programs/remove_complex.h>
-#include <goto-programs/remove_asm.h>
-#include <goto-programs/goto_convert_functions.h>
+#include <goto-programs/remove_virtual_functions.h>
+#include <goto-programs/set_properties.h>
 #include <goto-programs/show_properties.h>
 #include <goto-programs/show_symbol_table.h>
-#include <goto-programs/read_goto_binary.h>
-#include <goto-programs/goto_inline.h>
-#include <goto-programs/link_to_library.h>
 
 #include <analyses/is_threaded.h>
 #include <analyses/goto_check.h>
@@ -49,12 +50,11 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <langapi/mode.h>
 #include <langapi/language.h>
 
-#include <util/options.h>
 #include <util/config.h>
-#include <util/unicode.h>
 #include <util/exit_codes.h>
-
-#include <goto-programs/adjust_float_expressions.h>
+#include <util/options.h>
+#include <util/unicode.h>
+#include <util/version.h>
 
 #include "taint_analysis.h"
 #include "unreachable_instructions.h"
@@ -64,10 +64,10 @@ Author: Daniel Kroening, kroening@kroening.com
 
 goto_analyzer_parse_optionst::goto_analyzer_parse_optionst(
   int argc,
-  const char **argv):
-  parse_options_baset(GOTO_ANALYSER_OPTIONS, argc, argv),
-  messaget(ui_message_handler),
-  ui_message_handler(cmdline, "GOTO-ANALYZER " CBMC_VERSION)
+  const char **argv)
+  : parse_options_baset(GOTO_ANALYSER_OPTIONS, argc, argv),
+    messaget(ui_message_handler),
+    ui_message_handler(cmdline, std::string("GOTO-ANALYZER ") + CBMC_VERSION)
 {
 }
 
@@ -374,9 +374,8 @@ int goto_analyzer_parse_optionst::doit()
   //
   // Print a banner
   //
-  status() << "GOTO-ANALYSER version " CBMC_VERSION " "
-           << sizeof(void *)*8 << "-bit "
-           << config.this_architecture() << " "
+  status() << "GOTO-ANALYSER version " << CBMC_VERSION << " "
+           << sizeof(void *) * 8 << "-bit " << config.this_architecture() << " "
            << config.this_operating_system() << eom;
 
   register_languages();
@@ -628,7 +627,6 @@ int goto_analyzer_parse_optionst::perform_analysis(const optionst &options)
       result = static_show_domain(goto_model,
                                   *analyzer,
                                   options,
-                                  get_message_handler(),
                                   out);
     }
     else if(options.get_bool_option("verify"))
@@ -652,7 +650,6 @@ int goto_analyzer_parse_optionst::perform_analysis(const optionst &options)
       result = static_unreachable_instructions(goto_model,
                                                *analyzer,
                                                options,
-                                               get_message_handler(),
                                                out);
     }
     else if(options.get_bool_option("unreachable-functions"))
@@ -660,7 +657,6 @@ int goto_analyzer_parse_optionst::perform_analysis(const optionst &options)
       result = static_unreachable_functions(goto_model,
                                             *analyzer,
                                             options,
-                                            get_message_handler(),
                                             out);
     }
     else if(options.get_bool_option("reachable-functions"))
@@ -668,7 +664,6 @@ int goto_analyzer_parse_optionst::perform_analysis(const optionst &options)
       result = static_reachable_functions(goto_model,
                                           *analyzer,
                                           options,
-                                          get_message_handler(),
                                           out);
     }
     else
