@@ -59,7 +59,7 @@ static void build_dead_map_from_ai(
   dead_mapt &dest)
 {
   forall_goto_program_instructions(it, goto_program)
-    if(ai.abstract_state_before(it).is_bottom())
+    if(ai.abstract_state_before(it)->is_bottom())
       dest.insert(std::make_pair(it->location_number, it));
 }
 
@@ -84,7 +84,6 @@ static void output_dead_plain(
 }
 
 static void add_to_xml(
-  const namespacet &ns,
   const goto_programt &goto_program,
   const dead_mapt &dead_map,
   xmlt &dest)
@@ -206,7 +205,6 @@ bool static_unreachable_instructions(
   const goto_modelt &goto_model,
   const ai_baset &ai,
   const optionst &options,
-  message_handlert &message_handler,
   std::ostream &out)
 {
   json_arrayt json_result;
@@ -231,7 +229,7 @@ bool static_unreachable_instructions(
       }
       else if(options.get_bool_option("xml"))
       {
-        add_to_xml(ns, f_it->second.body, dead_map, xml_result);
+        add_to_xml(f_it->second.body, dead_map, xml_result);
       }
       else
       {
@@ -420,7 +418,7 @@ std::unordered_set<irep_idt> compute_called_functions_from_ai(
 
     const goto_programt &p = f_it->second.body;
 
-    if(!ai.abstract_state_before(p.instructions.begin()).is_bottom())
+    if(!ai.abstract_state_before(p.instructions.begin())->is_bottom())
       called.insert(f_it->first);
   }
 
@@ -431,7 +429,6 @@ bool static_unreachable_functions(
   const goto_modelt &goto_model,
   const ai_baset &ai,
   const optionst &options,
-  message_handlert &message_handler,
   std::ostream &out)
 {
   std::unordered_set<irep_idt> called =
@@ -446,7 +443,6 @@ bool static_reachable_functions(
   const goto_modelt &goto_model,
   const ai_baset &ai,
   const optionst &options,
-  message_handlert &message_handler,
   std::ostream &out)
 {
   std::unordered_set<irep_idt> called =
