@@ -6,6 +6,11 @@ Author: CM Wintersteiger, 2006
 
 \*******************************************************************/
 
+/// \file
+/// Command line option container
+
+#include "armcc_mode.h"
+
 #ifdef _WIN32
 #define EX_OK 0
 #define EX_USAGE 64
@@ -16,26 +21,13 @@ Author: CM Wintersteiger, 2006
 
 #include <iostream>
 
-#include <util/string2int.h>
 #include <util/message.h>
 #include <util/prefix.h>
 #include <util/config.h>
 
-#include "armcc_mode.h"
 #include "compile.h"
 
-/*******************************************************************\
-
-Function: armcc_modet::doit
-
-  Inputs:
-
- Outputs:
-
- Purpose: does it.
-
-\*******************************************************************/
-
+/// does it.
 int armcc_modet::doit()
 {
   if(cmdline.isset('?') || cmdline.isset("help"))
@@ -44,9 +36,7 @@ int armcc_modet::doit()
     return EX_OK;
   }
 
-  unsigned int verbosity=1;
-
-  compilet compiler(cmdline);
+  compilet compiler(cmdline, message_handler, cmdline.isset("diag_error="));
 
   #if 0
   bool act_as_ld=
@@ -56,22 +46,19 @@ int armcc_modet::doit()
     has_prefix(base_name, "goto-link");
   #endif
 
-  if(cmdline.isset("verbosity"))
-    verbosity=unsafe_string2int(cmdline.get_value("verbosity"));
-
-  compiler.ui_message_handler.set_verbosity(verbosity);
-  ui_message_handler.set_verbosity(verbosity);
+  const auto verbosity = eval_verbosity(
+    cmdline.get_value("verbosity"), messaget::M_ERROR, message_handler);
 
   debug() << "ARM mode" << eom;
-  
+
   // get configuration
   config.set(cmdline);
 
   config.ansi_c.mode=configt::ansi_ct::flavourt::ARM;
   config.ansi_c.arch="arm";
-  
+
   // determine actions to be taken
-  
+
   if(cmdline.isset('E'))
     compiler.mode=compilet::PREPROCESS_ONLY;
   else if(cmdline.isset('c') || cmdline.isset('S'))
@@ -111,13 +98,13 @@ int armcc_modet::doit()
       config.ansi_c.preprocessor_options.push_back("--preinclude="+*it);
   }
 
-  // armcc's default is .o    
+  // armcc's default is .o
   if(cmdline.isset("default_extension="))
     compiler.object_file_extension=
       cmdline.get_value("default_extension=");
   else
     compiler.object_file_extension="o";
-      
+
   // note that ARM's default is "unsigned_chars",
   // in contrast to gcc's default!
   if(cmdline.isset("signed_chars"))
@@ -143,7 +130,7 @@ int armcc_modet::doit()
     compiler.output_file_executable="a.out";
   }
 
-  if(verbosity>8)
+  if(verbosity > messaget::M_STATISTICS)
   {
     std::list<std::string>::iterator it;
 
@@ -152,7 +139,7 @@ int armcc_modet::doit()
         it!=config.ansi_c.defines.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Undefines:\n";
@@ -160,7 +147,7 @@ int armcc_modet::doit()
         it!=config.ansi_c.undefines.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Preprocessor Options:\n";
@@ -168,7 +155,7 @@ int armcc_modet::doit()
         it!=config.ansi_c.preprocessor_options.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Include Paths:\n";
@@ -176,7 +163,7 @@ int armcc_modet::doit()
         it!=config.ansi_c.include_paths.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Library Paths:\n";
@@ -184,32 +171,22 @@ int armcc_modet::doit()
         it!=compiler.library_paths.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
-    std::cout << "Output file (object): " << compiler.output_file_object << std::endl;
-    std::cout << "Output file (executable): " << compiler.output_file_executable << std::endl;
+    std::cout << "Output file (object): "
+              << compiler.output_file_object << '\n';
+    std::cout << "Output file (executable): "
+              << compiler.output_file_executable << '\n';
   }
 
   // Parse input program, convert to goto program, write output
   return compiler.doit() ? EX_USAGE : EX_OK;
 }
 
-/*******************************************************************\
-
-Function: armcc_modet::help_mode
-
-  Inputs:
-
- Outputs:
-
- Purpose: display command line help
-
-\*******************************************************************/
-
+/// display command line help
 void armcc_modet::help_mode()
 {
-  std::cout << "goto-armcc understands the options of armcc plus the following.\n\n";
+  std::cout << "goto-armcc understands the options "
+            << "of armcc plus the following.\n\n";
 }
-
-
