@@ -8,8 +8,13 @@ Date: June 2006
 
 \*******************************************************************/
 
-#ifndef GOTO_CC_ARMCC_MODE_H
-#define GOTO_CC_ARMCC_MODE_H
+/// \file
+/// Base class for command line interpretation for CL
+
+#ifndef CPROVER_GOTO_CC_ARMCC_MODE_H
+#define CPROVER_GOTO_CC_ARMCC_MODE_H
+
+#include <util/cout_message.h>
 
 #include "goto_cc_mode.h"
 #include "armcc_cmdline.h"
@@ -17,17 +22,20 @@ Date: June 2006
 class armcc_modet:public goto_cc_modet
 {
 public:
-  virtual int doit();
-  virtual void help_mode();
+  int doit() final;
+  void help_mode() final;
 
-  explicit armcc_modet(armcc_cmdlinet &_armcc_cmdline):
-    goto_cc_modet(_armcc_cmdline),
+  armcc_modet(
+    armcc_cmdlinet &_armcc_cmdline,
+    const std::string &_base_name):
+    goto_cc_modet(_armcc_cmdline, _base_name, message_handler),
     cmdline(_armcc_cmdline)
   {
   }
-  
+
 protected:
   armcc_cmdlinet &cmdline;
+  gcc_message_handlert message_handler;
 };
 
-#endif /* GOTO_CC_ARMCC_MODE_H */
+#endif // CPROVER_GOTO_CC_ARMCC_MODE_H
