@@ -24,6 +24,7 @@ Date: June 2006
 #include <util/suffix.h>
 #include <util/tempdir.h>
 #include <util/unicode.h>
+#include <util/version.h>
 
 #include <ansi-c/ansi_c_language.h>
 #include <ansi-c/ansi_c_entry_point.h>
@@ -390,8 +391,9 @@ bool compilet::compile()
     source_files.pop_front();
 
     // Visual Studio always prints the name of the file it's doing
+    // onto stdout. The name of the directory is stripped.
     if(echo_file_name)
-      status() << file_name << eom;
+      std::cout << get_base_name(file_name, false) << '\n' << std::flush;
 
     bool r=parse_source(file_name); // don't break the program!
 
@@ -420,9 +422,17 @@ bool compilet::compile()
       std::string cfn;
 
       if(output_file_object=="")
-        cfn=get_base_name(file_name, true)+"."+object_file_extension;
+      {
+        const std::string file_name_with_obj_ext =
+          get_base_name(file_name, true) + "." + object_file_extension;
+
+        if(!output_directory_object.empty())
+          cfn = concat_dir_file(output_directory_object, file_name_with_obj_ext);
+        else
+          cfn = file_name_with_obj_ext;
+      }
       else
-        cfn=output_file_object;
+        cfn = output_file_object;
 
       if(write_object_file(cfn, symbol_table, compiled_functions))
         return true;
@@ -676,7 +686,8 @@ unsigned compilet::function_body_count(const goto_functionst &functions) const
 
 void compilet::add_compiler_specific_defines(configt &config) const
 {
-  config.ansi_c.defines.push_back("__GOTO_CC_VERSION__=" CBMC_VERSION);
+  config.ansi_c.defines.push_back(
+    std::string("__GOTO_CC_VERSION__=") + CBMC_VERSION);
 }
 
 void compilet::convert_symbols(goto_functionst &dest)
