@@ -6,6 +6,11 @@ Author: CM Wintersteiger, 2006
 
 \*******************************************************************/
 
+/// \file
+/// Command line option container
+
+#include "cw_mode.h"
+
 #ifdef _WIN32
 #define EX_OK 0
 #define EX_USAGE 64
@@ -16,26 +21,13 @@ Author: CM Wintersteiger, 2006
 
 #include <iostream>
 
-#include <util/string2int.h>
 #include <util/message.h>
 #include <util/prefix.h>
 #include <util/config.h>
 
-#include "cw_mode.h"
 #include "compile.h"
 
-/*******************************************************************\
-
-Function: cw_modet::doit
-
-  Inputs:
-
- Outputs:
-
- Purpose: does it.
-
-\*******************************************************************/
-
+/// does it.
 int cw_modet::doit()
 {
   if(cmdline.isset('?') || cmdline.isset("help"))
@@ -44,9 +36,7 @@ int cw_modet::doit()
     return EX_OK;
   }
 
-  unsigned int verbosity=1;
-
-  compilet compiler(cmdline);
+  compilet compiler(cmdline, message_handler, cmdline.isset("Werror"));
 
   #if 0
   bool act_as_ld=
@@ -56,14 +46,11 @@ int cw_modet::doit()
     has_prefix(base_name, "goto-link");
   #endif
 
-  if(cmdline.isset("verbosity"))
-    verbosity=unsafe_string2unsigned(cmdline.get_value("verbosity"));
-
-  compiler.ui_message_handler.set_verbosity(verbosity);
-  ui_message_handler.set_verbosity(verbosity);
+  const auto verbosity = eval_verbosity(
+    cmdline.get_value("verbosity"), messaget::M_ERROR, message_handler);
 
   debug() << "CodeWarrior mode" << eom;
-  
+
   // get configuration
   config.set(cmdline);
 
@@ -107,7 +94,7 @@ int cw_modet::doit()
     compiler.output_file_object="";
     compiler.output_file_executable="a.out";
   }
-    
+
   if(cmdline.isset("Wp,"))
   {
     const std::list<std::string> &values=
@@ -132,7 +119,7 @@ int cw_modet::doit()
       config.ansi_c.preprocessor_options.push_back("-isystem "+*it);
   }
 
-  if(verbosity>8)
+  if(verbosity > messaget::M_STATISTICS)
   {
     std::list<std::string>::iterator it;
 
@@ -141,7 +128,7 @@ int cw_modet::doit()
         it!=config.ansi_c.defines.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Undefines:\n";
@@ -149,7 +136,7 @@ int cw_modet::doit()
         it!=config.ansi_c.undefines.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Preprocessor Options:\n";
@@ -157,7 +144,7 @@ int cw_modet::doit()
         it!=config.ansi_c.preprocessor_options.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Include Paths:\n";
@@ -165,7 +152,7 @@ int cw_modet::doit()
         it!=config.ansi_c.include_paths.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
     std::cout << "Library Paths:\n";
@@ -173,31 +160,22 @@ int cw_modet::doit()
         it!=compiler.library_paths.end();
         it++)
     {
-      std::cout << "  " << (*it) << std::endl;
+      std::cout << "  " << (*it) << '\n';
     }
 
-    std::cout << "Output file (object): " << compiler.output_file_object << std::endl;
-    std::cout << "Output file (executable): " << compiler.output_file_executable << std::endl;
+    std::cout << "Output file (object): "
+              << compiler.output_file_object << '\n';
+    std::cout << "Output file (executable): "
+              << compiler.output_file_executable << '\n';
   }
 
   // Parse input program, convert to goto program, write output
   return compiler.doit() ? EX_USAGE : EX_OK;
 }
 
-/*******************************************************************\
-
-Function: cw_modet::help_mode
-
-  Inputs:
-
- Outputs:
-
- Purpose: display command line help
-
-\*******************************************************************/
-
+/// display command line help
 void cw_modet::help_mode()
 {
-  std::cout << "goto-cw understands the options of gcc (mwcc mode) plus the following.\n\n";
+  std::cout << "goto-cw understands the options of "
+            << "gcc (mwcc mode) plus the following.\n\n";
 }
-
