@@ -8,31 +8,35 @@ Date: June 2006
 
 \*******************************************************************/
 
-#ifndef GOTO_CC_MODE_H
-#define GOTO_CC_MODE_H
+/// \file
+/// Command line interpretation for goto-cc.
 
-#include <langapi/language_ui.h>
+#ifndef CPROVER_GOTO_CC_GOTO_CC_MODE_H
+#define CPROVER_GOTO_CC_GOTO_CC_MODE_H
 
 #include "goto_cc_cmdline.h"
 
-class goto_cc_modet:public language_uit
+#include <util/message.h>
+
+class goto_cc_modet:public messaget
 {
 public:
-  std::string base_name;
-
   virtual int main(int argc, const char **argv);
   virtual int doit()=0;
   virtual void help_mode()=0;
   virtual void help();
   virtual void usage_error();
 
-  explicit goto_cc_modet(goto_cc_cmdlinet &_cmdline);
+  goto_cc_modet(
+    goto_cc_cmdlinet &,
+    const std::string &_base_name,
+    message_handlert &);
   ~goto_cc_modet();
-  
+
 protected:
-  ui_message_handlert ui_message_handler;
-  void register_languages();
   goto_cc_cmdlinet &cmdline;
+  const std::string base_name;
+  void register_languages();
 };
 
-#endif /* GOTO_CC_MODE_H */
+#endif // CPROVER_GOTO_CC_GOTO_CC_MODE_H
