@@ -71,16 +71,28 @@ const char *ld_options_with_argument[]=
   "-Y",
   "--assert",
   "--defsym",
+  "--file-alignment",
   "--fini",
   "--hash-size",
+  "--heap",
+  "--image-base",
   "--init",
   "--Map",
+  "--major-image-version",
+  "--major-os-version",
+  "--major-subsystem-version",
+  "--minor-image-version",
+  "--minor-os-version",
+  "--minor-subsystem-version",
   "--oformat",
   "--retain-symbols-file",
   "--rpath",
   "--rpath-link",
+  "--section-alignment",
   "--sort-section",
   "--spare-dynamic-tags",
+  "--stack",
+  "--subsystem",
   "--task-link",
   "--section-start",
   "--Tbss",
