@@ -21,23 +21,24 @@ Author: CM Wintersteiger, 2006
 
 #include <iostream>
 
+#include <util/config.h>
+#include <util/file_util.h>
+#include <util/get_base_name.h>
 #include <util/message.h>
 #include <util/prefix.h>
-#include <util/config.h>
-#include <util/get_base_name.h>
 
 #include "compile.h"
 
-/// does it.
-static bool is_directory(const std::string &s)
+static bool has_directory_suffix(const std::string &path)
 {
-  if(s.empty())
-    return false;
-  char last_char=s[s.size()-1];
-  // Visual CL recognizes both
-  return last_char=='\\' || last_char=='/';
+  // MS CL decides whether a parameter is a directory on the
+  // basis of the / or \\ suffix; it doesn't matter
+  // whether the directory actually exists.
+  return path.empty() ? false :
+                        path.back()=='/' || path.back()=='\\';
 }
 
+/// does it.
 int ms_cl_modet::doit()
 {
   if(cmdline.isset('?') ||
@@ -103,13 +104,28 @@ int ms_cl_modet::doit()
 
   if(cmdline.isset("Fo"))
   {
-    compiler.output_file_object=cmdline.get_value("Fo");
+    std::string Fo_value = cmdline.get_value("Fo");
 
-    // this could be a directory
-    if(is_directory(compiler.output_file_object) &&
-       cmdline.args.size()>=1)
-      compiler.output_file_object+=
-        get_base_name(cmdline.args[0], true)+".obj";
+    // this could be a directory or a file name
+    if(has_directory_suffix(Fo_value))
+    {
+      compiler.output_directory_object = Fo_value;
+
+      if(!is_directory(Fo_value))
+        warning() << "not a directory: " << Fo_value << eom;
+    }
+    else
+      compiler.output_file_object = Fo_value;
+  }
+
+  if(
+    compiler.mode == compilet::COMPILE_ONLY &&
+    cmdline.args.size() > 1 &&
+    compiler.output_directory_object.empty())
+  {
+    error() << "output directory required for /c with multiple input files"
+            << eom;
+    return EX_USAGE;
   }
 
   if(cmdline.isset("Fe"))
@@ -117,10 +133,17 @@ int ms_cl_modet::doit()
     compiler.output_file_executable=cmdline.get_value("Fe");
 
     // this could be a directory
-    if(is_directory(compiler.output_file_executable) &&
-       cmdline.args.size()>=1)
+    if(
+      has_directory_suffix(compiler.output_file_executable) &&
+      cmdline.args.size() >= 1)
+    {
+      if(!is_directory(compiler.output_file_executable))
+        warning() << "not a directory: "
+                  << compiler.output_file_executable << eom;
+
       compiler.output_file_executable+=
-        get_base_name(cmdline.args[0], true)+".exe";
+        get_base_name(cmdline.args[0], true) + ".exe";
+    }
   }
   else
   {
