@@ -8,8 +8,13 @@ Date: June 2006
 
 \*******************************************************************/
 
-#ifndef GOTO_CC_MS_CL_MODE_H
-#define GOTO_CC_MS_CL_MODE_H
+/// \file
+/// Visual Studio CL Mode
+
+#ifndef CPROVER_GOTO_CC_MS_CL_MODE_H
+#define CPROVER_GOTO_CC_MS_CL_MODE_H
+
+#include <util/cout_message.h>
 
 #include "goto_cc_mode.h"
 #include "ms_cl_cmdline.h"
@@ -20,14 +25,17 @@ public:
   virtual int doit();
   virtual void help_mode();
 
-  explicit ms_cl_modet(ms_cl_cmdlinet &_ms_cl_cmdline):
-    goto_cc_modet(_ms_cl_cmdline),
+  ms_cl_modet(
+    ms_cl_cmdlinet &_ms_cl_cmdline,
+    const std::string &_base_name):
+    goto_cc_modet(_ms_cl_cmdline, _base_name, message_handler),
     cmdline(_ms_cl_cmdline)
   {
   }
-  
+
 protected:
   ms_cl_cmdlinet &cmdline;
+  console_message_handlert message_handler;
 };
 
-#endif /* GOTO_CC_MS_CL_MODE_H */
+#endif // CPROVER_GOTO_CC_MS_CL_MODE_H
