@@ -6,18 +6,20 @@ Author: Peter Schrammel
 
 \*******************************************************************/
 
-#ifndef CPROVER_GOTO_DIFF_LANGUAGES_H
-#define CPROVER_GOTO_DIFF_LANGUAGES_H
+/// \file
+/// GOTO-DIFF Languages
+
+#ifndef CPROVER_GOTO_DIFF_GOTO_DIFF_LANGUAGES_H
+#define CPROVER_GOTO_DIFF_GOTO_DIFF_LANGUAGES_H
 
 #include <langapi/language_ui.h>
 #include <goto-programs/goto_model.h>
 
-class goto_diff_languagest :
-  public language_uit
+class goto_diff_languagest:public language_uit
 {
 public:
   explicit goto_diff_languagest(
-    const cmdlinet& cmdline,
+    const cmdlinet &cmdline,
     ui_message_handlert &ui_message_handler) :
   language_uit(cmdline, ui_message_handler)
   {
@@ -26,7 +28,6 @@ public:
 
 protected:
   virtual void register_languages();
-
 };
 
-#endif
+#endif // CPROVER_GOTO_DIFF_GOTO_DIFF_LANGUAGES_H
