@@ -17,9 +17,10 @@ Author: Peter Schrammel
 #include <memory>
 
 #include <util/config.h>
-#include <util/options.h>
-#include <util/make_unique.h>
 #include <util/exit_codes.h>
+#include <util/make_unique.h>
+#include <util/options.h>
+#include <util/version.h>
 
 #include <langapi/language.h>
 
@@ -60,22 +61,22 @@ Author: Peter Schrammel
 #include "unified_diff.h"
 #include "change_impact.h"
 
-goto_diff_parse_optionst::goto_diff_parse_optionst(int argc, const char **argv):
-  parse_options_baset(GOTO_DIFF_OPTIONS, argc, argv),
-  goto_diff_languagest(cmdline, ui_message_handler),
-  ui_message_handler(cmdline, "GOTO-DIFF " CBMC_VERSION),
-  languages2(cmdline, ui_message_handler)
+goto_diff_parse_optionst::goto_diff_parse_optionst(int argc, const char **argv)
+  : parse_options_baset(GOTO_DIFF_OPTIONS, argc, argv),
+    goto_diff_languagest(cmdline, ui_message_handler),
+    ui_message_handler(cmdline, std::string("GOTO-DIFF ") + CBMC_VERSION),
+    languages2(cmdline, ui_message_handler)
 {
 }
 
 ::goto_diff_parse_optionst::goto_diff_parse_optionst(
   int argc,
   const char **argv,
-  const std::string &extra_options):
-  parse_options_baset(GOTO_DIFF_OPTIONS+extra_options, argc, argv),
-  goto_diff_languagest(cmdline, ui_message_handler),
-  ui_message_handler(cmdline, "GOTO-DIFF " CBMC_VERSION),
-  languages2(cmdline, ui_message_handler)
+  const std::string &extra_options)
+  : parse_options_baset(GOTO_DIFF_OPTIONS + extra_options, argc, argv),
+    goto_diff_languagest(cmdline, ui_message_handler),
+    ui_message_handler(cmdline, std::string("GOTO-DIFF ") + CBMC_VERSION),
+    languages2(cmdline, ui_message_handler)
 {
 }
 
@@ -242,9 +243,8 @@ int goto_diff_parse_optionst::doit()
   //
   // Print a banner
   //
-  status() << "GOTO-DIFF version " CBMC_VERSION " "
-           << sizeof(void *)*8 << "-bit "
-           << config.this_architecture() << " "
+  status() << "GOTO-DIFF version " << CBMC_VERSION << " " << sizeof(void *) * 8
+           << "-bit " << config.this_architecture() << " "
            << config.this_operating_system() << eom;
 
   if(cmdline.args.size()!=2)
