@@ -6,18 +6,27 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_GOTO_PROGRAMS_FULL_SLICER_H
-#define CPROVER_GOTO_PROGRAMS_FULL_SLICER_H
+/// \file
+/// Slicing
 
-#include <goto-programs/goto_functions.h>
+#ifndef CPROVER_GOTO_INSTRUMENT_FULL_SLICER_H
+#define CPROVER_GOTO_INSTRUMENT_FULL_SLICER_H
+
+#include <goto-programs/goto_model.h>
 
 void full_slicer(
-  goto_functionst &goto_functions,
-  const namespacet &ns);
+  goto_functionst &,
+  const namespacet &);
+
+void full_slicer(goto_modelt &);
 
 void property_slicer(
-  goto_functionst &goto_functions,
-  const namespacet &ns,
+  goto_functionst &,
+  const namespacet &,
+  const std::list<std::string> &properties);
+
+void property_slicer(
+  goto_modelt &,
   const std::list<std::string> &properties);
 
 class slicing_criteriont
@@ -32,4 +41,4 @@ void full_slicer(
   const namespacet &ns,
   slicing_criteriont &criterion);
 
-#endif
+#endif // CPROVER_GOTO_INSTRUMENT_FULL_SLICER_H
