@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_LOOP_UTILS_H
-#define CPROVER_LOOP_UTILS_H
+/// \file
+/// Helper functions for k-induction and loop invariants
+
+#ifndef CPROVER_GOTO_INSTRUMENT_LOOP_UTILS_H
+#define CPROVER_GOTO_INSTRUMENT_LOOP_UTILS_H
 
 #include <analyses/natural_loops.h>
 
@@ -28,4 +31,4 @@ void build_havoc_code(
 
 goto_programt::targett get_loop_exit(const loopt &);
 
-#endif
+#endif // CPROVER_GOTO_INSTRUMENT_LOOP_UTILS_H
