@@ -40,7 +40,7 @@ public:
   {
   }
 
-  ~rw_set_baset() {}
+  virtual ~rw_set_baset() = default;
 
   struct entryt
   {
@@ -87,7 +87,7 @@ public:
   void output(std::ostream &out) const;
 
 protected:
-  virtual void track_deref(const entryt &entry, bool read) {}
+  virtual void track_deref(const entryt &, bool read) {}
   virtual void set_track_deref() {}
   virtual void reset_track_deref() {}
 
@@ -136,8 +136,6 @@ public:
   {
   }
 
-  ~_rw_set_loct() {}
-
 protected:
   value_setst &value_sets;
   const goto_programt::const_targett target;
@@ -192,8 +190,6 @@ public:
   {
     compute();
   }
-
-  ~rw_set_loct() {}
 };
 
 // another producer, this time for entire functions
@@ -213,8 +209,6 @@ public:
     compute_rec(function);
   }
 
-  ~rw_set_functiont() {}
-
 protected:
   const namespacet ns;
   value_setst &value_sets;
@@ -258,8 +252,6 @@ public:
     compute();
   }
 
-  ~rw_set_with_trackt() {}
-
 protected:
   /* flag and variable in the expression, from which we dereference */
   bool dereferencing;
