@@ -8,17 +8,20 @@ Date: January 2016
 
 \*******************************************************************/
 
-#ifndef CPROVER_SKIP_LOOPS_H
-#define CPROVER_SKIP_LOOPS_H
+/// \file
+/// Skip over selected loops by adding gotos
+
+#ifndef CPROVER_GOTO_INSTRUMENT_SKIP_LOOPS_H
+#define CPROVER_GOTO_INSTRUMENT_SKIP_LOOPS_H
 
 #include <string>
 
-class goto_functionst;
+class goto_modelt;
 class message_handlert;
 
 bool skip_loops(
-  goto_functionst &goto_functions,
+  goto_modelt &,
   const std::string &loop_ids,
-  message_handlert &message_handler);
+  message_handlert &);
 
-#endif
+#endif // CPROVER_GOTO_INSTRUMENT_SKIP_LOOPS_H
