@@ -8,15 +8,16 @@ Date: November 2011
 
 \*******************************************************************/
 
-#ifndef CPROVER_STACK_DEPTH_H
-#define CPROVER_STACK_DEPTH_H
+/// \file
+/// Stack depth checks
 
-class symbol_tablet;
-class goto_functionst;
+#ifndef CPROVER_GOTO_INSTRUMENT_STACK_DEPTH_H
+#define CPROVER_GOTO_INSTRUMENT_STACK_DEPTH_H
+
+class goto_modelt;
 
 void stack_depth(
-  symbol_tablet &symbol_table,
-  goto_functionst &goto_functions,
+  goto_modelt &,
   const int depth);
 
-#endif
+#endif // CPROVER_GOTO_INSTRUMENT_STACK_DEPTH_H
