@@ -6,22 +6,14 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/std_types.h>
-#include <util/std_code.h>
+/// \file
+/// Destructor Calls
 
 #include "destructor.h"
 
-/*******************************************************************\
-
-Function: get_destructor
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <util/std_expr.h>
+#include <util/std_types.h>
+#include <util/std_code.h>
 
 code_function_callt get_destructor(
   const namespacet &ns,
@@ -40,21 +32,20 @@ code_function_callt get_destructor(
       if(it->type().id()==ID_code)
       {
         const code_typet &code_type=to_code_type(it->type());
-        
+
         if(code_type.return_type().id()==ID_destructor &&
            code_type.parameters().size()==1)
         {
           const typet &arg_type=code_type.parameters().front().type();
-          
+
           if(arg_type.id()==ID_pointer &&
              ns.follow(arg_type.subtype())==type)
           {
-            exprt symbol_expr(ID_symbol, it->type());
-            symbol_expr.set(ID_identifier, it->get(ID_name));      
+            const symbol_exprt symbol_expr(it->get(ID_name), it->type());
 
             code_function_callt function_call;
             function_call.function()=symbol_expr;
-            
+
             return function_call;
           }
         }
