@@ -6,65 +6,51 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/simplify_expr.h>
-#include <util/expr_util.h>
-#include <util/std_expr.h>
-#include <util/rename.h>
-#include <util/cprover_prefix.h>
-#include <util/i2string.h>
-
-#include <ansi-c/c_types.h>
+/// \file
+/// Program Transformation
 
 #include "goto_convert_class.h"
 
-/*******************************************************************\
+#include <util/fresh_symbol.h>
+#include <util/simplify_expr.h>
+#include <util/std_expr.h>
+#include <util/cprover_prefix.h>
 
-Function: goto_convertt::make_compound_literal
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <util/c_types.h>
 
 symbol_exprt goto_convertt::make_compound_literal(
   const exprt &expr,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   const source_locationt source_location=expr.find_source_location();
-  
-  auxiliary_symbolt new_symbol;
-  symbolt *symbol_ptr;
-  
-  do
-  {
-    new_symbol.base_name="literal$"+i2string(++temporary_counter);
-    new_symbol.name=tmp_symbol_prefix+id2string(new_symbol.base_name);
-    new_symbol.is_static_lifetime=source_location.get_function().empty();
-    new_symbol.value=expr;
-    new_symbol.type=expr.type();
-    new_symbol.location=source_location;
-  }
-  while(symbol_table.move(new_symbol, symbol_ptr));    
+
+  symbolt &new_symbol = get_fresh_aux_symbol(
+    expr.type(),
+    tmp_symbol_prefix,
+    "literal",
+    source_location,
+    mode,
+    symbol_table);
+  new_symbol.is_static_lifetime=source_location.get_function().empty();
+  new_symbol.value=expr;
 
   // The value might depend on a variable, thus
   // generate code for this.
 
-  symbol_exprt result=symbol_ptr->symbol_expr();
+  symbol_exprt result=new_symbol.symbol_expr();
   result.add_source_location()=source_location;
 
   // The lifetime of compound literals is really that of
   // the block they are in.
   copy(code_declt(result), DECL, dest);
-  
+
   code_assignt code_assign(result, expr);
   code_assign.add_source_location()=source_location;
-  convert(code_assign, dest);
+  convert(code_assign, dest, mode);
 
   // now create a 'dead' instruction
-  if(!symbol_ptr->is_static_lifetime)
+  if(!new_symbol.is_static_lifetime)
   {
     code_deadt code_dead(result);
     targets.destructor_stack.push_back(code_dead);
@@ -73,18 +59,6 @@ symbol_exprt goto_convertt::make_compound_literal(
   return result;
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::needs_cleaning
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bool goto_convertt::needs_cleaning(const exprt &expr)
 {
   if(expr.id()==ID_dereference ||
@@ -101,7 +75,7 @@ bool goto_convertt::needs_cleaning(const exprt &expr)
     if(to_index_expr(expr).array().id()==ID_string_constant &&
        to_index_expr(expr).index().is_zero())
       return false;
-    
+
     return true;
   }
 
@@ -121,30 +95,19 @@ bool goto_convertt::needs_cleaning(const exprt &expr)
   // forall (i : int) (g1 || g2)
   if(expr.id()==ID_forall || expr.id()==ID_exists)
     return false;
-  
+
   forall_operands(it, expr)
     if(needs_cleaning(*it))
       return true;
-      
+
   return false;
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::rewrite_boolean
-
-  Inputs:
-
- Outputs:
-
- Purpose: re-write boolean operators into ?:
-
-\*******************************************************************/
-
+/// re-write boolean operators into ?:
 void goto_convertt::rewrite_boolean(exprt &expr)
 {
   assert(expr.id()==ID_and || expr.id()==ID_or);
-  
+
   if(!expr.is_boolean())
   {
     error().source_location=expr.find_source_location();
@@ -157,18 +120,21 @@ void goto_convertt::rewrite_boolean(exprt &expr)
   // re-write "a || b" into nested a?1:b
 
   exprt tmp;
-  
+
   if(expr.id()==ID_and)
     tmp=true_exprt();
   else // ID_or
     tmp=false_exprt();
-    
+
   exprt::operandst &ops=expr.operands();
 
   // start with last one
-  for(int i=int(ops.size())-1; i>=0; i--)
+  for(exprt::operandst::reverse_iterator
+      it=ops.rbegin();
+      it!=ops.rend();
+      ++it)
   {
-    exprt &op=ops[i];
+    exprt &op=*it;
 
     if(!op.is_boolean())
     {
@@ -193,21 +159,10 @@ void goto_convertt::rewrite_boolean(exprt &expr)
   expr.swap(tmp);
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::clean_expr
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::clean_expr(
   exprt &expr,
   goto_programt &dest,
+  const irep_idt &mode,
   bool result_is_used)
 {
   // this cleans:
@@ -218,21 +173,22 @@ void goto_convertt::clean_expr(
   //   compound assignments
   //   compound literals
 
-  if(!needs_cleaning(expr)) return;
+  if(!needs_cleaning(expr))
+    return;
 
   if(expr.id()==ID_and || expr.id()==ID_or)
   {
     // rewrite into ?:
     rewrite_boolean(expr);
-    
+
     // recursive call
-    clean_expr(expr, dest, result_is_used);
+    clean_expr(expr, dest, mode, result_is_used);
     return;
   }
   else if(expr.id()==ID_if)
   {
     // first clean condition
-    clean_expr(to_if_expr(expr).cond(), dest, true);
+    clean_expr(to_if_expr(expr).cond(), dest, mode, true);
 
     // possibly done now
     if(!needs_cleaning(to_if_expr(expr).true_case()) &&
@@ -241,7 +197,7 @@ void goto_convertt::clean_expr(
 
     // copy expression
     if_exprt if_expr=to_if_expr(expr);
-    
+
     if(!if_expr.cond().is_boolean())
     {
       error().source_location=if_expr.find_source_location();
@@ -251,7 +207,7 @@ void goto_convertt::clean_expr(
     }
 
     const source_locationt source_location=expr.find_source_location();
-    
+
     #if 0
     // We do some constant-folding here, to mimic
     // what typical compilers do.
@@ -274,27 +230,27 @@ void goto_convertt::clean_expr(
     #endif
 
     goto_programt tmp_true;
-    clean_expr(if_expr.true_case(), tmp_true, result_is_used);
+    clean_expr(if_expr.true_case(), tmp_true, mode, result_is_used);
 
     goto_programt tmp_false;
-    clean_expr(if_expr.false_case(), tmp_false, result_is_used);
-    
+    clean_expr(if_expr.false_case(), tmp_false, mode, result_is_used);
+
     if(result_is_used)
     {
-      symbolt &new_symbol=
-        new_tmp_symbol(expr.type(), "if_expr", dest, source_location);
+      symbolt &new_symbol =
+        new_tmp_symbol(expr.type(), "if_expr", dest, source_location, mode);
 
       code_assignt assignment_true;
       assignment_true.lhs()=new_symbol.symbol_expr();
       assignment_true.rhs()=if_expr.true_case();
       assignment_true.add_source_location()=source_location;
-      convert(assignment_true, tmp_true);
+      convert(assignment_true, tmp_true, mode);
 
       code_assignt assignment_false;
       assignment_false.lhs()=new_symbol.symbol_expr();
       assignment_false.rhs()=if_expr.false_case();
       assignment_false.add_source_location()=source_location;
-      convert(assignment_false, tmp_false);
+      convert(assignment_false, tmp_false, mode);
 
       // overwrites expr
       expr=new_symbol.symbol_expr();
@@ -304,23 +260,28 @@ void goto_convertt::clean_expr(
       // preserve the expressions for possible later checks
       if(if_expr.true_case().is_not_nil())
       {
-        code_expressiont code_expression(if_expr.true_case());
-        convert(code_expression, tmp_true);
+        // add a (void) type cast so that is_skip catches it in case the
+        // expression is just a constant
+        code_expressiont code_expression(
+          typecast_exprt(if_expr.true_case(), empty_typet()));
+        convert(code_expression, tmp_true, mode);
       }
-      
+
       if(if_expr.false_case().is_not_nil())
       {
-        code_expressiont code_expression(if_expr.false_case());
-        convert(code_expression, tmp_false);
+        // add a (void) type cast so that is_skip catches it in case the
+        // expression is just a constant
+        code_expressiont code_expression(
+          typecast_exprt(if_expr.false_case(), empty_typet()));
+        convert(code_expression, tmp_false, mode);
       }
-      
+
       expr=nil_exprt();
     }
 
-    // generate guard for argument side-effects    
+    // generate guard for argument side-effects
     generate_ifthenelse(
-      if_expr.cond(), tmp_true, tmp_false,
-      source_location, dest);
+      if_expr.cond(), tmp_true, tmp_false, source_location, dest, mode);
 
     return;
   }
@@ -329,24 +290,24 @@ void goto_convertt::clean_expr(
     if(result_is_used)
     {
       exprt result;
-    
+
       Forall_operands(it, expr)
       {
         bool last=(it==--expr.operands().end());
-        
+
         // special treatment for last one
         if(last)
         {
           result.swap(*it);
-          clean_expr(result, dest, true);
+          clean_expr(result, dest, mode, true);
         }
         else
         {
-          clean_expr(*it, dest, false);
+          clean_expr(*it, dest, mode, false);
 
           // remember these for later checks
           if(it->is_not_nil())
-            convert(code_expressiont(*it), dest);
+            convert(code_expressiont(*it), dest, mode);
         }
       }
 
@@ -356,16 +317,16 @@ void goto_convertt::clean_expr(
     {
       Forall_operands(it, expr)
       {
-        clean_expr(*it, dest, false);
+        clean_expr(*it, dest, mode, false);
 
         // remember as expression statement for later checks
         if(it->is_not_nil())
-          convert(code_expressiont(*it), dest);
+          convert(code_expressiont(*it), dest, mode);
       }
-      
+
       expr=nil_exprt();
     }
-    
+
     return;
   }
   else if(expr.id()==ID_typecast)
@@ -378,29 +339,30 @@ void goto_convertt::clean_expr(
     }
 
     // preserve 'result_is_used'
-    clean_expr(expr.op0(), dest, result_is_used);
-    
+    clean_expr(expr.op0(), dest, mode, result_is_used);
+
     if(expr.op0().is_nil())
       expr.make_nil();
-    
+
     return;
   }
   else if(expr.id()==ID_side_effect)
   {
     // some of the side-effects need special treatment!
     const irep_idt statement=to_side_effect_expr(expr).get_statement();
-    
+
     if(statement==ID_gcc_conditional_expression)
     {
       // need to do separately
-      remove_gcc_conditional_expression(expr, dest);
+      remove_gcc_conditional_expression(expr, dest, mode);
       return;
     }
     else if(statement==ID_statement_expression)
     {
       // need to do separately to prevent that
       // the operands of expr get 'cleaned'
-      remove_statement_expression(to_side_effect_expr(expr), dest, result_is_used);
+      remove_statement_expression(
+        to_side_effect_expr(expr), dest, mode, result_is_used);
       return;
     }
     else if(statement==ID_assign)
@@ -411,7 +373,7 @@ void goto_convertt::clean_expr(
       if(expr.op1().id()==ID_side_effect &&
          to_side_effect_expr(expr.op1()).get_statement()==ID_function_call)
       {
-        clean_expr(expr.op0(), dest);
+        clean_expr(expr.op0(), dest, mode);
         exprt lhs=expr.op0();
 
         // turn into code
@@ -419,7 +381,7 @@ void goto_convertt::clean_expr(
         assignment.lhs()=lhs;
         assignment.rhs()=expr.op1();
         assignment.add_source_location()=expr.source_location();
-        convert_assign(assignment, dest);
+        convert_assign(assignment, dest, mode);
 
         if(result_is_used)
           expr.swap(lhs);
@@ -431,7 +393,9 @@ void goto_convertt::clean_expr(
     else if(statement==ID_function_call)
     {
       if(to_side_effect_expr_function_call(expr).function().id()==ID_symbol &&
-         to_symbol_expr(to_side_effect_expr_function_call(expr).function()).get_identifier()=="__noop")
+         to_symbol_expr(
+           to_side_effect_expr_function_call(expr).
+           function()).get_identifier()=="__noop")
       {
         // __noop needs special treatment, as arguments are not
         // evaluated
@@ -444,7 +408,7 @@ void goto_convertt::clean_expr(
     assert(expr.operands().size()==2);
     // check if there are side-effects
     goto_programt tmp;
-    clean_expr(expr.op1(), tmp, true);
+    clean_expr(expr.op1(), tmp, mode, true);
     if(tmp.instructions.empty())
     {
       error().source_location=expr.find_source_location();
@@ -457,18 +421,18 @@ void goto_convertt::clean_expr(
   else if(expr.id()==ID_address_of)
   {
     assert(expr.operands().size()==1);
-    clean_expr_address_of(expr.op0(), dest);
+    clean_expr_address_of(expr.op0(), dest, mode);
     return;
   }
 
   // TODO: evaluation order
 
   Forall_operands(it, expr)
-    clean_expr(*it, dest);
+    clean_expr(*it, dest, mode);
 
   if(expr.id()==ID_side_effect)
   {
-    remove_side_effect(to_side_effect_expr(expr), dest, result_is_used);
+    remove_side_effect(to_side_effect_expr(expr), dest, mode, result_is_used);
   }
   else if(expr.id()==ID_compound_literal)
   {
@@ -478,21 +442,10 @@ void goto_convertt::clean_expr(
   }
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::clean_expr_address_of
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::clean_expr_address_of(
   exprt &expr,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   // The address of object constructors can be taken,
   // which is re-written into the address of a variable.
@@ -500,8 +453,8 @@ void goto_convertt::clean_expr_address_of(
   if(expr.id()==ID_compound_literal)
   {
     assert(expr.operands().size()==1);
-    clean_expr(expr.op0(), dest);
-    expr=make_compound_literal(expr.op0(), dest);
+    clean_expr(expr.op0(), dest, mode);
+    expr = make_compound_literal(expr.op0(), dest, mode);
   }
   else if(expr.id()==ID_string_constant)
   {
@@ -511,13 +464,13 @@ void goto_convertt::clean_expr_address_of(
   else if(expr.id()==ID_index)
   {
     assert(expr.operands().size()==2);
-    clean_expr_address_of(expr.op0(), dest);
-    clean_expr(expr.op1(), dest);
+    clean_expr_address_of(expr.op0(), dest, mode);
+    clean_expr(expr.op1(), dest, mode);
   }
   else if(expr.id()==ID_dereference)
   {
     assert(expr.operands().size()==1);
-    clean_expr(expr.op0(), dest);
+    clean_expr(expr.op0(), dest, mode);
   }
   else if(expr.id()==ID_comma)
   {
@@ -525,49 +478,38 @@ void goto_convertt::clean_expr_address_of(
     // Treatment is similar to clean_expr() above.
 
     exprt result;
-  
+
     Forall_operands(it, expr)
     {
       bool last=(it==--expr.operands().end());
-      
+
       // special treatment for last one
       if(last)
         result.swap(*it);
       else
       {
-        clean_expr(*it, dest, false);
+        clean_expr(*it, dest, mode, false);
 
         // get any side-effects
         if(it->is_not_nil())
-          convert(code_expressiont(*it), dest);
+          convert(code_expressiont(*it), dest, mode);
       }
     }
 
     expr.swap(result);
-    
+
     // do again
-    clean_expr_address_of(expr, dest);
+    clean_expr_address_of(expr, dest, mode);
   }
   else
     Forall_operands(it, expr)
-      clean_expr_address_of(*it, dest);
+      clean_expr_address_of(*it, dest, mode);
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::remove_gcc_conditional_expression
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::remove_gcc_conditional_expression(
   exprt &expr,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   if(expr.operands().size()!=2)
   {
@@ -577,7 +519,7 @@ void goto_convertt::remove_gcc_conditional_expression(
   }
 
   // first remove side-effects from condition
-  clean_expr(expr.op0(), dest);
+  clean_expr(expr.op0(), dest, mode);
 
   // now we can copy op0 safely
   if_exprt if_expr;
@@ -590,9 +532,9 @@ void goto_convertt::remove_gcc_conditional_expression(
 
   if(if_expr.cond().type()!=bool_typet())
     if_expr.cond().make_typecast(bool_typet());
-  
+
   expr.swap(if_expr);
 
-  // there might still be junk in expr.op2()  
-  clean_expr(expr, dest);
+  // there might still be junk in expr.op2()
+  clean_expr(expr, dest, mode);
 }
