@@ -146,15 +146,12 @@ void goto_convertt::finish_gotos(goto_programt &dest, const irep_idt &mode)
       // for C++ non-pod types and impossible in Java in any case.
       auto goto_stack=g_it.second;
       const auto &label_stack=l_it->second.second;
-      bool stack_is_prefix=true;
-      if(label_stack.size()>goto_stack.size())
-        stack_is_prefix=false;
-      for(std::size_t i=0, ilim=label_stack.size();
-          i!=ilim && stack_is_prefix;
-          ++i)
+      bool stack_is_prefix = label_stack.size() <= goto_stack.size();
+      for(
+        std::size_t idx = 0, ilim = label_stack.size();
+        idx != ilim && stack_is_prefix; ++idx)
       {
-        if(goto_stack[i]!=label_stack[i])
-          stack_is_prefix=false;
+        stack_is_prefix &= goto_stack[idx] == label_stack[idx];
       }
 
       if(!stack_is_prefix)
@@ -355,8 +352,8 @@ void goto_convertt::convert_label(
 }
 
 void goto_convertt::convert_gcc_local_label(
-  const codet &code,
-  goto_programt &dest)
+  const codet &,
+  goto_programt &)
 {
   // ignore for now
 }
@@ -715,8 +712,8 @@ void goto_convertt::convert_decl(
 }
 
 void goto_convertt::convert_decl_type(
-  const codet &code,
-  goto_programt &dest)
+  const codet &,
+  goto_programt &)
 {
   // we remove these
 }
@@ -761,7 +758,8 @@ void goto_convertt::convert_assign(
     (rhs.get(ID_statement) == ID_assign ||
      rhs.get(ID_statement) == ID_postincrement ||
      rhs.get(ID_statement) == ID_preincrement ||
-     rhs.get(ID_statement) == ID_statement_expression))
+     rhs.get(ID_statement) == ID_statement_expression ||
+     rhs.get(ID_statement) == ID_gcc_conditional_expression))
   {
     // handle above side effects
     clean_expr(rhs, dest, mode);
@@ -1572,12 +1570,12 @@ void goto_convertt::convert_ifthenelse(
 
   // convert 'then'-branch
   goto_programt tmp_then;
-  convert(to_code(code.then_case()), tmp_then, mode);
+  convert(code.then_case(), tmp_then, mode);
 
   goto_programt tmp_else;
 
   if(has_else)
-    convert(to_code(code.else_case()), tmp_else, mode);
+    convert(code.else_case(), tmp_else, mode);
 
   exprt tmp_guard=code.cond();
   clean_expr(tmp_guard, dest, mode);
@@ -1990,8 +1988,7 @@ symbolt &goto_convertt::new_tmp_symbol(
     mode,
     symbol_table);
 
-  code_declt decl;
-  decl.symbol()=new_symbol.symbol_expr();
+  code_declt decl(new_symbol.symbol_expr());
   decl.add_source_location()=source_location;
   convert_decl(decl, dest, mode);
 
