@@ -126,8 +126,7 @@ protected:
     bool result_is_used);
   void remove_cpp_delete(
     side_effect_exprt &expr,
-    goto_programt &dest,
-    bool result_is_used);
+    goto_programt &dest);
   void remove_malloc(
     side_effect_exprt &expr,
     goto_programt &dest,
@@ -135,8 +134,7 @@ protected:
     bool result_is_used);
   void remove_temporary_object(
     side_effect_exprt &expr,
-    goto_programt &dest,
-    bool result_is_used);
+    goto_programt &dest);
   void remove_statement_expression(
     side_effect_exprt &expr,
     goto_programt &dest,
@@ -195,7 +193,7 @@ protected:
     const exprt::operandst &arguments,
     goto_programt &dest);
 
-  virtual void do_function_call_symbol(const symbolt &symbol)
+  virtual void do_function_call_symbol(const symbolt &)
   {
   }
 
@@ -631,12 +629,10 @@ protected:
     const exprt::operandst &arguments,
     goto_programt &dest);
   void do_input(
-    const exprt &lhs,
     const exprt &rhs,
     const exprt::operandst &arguments,
     goto_programt &dest);
   void do_output(
-    const exprt &lhs,
     const exprt &rhs,
     const exprt::operandst &arguments,
     goto_programt &dest);
