@@ -6,25 +6,17 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/std_expr.h>
+/// \file
+/// Program Transformation
 
 #include "goto_convert_class.h"
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_msc_try_finally
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <util/std_expr.h>
 
 void goto_convertt::convert_msc_try_finally(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   if(code.operands().size()!=2)
   {
@@ -32,49 +24,38 @@ void goto_convertt::convert_msc_try_finally(
     error() << "msc_try_finally expects two arguments" << eom;
     throw 0;
   }
-  
+
   goto_programt tmp;
   tmp.add_instruction(SKIP)->source_location=code.source_location();
 
-  {  
+  {
     // save 'leave' target
     leave_targett leave_target(targets);
     targets.set_leave(tmp.instructions.begin());
-    
+
     // first put 'finally' code onto destructor stack
     targets.destructor_stack.push_back(to_code(code.op1()));
-  
+
     // do 'try' code
-    convert(to_code(code.op0()), dest);
+    convert(to_code(code.op0()), dest, mode);
 
     // pop 'finally' from destructor stack
     targets.destructor_stack.pop_back();
-    
+
     // 'leave' target gets restored here
   }
 
   // now add 'finally' code
-  convert(to_code(code.op1()), dest);
-  
+  convert(to_code(code.op1()), dest, mode);
+
   // this is the target for 'leave'
   dest.destructive_append(tmp);
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_msc_try_except
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::convert_msc_try_except(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   if(code.operands().size()!=3)
   {
@@ -83,26 +64,15 @@ void goto_convertt::convert_msc_try_except(
     throw 0;
   }
 
-  convert(to_code(code.op0()), dest);
-  
+  convert(to_code(code.op0()), dest, mode);
+
   // todo: generate exception tracking
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_msc_leave
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::convert_msc_leave(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   if(!targets.leave_set)
   {
@@ -110,7 +80,7 @@ void goto_convertt::convert_msc_leave(
     error() << "leave without target" << eom;
     throw 0;
   }
-  
+
   // need to process destructor stack
   for(std::size_t d=targets.destructor_stack.size();
       d!=targets.leave_stack_size;
@@ -118,7 +88,7 @@ void goto_convertt::convert_msc_leave(
   {
     codet d_code=targets.destructor_stack[d-1];
     d_code.add_source_location()=code.source_location();
-    convert(d_code, dest);
+    convert(d_code, dest, mode);
   }
 
   goto_programt::targett t=dest.add_instruction();
@@ -126,60 +96,51 @@ void goto_convertt::convert_msc_leave(
   t->source_location=code.source_location();
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_try_catch
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::convert_try_catch(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   assert(code.operands().size()>=2);
-  
+
   // add the CATCH-push instruction to 'dest'
   goto_programt::targett catch_push_instruction=dest.add_instruction();
   catch_push_instruction->make_catch();
-  catch_push_instruction->code.set_statement(ID_catch);
   catch_push_instruction->source_location=code.source_location();
-  
+
+  code_push_catcht push_catch_code;
+
   // the CATCH-push instruction is annotated with a list of IDs,
   // one per target
-  irept::subt &exception_list=
-    catch_push_instruction->code.add(ID_exception_list).get_sub();
+  code_push_catcht::exception_listt &exception_list=
+    push_catch_code.exception_list();
 
   // add a SKIP target for the end of everything
   goto_programt end;
   goto_programt::targett end_target=end.add_instruction();
   end_target->make_skip();
-  
+
   // the first operand is the 'try' block
-  convert(to_code(code.op0()), dest);
-  
+  convert(to_code(code.op0()), dest, mode);
+
   // add the CATCH-pop to the end of the 'try' block
   goto_programt::targett catch_pop_instruction=dest.add_instruction();
   catch_pop_instruction->make_catch();
-  catch_pop_instruction->code.set_statement(ID_catch);
-  
+  catch_pop_instruction->code=code_pop_catcht();
+
   // add a goto to the end of the 'try' block
   dest.add_instruction()->make_goto(end_target);
 
-  for(unsigned i=1; i<code.operands().size(); i++)
+  for(std::size_t i=1; i<code.operands().size(); i++)
   {
     const codet &block=to_code(code.operands()[i]);
-  
+
     // grab the ID and add to CATCH instruction
-    exception_list.push_back(irept(block.get(ID_exception_id)));
-    
+    exception_list.push_back(
+      code_push_catcht::exception_list_entryt(block.get(ID_exception_id)));
+
     goto_programt tmp;
-    convert(block, tmp);
+    convert(block, tmp, mode);
     catch_push_instruction->targets.push_back(tmp.instructions.begin());
     dest.destructive_append(tmp);
 
@@ -187,25 +148,16 @@ void goto_convertt::convert_try_catch(
     dest.add_instruction()->make_goto(end_target);
   }
 
-  // add the end-target  
+  catch_push_instruction->code=push_catch_code;
+
+  // add the end-target
   dest.destructive_append(end);
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_CPROVER_try_catch
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::convert_CPROVER_try_catch(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   if(code.operands().size()!=2)
   {
@@ -221,7 +173,7 @@ void goto_convertt::convert_CPROVER_try_catch(
   // set 'throw' target
   throw_targett throw_target(targets);
   targets.set_throw(tmp.instructions.begin());
-  
+
   // now put 'catch' code onto destructor stack
   code_ifthenelset catch_code;
   catch_code.cond()=exception_flag();
@@ -231,30 +183,19 @@ void goto_convertt::convert_CPROVER_try_catch(
   targets.destructor_stack.push_back(catch_code);
 
   // now convert 'try' code
-  convert(to_code(code.op0()), dest);
+  convert(to_code(code.op0()), dest, mode);
 
   // pop 'catch' code off stack
   targets.destructor_stack.pop_back();
-  
+
   // add 'throw' target
   dest.destructive_append(tmp);
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_CPROVER_throw
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::convert_CPROVER_throw(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   // set the 'exception' flag
   {
@@ -269,7 +210,8 @@ void goto_convertt::convert_CPROVER_throw(
   if(targets.throw_set)
   {
     // need to process destructor stack
-    unwind_destructor_stack(code.source_location(), targets.throw_stack_size, dest);
+    unwind_destructor_stack(
+      code.source_location(), targets.throw_stack_size, dest, mode);
 
     // add goto
     goto_programt::targett t=dest.add_instruction();
@@ -279,7 +221,7 @@ void goto_convertt::convert_CPROVER_throw(
   else // otherwise, we do a return
   {
     // need to process destructor stack
-    unwind_destructor_stack(code.source_location(), 0, dest);
+    unwind_destructor_stack(code.source_location(), 0, dest, mode);
 
     // add goto
     goto_programt::targett t=dest.add_instruction();
@@ -288,21 +230,10 @@ void goto_convertt::convert_CPROVER_throw(
   }
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::convert_CPROVER_try_finally
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_convertt::convert_CPROVER_try_finally(
   const codet &code,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
 {
   if(code.operands().size()!=2)
   {
@@ -310,39 +241,27 @@ void goto_convertt::convert_CPROVER_try_finally(
     error() << "CPROVER_try_finally expects two arguments" << eom;
     throw 0;
   }
-  
+
   // first put 'finally' code onto destructor stack
   targets.destructor_stack.push_back(to_code(code.op1()));
-  
+
   // do 'try' code
-  convert(to_code(code.op0()), dest);
+  convert(to_code(code.op0()), dest, mode);
 
   // pop 'finally' from destructor stack
   targets.destructor_stack.pop_back();
 
   // now add 'finally' code
-  convert(to_code(code.op1()), dest);
+  convert(to_code(code.op1()), dest, mode);
 }
 
-/*******************************************************************\
-
-Function: goto_convertt::exception_flag
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 symbol_exprt goto_convertt::exception_flag()
 {
   irep_idt id="$exception_flag";
 
   symbol_tablet::symbolst::const_iterator s_it=
     symbol_table.symbols.find(id);
-  
+
   if(s_it==symbol_table.symbols.end())
   {
     symbolt new_symbol;
@@ -352,45 +271,45 @@ symbol_exprt goto_convertt::exception_flag()
     new_symbol.is_thread_local=true;
     new_symbol.is_file_local=false;
     new_symbol.type=bool_typet();
-    symbol_table.move(new_symbol);
+    symbol_table.insert(std::move(new_symbol));
   }
-  
+
   return symbol_exprt(id, bool_typet());
 }
-    
-/*******************************************************************\
-
-Function: goto_convertt::unwind_destructor_stack
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
 
 void goto_convertt::unwind_destructor_stack(
   const source_locationt &source_location,
   std::size_t final_stack_size,
-  goto_programt &dest)
+  goto_programt &dest,
+  const irep_idt &mode)
+{
+  unwind_destructor_stack(
+    source_location, final_stack_size, dest, targets.destructor_stack, mode);
+}
+
+void goto_convertt::unwind_destructor_stack(
+  const source_locationt &source_location,
+  std::size_t final_stack_size,
+  goto_programt &dest,
+  destructor_stackt &destructor_stack,
+  const irep_idt &mode)
 {
   // There might be exceptions happening in the exception
   // handler. We thus pop off the stack, and then later
   // one restore the original stack.
-  destructor_stackt old_stack=targets.destructor_stack;
+  destructor_stackt old_stack=destructor_stack;
 
-  while(targets.destructor_stack.size()>final_stack_size)
+  while(destructor_stack.size()>final_stack_size)
   {
-    codet d_code=targets.destructor_stack.back();
+    codet d_code=destructor_stack.back();
     d_code.add_source_location()=source_location;
-    
+
     // pop now to avoid doing this again
-    targets.destructor_stack.pop_back();
- 
-    convert(d_code, dest);
+    destructor_stack.pop_back();
+
+    convert(d_code, dest, mode);
   }
 
   // Now restore old stack.
-  old_stack.swap(targets.destructor_stack);  
+  old_stack.swap(destructor_stack);
 }
