@@ -8,55 +8,57 @@ Date: June 2003
 
 \*******************************************************************/
 
-#ifndef CPROVER_GOTO_CONVERT_FUNCTIONS_H
-#define CPROVER_GOTO_CONVERT_FUNCTIONS_H
+/// \file
+/// Goto Programs with Functions
+
+#ifndef CPROVER_GOTO_PROGRAMS_GOTO_CONVERT_FUNCTIONS_H
+#define CPROVER_GOTO_PROGRAMS_GOTO_CONVERT_FUNCTIONS_H
 
 #include "goto_model.h"
 #include "goto_convert_class.h"
+#include "goto_functions.h"
 
 // convert it all!
 void goto_convert(
-  symbol_tablet &symbol_table,
+  symbol_table_baset &symbol_table,
   goto_functionst &functions,
-  message_handlert &message_handler);
-  
+  message_handlert &);
+
 // convert it all!
 void goto_convert(
-  symbol_tablet &symbol_table,
-  goto_modelt &dest,
-  message_handlert &message_handler);
-  
+  goto_modelt &,
+  message_handlert &);
+
 // just convert a specific function
 void goto_convert(
   const irep_idt &identifier,
-  symbol_tablet &symbol_table,
+  symbol_table_baset &symbol_table,
   goto_functionst &functions,
-  message_handlert &message_handler);
-  
+  message_handlert &);
+
 class goto_convert_functionst:public goto_convertt
 {
 public:
-  void goto_convert();
-  void convert_function(const irep_idt &identifier);
+  void goto_convert(goto_functionst &functions);
+  void convert_function(
+    const irep_idt &identifier,
+    goto_functionst::goto_functiont &result);
 
   goto_convert_functionst(
-    symbol_tablet &_symbol_table,
-    goto_functionst &_functions,
+    symbol_table_baset &_symbol_table,
     message_handlert &_message_handler);
-  
+
   virtual ~goto_convert_functionst();
 
 protected:
-  goto_functionst &functions;
-  
-  static bool hide(const goto_programt &goto_program);
+  static bool hide(const goto_programt &);
 
   //
-  // function calls  
+  // function calls
   //
   void add_return(
     goto_functionst::goto_functiont &,
     const source_locationt &);
 };
 
-#endif
+#endif // CPROVER_GOTO_PROGRAMS_GOTO_CONVERT_FUNCTIONS_H
