@@ -390,8 +390,7 @@ void goto_convertt::remove_function_call(
     symbol_table);
 
   {
-    code_declt decl;
-    decl.symbol()=new_symbol.symbol_expr();
+    code_declt decl(new_symbol.symbol_expr());
     decl.add_source_location()=new_symbol.location;
     convert_decl(decl, dest, mode);
   }
@@ -425,8 +424,6 @@ void goto_convertt::remove_cpp_new(
   goto_programt &dest,
   bool result_is_used)
 {
-  codet call;
-
   const symbolt &new_symbol = get_fresh_aux_symbol(
     expr.type(),
     tmp_symbol_prefix,
@@ -435,12 +432,11 @@ void goto_convertt::remove_cpp_new(
     ID_cpp,
     symbol_table);
 
-  code_declt decl;
-  decl.symbol()=new_symbol.symbol_expr();
+  code_declt decl(new_symbol.symbol_expr());
   decl.add_source_location()=new_symbol.location;
   convert_decl(decl, dest, ID_cpp);
 
-  call=code_assignt(new_symbol.symbol_expr(), expr);
+  const code_assignt call(new_symbol.symbol_expr(), expr);
 
   if(result_is_used)
     static_cast<exprt &>(expr)=new_symbol.symbol_expr();
@@ -452,14 +448,11 @@ void goto_convertt::remove_cpp_new(
 
 void goto_convertt::remove_cpp_delete(
   side_effect_exprt &expr,
-  goto_programt &dest,
-  bool result_is_used)
+  goto_programt &dest)
 {
   assert(expr.operands().size()==1);
 
-  codet tmp;
-
-  tmp.set_statement(expr.get_statement());
+  codet tmp(expr.get_statement());
   tmp.add_source_location()=expr.source_location();
   tmp.copy_to_operands(expr.op0());
   tmp.set(ID_destructor, expr.find(ID_destructor));
@@ -507,8 +500,7 @@ void goto_convertt::remove_malloc(
 
 void goto_convertt::remove_temporary_object(
   side_effect_exprt &expr,
-  goto_programt &dest,
-  bool result_is_used)
+  goto_programt &dest)
 {
   const irep_idt &mode = expr.get(ID_mode);
   if(expr.operands().size()!=1 &&
@@ -666,11 +658,11 @@ void goto_convertt::remove_side_effect(
     remove_cpp_new(expr, dest, result_is_used);
   else if(statement==ID_cpp_delete ||
           statement==ID_cpp_delete_array)
-    remove_cpp_delete(expr, dest, result_is_used);
+    remove_cpp_delete(expr, dest);
   else if(statement==ID_allocate)
     remove_malloc(expr, dest, mode, result_is_used);
   else if(statement==ID_temporary_object)
-    remove_temporary_object(expr, dest, result_is_used);
+    remove_temporary_object(expr, dest);
   else if(statement==ID_statement_expression)
     remove_statement_expression(expr, dest, mode, result_is_used);
   else if(statement==ID_nondet)
@@ -684,8 +676,9 @@ void goto_convertt::remove_side_effect(
   else if(statement==ID_throw)
   {
     goto_programt::targett t=dest.add_instruction(THROW);
-    t->code=
-      code_expressiont(side_effect_expr_throwt(expr.find(ID_exception_list)));
+    t->code = code_expressiont(
+      side_effect_expr_throwt(
+        expr.find(ID_exception_list), expr.type(), expr.source_location()));
     t->code.op0().operands().swap(expr.operands());
     t->code.add_source_location()=expr.source_location();
     t->source_location=expr.source_location();
