@@ -195,11 +195,47 @@ public:
   }
 };
 
+struct trace_optionst
+{
+  bool json_full_lhs;
+  bool hex_representation;
+  bool base_prefix;
+  bool show_function_calls;
+  bool show_code;
+
+  static const trace_optionst default_options;
+
+  explicit trace_optionst(const optionst &options)
+  {
+    json_full_lhs = options.get_bool_option("trace-json-extended");
+    hex_representation = options.get_bool_option("trace-hex");
+    base_prefix = hex_representation;
+    show_function_calls = options.get_bool_option("trace-show-function-calls");
+    show_code = options.get_bool_option("trace-show-code");
+  };
+
+private:
+  trace_optionst()
+  {
+    json_full_lhs = false;
+    hex_representation = false;
+    base_prefix = false;
+    show_function_calls = false;
+    show_code = false;
+  };
+};
+
 void show_goto_trace(
   std::ostream &out,
   const namespacet &,
   const goto_tracet &);
 
+void show_goto_trace(
+  std::ostream &out,
+  const namespacet &,
+  const goto_tracet &,
+  const trace_optionst &);
+
 void trace_value(
   std::ostream &out,
   const namespacet &,
@@ -208,32 +244,26 @@ void trace_value(
   const exprt &value);
 
 
-struct trace_optionst
-{
-  bool json_full_lhs;
-
-  static const trace_optionst default_options;
-
-  explicit trace_optionst(const optionst &options)
-  {
-    json_full_lhs = options.get_bool_option("trace-json-extended");
-  };
-
-private:
-  trace_optionst()
-  {
-    json_full_lhs = false;
-  };
-};
-
-#define OPT_GOTO_TRACE "(trace-json-extended)"
+#define OPT_GOTO_TRACE "(trace-json-extended)" \
+                       "(trace-show-function-calls)" \
+                       "(trace-show-code)" \
+                       "(trace-hex)"
 
 #define HELP_GOTO_TRACE                                                        \
-  " --trace-json-extended        add rawLhs property to trace\n"
+  " --trace-json-extended        add rawLhs property to trace\n"               \
+  " --trace-show-function-calls  show function calls in plain trace\n"         \
+  " --trace-show-code            show original code in plain trace\n"          \
+  " --trace-hex                  represent plain trace values in hex\n"
 
 #define PARSE_OPTIONS_GOTO_TRACE(cmdline, options)                             \
   if(cmdline.isset("trace-json-extended"))                                     \
-    options.set_option("trace-json-extended", true);
+    options.set_option("trace-json-extended", true);                           \
+  if(cmdline.isset("trace-show-function-calls"))                               \
+    options.set_option("trace-show-function-calls", true);                     \
+  if(cmdline.isset("trace-show-code"))                                       \
+      options.set_option("trace-show-code", true);                             \
+  if(cmdline.isset("trace-hex"))                                               \
+    options.set_option("trace-hex", true);
 
 
 #endif // CPROVER_GOTO_PROGRAMS_GOTO_TRACE_H
