@@ -273,7 +273,7 @@ protected:
   dynamic_typest dynamic_types;
   int num_dynamic_objects;
   mp_integer stack_depth;
-  int thread_id;
+  unsigned thread_id;
 
   bool evaluate_boolean(const exprt &expr)
   {
