@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_LOOP_IDS_H
-#define CPROVER_LOOP_IDS_H
+/// \file
+/// Loop IDs
+
+#ifndef CPROVER_GOTO_PROGRAMS_LOOP_IDS_H
+#define CPROVER_GOTO_PROGRAMS_LOOP_IDS_H
 
 #include <util/ui_message.h>
 
@@ -25,4 +28,4 @@ void show_loop_ids(
   ui_message_handlert::uit,
   const goto_programt &);
 
-#endif
+#endif // CPROVER_GOTO_PROGRAMS_LOOP_IDS_H
