@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_PROPERTY_CHECKER_H
-#define CPROVER_PROPERTY_CHECKER_H
+/// \file
+/// Property Checker Interface
+
+#ifndef CPROVER_GOTO_PROGRAMS_PROPERTY_CHECKER_H
+#define CPROVER_GOTO_PROGRAMS_PROPERTY_CHECKER_H
 
 // this is just an interface -- it won't actually do any checking!
 
@@ -26,8 +29,8 @@ public:
   explicit property_checkert(
     message_handlert &_message_handler);
 
-  typedef enum { PASS, FAIL, ERROR, UNKNOWN } resultt;
-  
+  enum class resultt { PASS, FAIL, ERROR, UNKNOWN };
+
   static std::string as_string(resultt);
 
   // Check whether all properties in goto_functions hold.
@@ -35,12 +38,12 @@ public:
 
   struct property_statust
   {
-    // this is the counterexample  
+    // this is the counterexample
     goto_tracet error_trace;
     resultt result;
     goto_programt::const_targett location;
   };
-  
+
   // the irep_idt is the property id
   typedef std::map<irep_idt, property_statust> property_mapt;
   property_mapt property_map;
@@ -49,4 +52,4 @@ protected:
   void initialize_property_map(const goto_functionst &);
 };
 
-#endif
+#endif // CPROVER_GOTO_PROGRAMS_PROPERTY_CHECKER_H
