@@ -6,6 +6,9 @@ Author: CM Wintersteiger
 
 \*******************************************************************/
 
+/// \file
+/// Write GOTO binaries
+
 #ifndef CPROVER_GOTO_PROGRAMS_WRITE_GOTO_BINARY_H
 #define CPROVER_GOTO_PROGRAMS_WRITE_GOTO_BINARY_H
 
@@ -16,20 +19,23 @@ Author: CM Wintersteiger
 
 #include "goto_functions.h"
 
-class symbol_tablet;
-class goto_functionst;
+class goto_modelt;
 class message_handlert;
 
 bool write_goto_binary(
   std::ostream &out,
-  const symbol_tablet &symbol_table,
-  const goto_functionst &goto_functions,
+  const goto_modelt &,
+  int version=GOTO_BINARY_VERSION);
+
+bool write_goto_binary(
+  std::ostream &out,
+  const symbol_tablet &,
+  const goto_functionst &,
   int version=GOTO_BINARY_VERSION);
 
 bool write_goto_binary(
   const std::string &filename,
-  const symbol_tablet &lsymbol_table,
-  const goto_functionst &goto_functions,
-  message_handlert &message_handler);
+  const goto_modelt &,
+  message_handlert &);
 
-#endif
+#endif // CPROVER_GOTO_PROGRAMS_WRITE_GOTO_BINARY_H
