@@ -6,75 +6,33 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <cstdlib>
-#include <cassert>
-#include <iostream>
-
-#include <util/std_expr.h>
-#include <util/prefix.h>
+/// \file
+/// Symbolic Execution
 
 #include "goto_symex_state.h"
 
-/*******************************************************************\
+#include <cstdlib>
+#include <iostream>
 
-Function: goto_symex_statet::goto_symex_statet
+#include <util/invariant.h>
+#include <util/base_exceptions.h>
+#include <util/std_expr.h>
+#include <util/prefix.h>
 
-  Inputs:
+#include <analyses/dirty.h>
 
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
-goto_symex_statet::goto_symex_statet():
-  depth(0),
-  symex_target(NULL),
-  atomic_section_id(0),
-  record_events(true)
+goto_symex_statet::goto_symex_statet()
+  : depth(0),
+    symex_target(nullptr),
+    atomic_section_id(0),
+    record_events(true),
+    dirty()
 {
   threads.resize(1);
   new_frame();
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::initialize
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
-void goto_symex_statet::initialize(const goto_functionst &goto_functions)
-{
-  goto_functionst::function_mapt::const_iterator it=
-    goto_functions.function_map.find(goto_functionst::entry_point());
-
-  if(it==goto_functions.function_map.end())
-    throw "program has no entry point";
-
-  const goto_programt &body=it->second.body;
-
-  source=symex_targett::sourcet(body);
-  top().end_of_function=--body.instructions.end();
-  top().calling_location.pc=top().end_of_function;
-}
-
-/*******************************************************************\
-
-Function: goto_symex_statet::level0t::operator()
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+goto_symex_statet::~goto_symex_statet()=default;
 
 void goto_symex_statet::level0t::operator()(
   ssa_exprt &ssa_expr,
@@ -92,34 +50,19 @@ void goto_symex_statet::level0t::operator()(
     return;
 
   const symbolt *s;
+  const bool found_l0 = !ns.lookup(obj_identifier, s);
+  DATA_INVARIANT(
+    found_l0, "level0: failed to find " + id2string(obj_identifier));
 
-  if(ns.lookup(obj_identifier, s))
-  {
-    std::cerr << "level0: failed to find " << obj_identifier << std::endl;
-    abort();
-  }
-  
   // don't rename shared variables or functions
   if(s->type.id()==ID_code ||
      s->is_shared())
     return;
 
-  // rename!    
+  // rename!
   ssa_expr.set_level_0(thread_nr);
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::level1t::operator()
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::level1t::operator()(ssa_exprt &ssa_expr)
 {
   // already renamed?
@@ -129,30 +72,20 @@ void goto_symex_statet::level1t::operator()(ssa_exprt &ssa_expr)
   const irep_idt l0_name=ssa_expr.get_l1_object_identifier();
 
   current_namest::const_iterator it=current_names.find(l0_name);
-  if(it==current_names.end()) return;
+  if(it==current_names.end())
+    return;
 
   // rename!
   ssa_expr.set_level_1(it->second.second);
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::constant_propagation
-
-  Inputs:
-
- Outputs:
-
- Purpose: This function determines what expressions are to
-          be propagated as "constants"
-
-\*******************************************************************/
-
+/// This function determines what expressions are to be propagated as
+/// "constants"
 bool goto_symex_statet::constant_propagation(const exprt &expr) const
 {
   if(expr.is_constant())
     return true;
-  
+
   if(expr.id()==ID_address_of)
   {
     const address_of_exprt &address_of_expr=to_address_of_expr(expr);
@@ -177,8 +110,12 @@ bool goto_symex_statet::constant_propagation(const exprt &expr) const
   {
     // propagate stuff with sizeof in it
     forall_operands(it, expr)
+    {
       if(it->find(ID_C_c_sizeof_type).is_not_nil())
         return true;
+      else if(!constant_propagation(*it))
+        return false;
+    }
 
     return true;
   }
@@ -187,7 +124,7 @@ bool goto_symex_statet::constant_propagation(const exprt &expr) const
     forall_operands(it, expr)
       if(!constant_propagation(*it))
         return false;
-        
+
     return true;
   }
   else if(expr.id()==ID_array_of)
@@ -236,19 +173,7 @@ bool goto_symex_statet::constant_propagation(const exprt &expr) const
   return false;
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::constant_propagation_reference
-
-  Inputs:
-
- Outputs:
-
- Purpose: this function determines which reference-typed
-          expressions are constant
-
-\*******************************************************************/
-
+/// this function determines which reference-typed expressions are constant
 bool goto_symex_statet::constant_propagation_reference(const exprt &expr) const
 {
   if(expr.id()==ID_symbol)
@@ -273,18 +198,7 @@ bool goto_symex_statet::constant_propagation_reference(const exprt &expr) const
   return false;
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::assignment
-
-  Inputs:
-
- Outputs:
-
- Purpose: write to a variable
-
-\*******************************************************************/
-
+/// write to a variable
 static bool check_renaming(const exprt &expr);
 
 static bool check_renaming(const typet &type)
@@ -313,18 +227,23 @@ static bool check_renaming(const typet &type)
 
 static bool check_renaming_l1(const exprt &expr)
 {
-  if(check_renaming(expr.type())) return true;
+  if(check_renaming(expr.type()))
+    return true;
 
   if(expr.id()==ID_symbol)
   {
-    if(!expr.get_bool(ID_C_SSA_symbol)) return expr.type().id()!=ID_code;
-    if(!to_ssa_expr(expr).get_level_2().empty()) return true;
-    if(to_ssa_expr(expr).get_original_expr().type()!=expr.type()) return true;
+    if(!expr.get_bool(ID_C_SSA_symbol))
+      return expr.type().id()!=ID_code;
+    if(!to_ssa_expr(expr).get_level_2().empty())
+      return true;
+    if(to_ssa_expr(expr).get_original_expr().type()!=expr.type())
+      return true;
   }
   else
   {
     forall_operands(it, expr)
-      if(check_renaming_l1(*it)) return true;
+      if(check_renaming_l1(*it))
+        return true;
   }
 
   return false;
@@ -332,7 +251,8 @@ static bool check_renaming_l1(const exprt &expr)
 
 static bool check_renaming(const exprt &expr)
 {
-  if(check_renaming(expr.type())) return true;
+  if(check_renaming(expr.type()))
+    return true;
 
   if(expr.id()==ID_address_of &&
      expr.op0().id()==ID_symbol)
@@ -343,14 +263,18 @@ static bool check_renaming(const exprt &expr)
            check_renaming(expr.op0().op1());
   else if(expr.id()==ID_symbol)
   {
-    if(!expr.get_bool(ID_C_SSA_symbol)) return expr.type().id()!=ID_code;
-    if(to_ssa_expr(expr).get_level_2().empty()) return true;
-    if(to_ssa_expr(expr).get_original_expr().type()!=expr.type()) return true;
+    if(!expr.get_bool(ID_C_SSA_symbol))
+      return expr.type().id()!=ID_code;
+    if(to_ssa_expr(expr).get_level_2().empty())
+      return true;
+    if(to_ssa_expr(expr).get_original_expr().type()!=expr.type())
+      return true;
   }
   else
   {
     forall_operands(it, expr)
-      if(check_renaming(*it)) return true;
+      if(check_renaming(*it))
+        return true;
   }
 
   return false;
@@ -361,8 +285,8 @@ static void assert_l1_renaming(const exprt &expr)
   #if 1
   if(check_renaming_l1(expr))
   {
-    std::cerr << expr.pretty() << std::endl;
-    assert(false);
+    std::cerr << expr.pretty() << '\n';
+    UNREACHABLE;
   }
   #else
   (void)expr;
@@ -374,8 +298,8 @@ static void assert_l2_renaming(const exprt &expr)
   #if 1
   if(check_renaming(expr))
   {
-    std::cerr << expr.pretty() << std::endl;
-    assert(false);
+    std::cerr << expr.pretty() << '\n';
+    UNREACHABLE;
   }
   #else
   (void)expr;
@@ -387,7 +311,8 @@ void goto_symex_statet::assignment(
   const exprt &rhs,  // L2
   const namespacet &ns,
   bool rhs_is_simplified,
-  bool record_value)
+  bool record_value,
+  bool allow_pointer_unsoundness)
 {
   // identifier should be l0 or l1, make sure it's l1
   rename(lhs, ns, L1);
@@ -398,8 +323,8 @@ void goto_symex_statet::assignment(
   lhs.update_type();
   assert_l1_renaming(lhs);
 
-  #if 0  
-  assert(l1_identifier != get_original_name(l1_identifier)
+  #if 0
+  PRECONDITION(l1_identifier != get_original_name(l1_identifier)
       || l1_identifier=="goto_symex::\\guard"
       || ns.lookup(l1_identifier).is_shared()
       || has_prefix(id2string(l1_identifier), "symex::invalid_object")
@@ -418,13 +343,17 @@ void goto_symex_statet::assignment(
   assert_l2_renaming(lhs);
   assert_l2_renaming(rhs);
 
+  // see #305 on GitHub for a simple example and possible discussion
+  if(is_shared && lhs.type().id() == ID_pointer && !allow_pointer_unsoundness)
+    throw "pointer handling for concurrency is unsound";
+
   // for value propagation -- the RHS is L2
-  
+
   if(!is_shared && record_value && constant_propagation(rhs))
     propagation.values[l1_identifier]=rhs;
   else
     propagation.remove(l1_identifier);
-      
+
   {
     // update value sets
     value_sett::expr_sett rhs_value_set;
@@ -437,34 +366,22 @@ void goto_symex_statet::assignment(
     assert_l1_renaming(l1_lhs);
     assert_l1_renaming(l1_rhs);
 
-    value_set.assign(l1_lhs, l1_rhs, ns, rhs_is_simplified, is_shared);  
+    value_set.assign(l1_lhs, l1_rhs, ns, rhs_is_simplified, is_shared);
   }
-  
+
   #if 0
-  std::cout << "Assigning " << l1_identifier << std::endl;
+  std::cout << "Assigning " << l1_identifier << '\n';
   value_set.output(ns, std::cout);
-  std::cout << "**********************" << std::endl;
+  std::cout << "**********************\n";
   #endif
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::propagationt::operator()
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::propagationt::operator()(exprt &expr)
 {
   if(expr.id()==ID_symbol)
   {
-    valuest::const_iterator it=
-      values.find(expr.get(ID_identifier));
+    valuest::const_iterator it =
+      values.find(to_symbol_expr(expr).get_identifier());
     if(it!=values.end())
       expr=it->second;
   }
@@ -480,18 +397,6 @@ void goto_symex_statet::propagationt::operator()(exprt &expr)
   }
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::set_ssa_indices
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::set_ssa_indices(
   ssa_exprt &ssa_expr,
   const namespacet &ns,
@@ -502,38 +407,29 @@ void goto_symex_statet::set_ssa_indices(
   case L0:
     level0(ssa_expr, ns, source.thread_nr);
     break;
-    
+
   case L1:
-    if(!ssa_expr.get_level_2().empty()) return;
-    if(!ssa_expr.get_level_1().empty()) return;
+    if(!ssa_expr.get_level_2().empty())
+      return;
+    if(!ssa_expr.get_level_1().empty())
+      return;
     level0(ssa_expr, ns, source.thread_nr);
     level1(ssa_expr);
     break;
-  
+
   case L2:
-    if(!ssa_expr.get_level_2().empty()) return;
+    if(!ssa_expr.get_level_2().empty())
+      return;
     level0(ssa_expr, ns, source.thread_nr);
     level1(ssa_expr);
     ssa_expr.set_level_2(level2.current_count(ssa_expr.get_identifier()));
     break;
-    
+
   default:
-    assert(false);
+    UNREACHABLE;
   }
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::rename
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::rename(
   exprt &expr,
   const namespacet &ns,
@@ -599,9 +495,12 @@ void goto_symex_statet::rename(
   }
   else if(expr.id()==ID_address_of)
   {
-    assert(expr.operands().size()==1);
+    DATA_INVARIANT(
+      expr.operands().size() == 1, "address_of should have a single operand");
     rename_address(expr.op0(), ns, level);
-    assert(expr.type().id()==ID_pointer);
+    DATA_INVARIANT(
+      expr.type().id() == ID_pointer,
+      "type of address_of should be ID_pointer");
     expr.type().subtype()=expr.op0().type();
   }
   else
@@ -618,39 +517,30 @@ void goto_symex_statet::rename(
       expr.type()=to_with_expr(expr).old().type();
     else if(expr.id()==ID_if)
     {
-      assert(to_if_expr(expr).true_case().type()==to_if_expr(expr).false_case().type());
+      DATA_INVARIANT(
+        to_if_expr(expr).true_case().type() ==
+          to_if_expr(expr).false_case().type(),
+        "true case of to_if_expr should be of same type "
+        "as false case");
       expr.type()=to_if_expr(expr).true_case().type();
     }
   }
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::l2_thread_read_encoding
-
-  Inputs:
-
- Outputs:
-
- Purpose: thread encoding
-
-\*******************************************************************/
-
+/// thread encoding
 bool goto_symex_statet::l2_thread_read_encoding(
   ssa_exprt &expr,
   const namespacet &ns)
 {
-  if(!record_events)
-    return false;
-
   // do we have threads?
   if(threads.size()<=1)
     return false;
 
   // is it a shared object?
   const irep_idt &obj_identifier=expr.get_object_name();
-  if(obj_identifier=="goto_symex::\\guard" ||
-     !ns.lookup(obj_identifier).is_shared())
+  if(
+    obj_identifier == "goto_symex::\\guard" ||
+    (!ns.lookup(obj_identifier).is_shared() && !(dirty)(obj_identifier)))
     return false;
 
   ssa_exprt ssa_l1=expr;
@@ -742,7 +632,7 @@ bool goto_symex_statet::l2_thread_read_encoding(
       ssa_l1.get_original_expr(),
       tmp,
       source,
-      symex_targett::PHI);
+      symex_targett::assignment_typet::PHI);
 
     set_ssa_indices(ssa_l1, ns, L2);
     expr=ssa_l1;
@@ -754,15 +644,25 @@ bool goto_symex_statet::l2_thread_read_encoding(
     return true;
   }
 
-  // produce a fresh L2 name
   if(level2.current_names.find(l1_identifier)==level2.current_names.end())
     level2.current_names[l1_identifier]=std::make_pair(ssa_l1, 0);
+
+  // No event and no fresh index, but avoid constant propagation
+  if(!record_events)
+  {
+    set_ssa_indices(ssa_l1, ns, L2);
+    expr=ssa_l1;
+    return true;
+  }
+
+  // produce a fresh L2 name
   level2.increase_counter(l1_identifier);
   set_ssa_indices(ssa_l1, ns, L2);
   expr=ssa_l1;
 
   // and record that
-  assert(symex_target!=NULL);
+  INVARIANT_STRUCTURED(
+    symex_target!=nullptr, nullptr_exceptiont, "symex_target is null");
   symex_target->shared_read(
     guard.as_expr(),
     expr,
@@ -772,18 +672,7 @@ bool goto_symex_statet::l2_thread_read_encoding(
   return true;
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::l2_thread_write_encoding
-
-  Inputs:
-
- Outputs:
-
- Purpose: thread encoding
-
-\*******************************************************************/
-
+/// thread encoding
 bool goto_symex_statet::l2_thread_write_encoding(
   const ssa_exprt &expr,
   const namespacet &ns)
@@ -793,10 +682,11 @@ bool goto_symex_statet::l2_thread_write_encoding(
 
   // is it a shared object?
   const irep_idt &obj_identifier=expr.get_object_name();
-  if(obj_identifier=="goto_symex::\\guard" ||
-     !ns.lookup(obj_identifier).is_shared())
+  if(
+    obj_identifier == "goto_symex::\\guard" ||
+    (!ns.lookup(obj_identifier).is_shared() && !(dirty)(obj_identifier)))
     return false; // not shared
-    
+
   // see whether we are within an atomic section
   if(atomic_section_id!=0)
   {
@@ -818,18 +708,6 @@ bool goto_symex_statet::l2_thread_write_encoding(
   return threads.size()>1;
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::rename_address
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::rename_address(
   exprt &expr,
   const namespacet &ns,
@@ -858,7 +736,7 @@ void goto_symex_statet::rename_address(
       index_exprt &index_expr=to_index_expr(expr);
 
       rename_address(index_expr.array(), ns, level);
-      assert(index_expr.array().type().id()==ID_array);
+      PRECONDITION(index_expr.array().type().id() == ID_array);
       expr.type()=index_expr.array().type().subtype();
 
       // the index is not an address
@@ -888,7 +766,7 @@ void goto_symex_statet::rename_address(
           to_struct_union_type(member_expr.struct_op().type());
         const struct_union_typet::componentt &comp=
           su_type.get_component(member_expr.get_component_name());
-        assert(comp.is_not_nil());
+        PRECONDITION(comp.is_not_nil());
         expr.type()=comp.type();
       }
       else
@@ -907,18 +785,6 @@ void goto_symex_statet::rename_address(
   }
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::rename
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::rename(
   typet &type,
   const irep_idt &l1_identifier,
@@ -934,10 +800,20 @@ void goto_symex_statet::rename(
   {
     l1_type_entry=l1_types.insert(std::make_pair(l1_identifier, type));
 
-    if(!l1_type_entry.second)
+    if(!l1_type_entry.second) // was already in map
     {
-      type=l1_type_entry.first->second;
-      return;
+      // do not change a complete array type to an incomplete one
+
+      const typet &type_prev=l1_type_entry.first->second;
+
+      if(type.id()!=ID_array ||
+         type_prev.id()!=ID_array ||
+         to_array_type(type).is_incomplete() ||
+         to_array_type(type_prev).is_complete())
+      {
+        type=l1_type_entry.first->second;
+        return;
+      }
     }
   }
 
@@ -980,18 +856,6 @@ void goto_symex_statet::rename(
     l1_type_entry.first->second=type;
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::get_original_name
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::get_original_name(exprt &expr) const
 {
   get_original_name(expr.type());
@@ -1004,18 +868,6 @@ void goto_symex_statet::get_original_name(exprt &expr) const
       get_original_name(*it);
 }
 
-/*******************************************************************\
- 
-Function: goto_symex_statet::get_original_name
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::get_original_name(typet &type) const
 {
   // rename all the symbols with their last known value
@@ -1044,18 +896,6 @@ void goto_symex_statet::get_original_name(typet &type) const
   }
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::get_l1_name
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::get_l1_name(exprt &expr) const
 {
   // do not reset the type !
@@ -1068,23 +908,11 @@ void goto_symex_statet::get_l1_name(exprt &expr) const
       get_l1_name(*it);
 }
 
-/*******************************************************************\
-
-Function: goto_symex_statet::switch_to_thread
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void goto_symex_statet::switch_to_thread(unsigned t)
 {
-  assert(source.thread_nr<threads.size());
-  assert(t<threads.size());
-  
+  PRECONDITION(source.thread_nr < threads.size());
+  PRECONDITION(t < threads.size());
+
   // save PC
   threads[source.thread_nr].pc=source.pc;
   threads[source.thread_nr].atomic_section_id=atomic_section_id;
@@ -1092,6 +920,6 @@ void goto_symex_statet::switch_to_thread(unsigned t)
   // get new PC
   source.thread_nr=t;
   source.pc=threads[t].pc;
-  
+
   guard=threads[t].guard;
 }
