@@ -6,35 +6,55 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+/// \file
+/// Symbolic Execution
+
 #ifndef CPROVER_GOTO_SYMEX_GOTO_SYMEX_STATE_H
 #define CPROVER_GOTO_SYMEX_GOTO_SYMEX_STATE_H
 
-#include <cassert>
+#include <memory>
+#include <unordered_set>
 
+#include <analyses/dirty.h>
+
+#include <util/invariant.h>
 #include <util/guard.h>
 #include <util/std_expr.h>
-#include <util/i2string.h>
 #include <util/ssa_expr.h>
+#include <util/make_unique.h>
 
 #include <pointer-analysis/value_set.h>
-#include <goto-programs/goto_functions.h>
+#include <goto-programs/goto_function.h>
 
-#include "symex_target.h"
+#include "symex_target_equation.h"
 
 // central data structure: state
-class goto_symex_statet
+class goto_symex_statet final
 {
 public:
   goto_symex_statet();
+  ~goto_symex_statet();
 
-  // distance from entry
+  /// \brief Fake "copy constructor" that initializes the `symex_target` member
+  explicit goto_symex_statet(
+    const goto_symex_statet &other,
+    symex_target_equationt *const target)
+    : goto_symex_statet(other) // NOLINT
+  {
+    symex_target = target;
+  }
+
+  /// contains symbols that are minted during symbolic execution, such as
+  /// dynamically created objects etc. The names in this table are needed
+  /// for error traces even after symbolic execution has finished.
+  symbol_tablet symbol_table;
+
+  /// distance from entry
   unsigned depth;
 
   guardt guard;
   symex_targett::sourcet source;
-  symex_targett *symex_target;
-
-  void initialize(const goto_functionst &goto_functions);
+  symex_target_equationt *symex_target;
 
   // we have a two-level renaming
 
@@ -42,15 +62,15 @@ public:
 
   // we remember all L1 renamings
   typedef std::set<irep_idt> l1_historyt;
-  l1_historyt l1_history; 
-  
+  l1_historyt l1_history;
+
   struct renaming_levelt
   {
     virtual ~renaming_levelt() { }
 
     typedef std::map<irep_idt, std::pair<ssa_exprt, unsigned> > current_namest;
     current_namest current_names;
-    
+
     unsigned current_count(const irep_idt &identifier) const
     {
       current_namest::const_iterator it=
@@ -60,11 +80,11 @@ public:
 
     void increase_counter(const irep_idt &identifier)
     {
-      assert(current_names.find(identifier)!=current_names.end());
+      PRECONDITION(current_names.find(identifier) != current_names.end());
       ++current_names[identifier].second;
     }
 
-    void get_variables(hash_set_cont<ssa_exprt, irep_hash> &vars) const
+    void get_variables(std::unordered_set<ssa_exprt, irep_hash> &vars) const
     {
       for(current_namest::const_iterator it=current_names.begin();
           it!=current_names.end();
@@ -72,7 +92,7 @@ public:
         vars.insert(it->second.first);
     }
   };
-  
+
   // level 0 -- threads!
   // renaming built for one particular interleaving
   struct level0t:public renaming_levelt
@@ -88,7 +108,7 @@ public:
 
   // level 1 -- function frames
   // this is to preserve locality in case of recursion
-  
+
   struct level1t:public renaming_levelt
   {
     void operator()(ssa_exprt &ssa_expr);
@@ -107,7 +127,7 @@ public:
           current_names.insert(it, *ito);
         else if(it!=current_names.end())
         {
-          assert(it->first==ito->first);
+          PRECONDITION(it->first == ito->first);
           it->second=ito->second;
           ++it;
         }
@@ -117,7 +137,7 @@ public:
     level1t() { }
     virtual ~level1t() { }
   } level1;
-  
+
   // level 2 -- SSA
 
   struct level2t:public renaming_levelt
@@ -125,7 +145,7 @@ public:
     level2t() { }
     virtual ~level2t() { }
   } level2;
-  
+
   // this maps L1 names to (L2) constants
   class propagationt
   {
@@ -138,10 +158,9 @@ public:
     {
       values.erase(identifier);
     }
-    
   } propagation;
-  
-  typedef enum { L0=0, L1=1, L2=2 } levelt;
+
+  enum levelt { L0=0, L1=1, L2=2 };
 
   // performs renaming _up to_ the given level
   void rename(exprt &expr, const namespacet &ns, levelt level=L2);
@@ -150,13 +169,14 @@ public:
     const irep_idt &l1_identifier,
     const namespacet &ns,
     levelt level=L2);
-  
+
   void assignment(
     ssa_exprt &lhs, // L0/L1
     const exprt &rhs,  // L2
     const namespacet &ns,
     bool rhs_is_simplified,
-    bool record_value);
+    bool record_value,
+    bool allow_pointer_unsoundness=false);
 
   // what to propagate
   bool constant_propagation(const exprt &expr) const;
@@ -173,9 +193,9 @@ protected:
   void get_l1_name(exprt &expr) const;
 
   // this maps L1 names to (L2) types
-  typedef hash_map_cont<irep_idt, typet, irep_id_hash> l1_typest;
+  typedef std::unordered_map<irep_idt, typet> l1_typest;
   l1_typest l1_types;
-  
+
 public:
   // uses level 1 names, and is used to
   // do dereferencing
@@ -188,21 +208,24 @@ public:
     level2t::current_namest level2_current_names;
     value_sett value_set;
     guardt guard;
+    symex_targett::sourcet source;
     propagationt propagation;
     unsigned atomic_section_id;
-    
+
     explicit goto_statet(const goto_symex_statet &s):
       depth(s.depth),
       level2_current_names(s.level2.current_names),
       value_set(s.value_set),
       guard(s.guard),
+      source(s.source),
       propagation(s.propagation),
       atomic_section_id(s.atomic_section_id)
     {
     }
 
     // the below replicate levelt2 member functions
-    void level2_get_variables(hash_set_cont<ssa_exprt, irep_hash> &vars) const
+    void level2_get_variables(
+      std::unordered_set<ssa_exprt, irep_hash> &vars) const
     {
       for(level2t::current_namest::const_iterator
           it=level2_current_names.begin();
@@ -219,16 +242,28 @@ public:
     }
   };
 
+  explicit goto_symex_statet(const goto_statet &s)
+    : depth(s.depth),
+      guard(s.guard),
+      source(s.source),
+      propagation(s.propagation),
+      value_set(s.value_set),
+      atomic_section_id(s.atomic_section_id)
+  {
+    level2.current_names = s.level2_current_names;
+  }
+
   // gotos
   typedef std::list<goto_statet> goto_state_listt;
-  typedef std::map<goto_programt::const_targett, goto_state_listt> goto_state_mapt;
+  typedef std::map<goto_programt::const_targett, goto_state_listt>
+    goto_state_mapt;
 
   // stack frames -- these are used for function calls and
   // for exceptions
   class framet
   {
   public:
-    // function calls  
+    // function calls
     irep_idt function_identifier;
     goto_state_mapt goto_state_map;
     symex_targett::sourcet calling_location;
@@ -238,10 +273,10 @@ public:
     bool hidden_function;
 
     renaming_levelt::current_namest old_level1;
-    
+
     typedef std::set<irep_idt> local_objectst;
     local_objectst local_objects;
-    
+
     framet():
       return_value(nil_exprt()),
       hidden_function(false)
@@ -264,50 +299,51 @@ public:
       unsigned count;
       bool is_recursion;
     };
-    typedef hash_map_cont<irep_idt, loop_infot, irep_id_hash>
-      loop_iterationst;
+    typedef std::unordered_map<irep_idt, loop_infot> loop_iterationst;
     loop_iterationst loop_iterations;
   };
 
   typedef std::vector<framet> call_stackt;
 
-  inline call_stackt &call_stack()
+  call_stackt &call_stack()
   {
-    assert(source.thread_nr<threads.size());
+    PRECONDITION(source.thread_nr < threads.size());
     return threads[source.thread_nr].call_stack;
   }
-  
-  inline const call_stackt &call_stack() const
+
+  const call_stackt &call_stack() const
   {
-    assert(source.thread_nr<threads.size());
+    PRECONDITION(source.thread_nr < threads.size());
     return threads[source.thread_nr].call_stack;
   }
-  
-  inline framet &top()
+
+  framet &top()
   {
-    assert(!call_stack().empty());
+    PRECONDITION(!call_stack().empty());
     return call_stack().back();
   }
 
-  inline const framet &top() const
+  const framet &top() const
   {
-    assert(!call_stack().empty());
+    PRECONDITION(!call_stack().empty());
     return call_stack().back();
   }
-  
-  inline framet &new_frame() { call_stack().push_back(framet()); return top(); }
-  inline void pop_frame() { call_stack().pop_back(); }
-  inline const framet &previous_frame() { return *(--(--call_stack().end())); }
+
+  framet &new_frame() { call_stack().push_back(framet()); return top(); }
+  void pop_frame() { call_stack().pop_back(); }
+  const framet &previous_frame() { return *(--(--call_stack().end())); }
 
   // threads
   unsigned atomic_section_id;
   typedef std::pair<unsigned, std::list<guardt> > a_s_r_entryt;
-  typedef hash_map_cont<ssa_exprt, a_s_r_entryt, irep_hash> read_in_atomic_sectiont;
+  typedef std::unordered_map<ssa_exprt, a_s_r_entryt, irep_hash>
+    read_in_atomic_sectiont;
   typedef std::list<guardt> a_s_w_entryt;
-  typedef hash_map_cont<ssa_exprt, a_s_w_entryt, irep_hash> written_in_atomic_sectiont;
+  typedef std::unordered_map<ssa_exprt, a_s_w_entryt, irep_hash>
+    written_in_atomic_sectiont;
   read_in_atomic_sectiont read_in_atomic_section;
   written_in_atomic_sectiont written_in_atomic_section;
-  
+
   class threadt
   {
   public:
@@ -325,12 +361,39 @@ public:
 
   typedef std::vector<threadt> threadst;
   threadst threads;
-  
+
   bool l2_thread_read_encoding(ssa_exprt &expr, const namespacet &ns);
   bool l2_thread_write_encoding(const ssa_exprt &expr, const namespacet &ns);
 
+  void populate_dirty_for_function(
+    const irep_idt &id, const goto_functiont &);
+
   void switch_to_thread(unsigned t);
   bool record_events;
+  incremental_dirtyt dirty;
+
+  goto_programt::const_targett saved_target;
+
+  /// \brief This state is saved, with the PC pointing to the target of a GOTO
+  bool has_saved_jump_target;
+
+  /// \brief This state is saved, with the PC pointing to the next instruction
+  /// of a GOTO
+  bool has_saved_next_instruction;
+  bool saved_target_is_backwards;
+
+private:
+  /// \brief Dangerous, do not use
+  ///
+  /// Copying a state S1 to S2 risks S2 pointing to a deallocated
+  /// symex_target_equationt if S1 (and the symex_target_equationt that its
+  /// `symex_target` member points to) go out of scope. If your class has a
+  /// goto_symex_statet member and needs a copy constructor, copy instances
+  /// of this class using the public two-argument copy constructor
+  /// constructor to ensure that the copy points to an allocated
+  /// symex_target_equationt. The two-argument copy constructor uses this
+  /// private copy constructor as a delegate.
+  goto_symex_statet(const goto_symex_statet &other) = default;
 };
 
-#endif
+#endif // CPROVER_GOTO_SYMEX_GOTO_SYMEX_STATE_H
