@@ -16,7 +16,7 @@ void memory_model_psot::operator()(symex_target_equationt &equation)
   statistics() << "Adding PSO constraints" << eom;
 
   build_event_lists(equation);
-  build_clock_type(equation);
+  build_clock_type();
 
   read_from(equation);
   write_serialization_external(equation);
