@@ -372,11 +372,6 @@ void symex_slice_by_tracet::compute_ts_back(
   }
 }
 
-void symex_slice_by_tracet::compute_ts_fd(
-  symex_target_equationt &equation)
-{
-}
-
 void symex_slice_by_tracet::slice_SSA_steps(
   symex_target_equationt &equation,
   std::set<exprt> implications)
@@ -552,7 +547,7 @@ std::set<exprt> symex_slice_by_tracet::implied_guards(exprt e)
     }
     else
     {
-      int i=unsafe_string2int(id_string.substr(merge_loc+6));
+      const std::size_t i = unsafe_string2size_t(id_string.substr(merge_loc+6));
       if(merge_impl_cache_back[i].first)
       {
         return merge_impl_cache_back[i].second;
