@@ -54,7 +54,11 @@ void goto_symext::symex_assign(
     else if(statement==ID_allocate)
       symex_allocate(state, lhs, side_effect_expr);
     else if(statement==ID_printf)
-      symex_printf(state, lhs, side_effect_expr);
+    {
+      if(lhs.is_not_nil())
+        throw "printf: unexpected assignment";
+      symex_printf(state, side_effect_expr);
+    }
     else if(statement==ID_gcc_builtin_va_arg_next)
       symex_gcc_builtin_va_arg_next(state, lhs, side_effect_expr);
     else
