@@ -153,7 +153,7 @@ void goto_symext::symex_allocate(
   value_symbol.name="symex_dynamic::"+id2string(value_symbol.base_name);
   value_symbol.is_lvalue=true;
   value_symbol.type=object_type;
-  value_symbol.type.set("#dynamic", true);
+  value_symbol.type.set(ID_C_dynamic, true);
   value_symbol.mode = mode;
 
   state.symbol_table.add(value_symbol);
@@ -311,7 +311,6 @@ irep_idt get_string_argument(const exprt &src, const namespacet &ns)
 
 void goto_symext::symex_printf(
   statet &state,
-  const exprt &lhs,
   const exprt &rhs)
 {
   if(rhs.operands().empty())
@@ -433,7 +432,7 @@ void goto_symext::symex_cpp_new(
   else
     symbol.type=code.type().subtype();
 
-  symbol.type.set("#dynamic", true);
+  symbol.type.set(ID_C_dynamic, true);
 
   state.symbol_table.add(symbol);
 
@@ -454,8 +453,8 @@ void goto_symext::symex_cpp_new(
 }
 
 void goto_symext::symex_cpp_delete(
-  statet &state,
-  const codet &code)
+  statet &,
+  const codet &)
 {
   // TODO
   #if 0
@@ -503,9 +502,10 @@ void goto_symext::symex_trace(
 }
 
 void goto_symext::symex_fkt(
-  statet &state,
-  const code_function_callt &code)
+  statet &,
+  const code_function_callt &)
 {
+  UNREACHABLE;
   #if 0
   exprt new_fc(ID_function, fc.type());
 
@@ -526,7 +526,7 @@ void goto_symext::symex_fkt(
 }
 
 void goto_symext::symex_macro(
-  statet &state,
+  statet &,
   const code_function_callt &code)
 {
   const irep_idt &identifier=code.op0().get(ID_identifier);
