@@ -18,9 +18,9 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <util/invariant.h>
 
 bool goto_symext::get_unwind_recursion(
-  const irep_idt &identifier,
-  const unsigned thread_nr,
-  unsigned unwind)
+  const irep_idt &,
+  const unsigned,
+  unsigned)
 {
   return false;
 }
@@ -72,7 +72,8 @@ void goto_symext::parameter_assignments(
                        "not enough arguments, inserting non-deterministic value"
                     << log.eom;
 
-      rhs=side_effect_expr_nondett(parameter_type);
+      rhs = side_effect_expr_nondett(
+        parameter_type, state.source.pc->source_location);
     }
     else
       rhs=*it1;
@@ -148,6 +149,7 @@ void goto_symext::parameter_assignments(
       symbolt symbol;
       symbol.name=id;
       symbol.base_name="va_arg"+std::to_string(va_count);
+      symbol.mode=ID_C;
       symbol.type=it1->type();
 
       state.symbol_table.insert(std::move(symbol));
@@ -222,6 +224,11 @@ void goto_symext::symex_function_call_code(
 
   state.dirty.populate_dirty_for_function(identifier, goto_function);
 
+  auto emplace_safe_pointers_result =
+    safe_pointers.emplace(identifier, local_safe_pointerst{ns});
+  if(emplace_safe_pointers_result.second)
+    emplace_safe_pointers_result.first->second(goto_function.body);
+
   const bool stop_recursing=get_unwind_recursion(
     identifier,
     state.source.thread_nr,
@@ -259,8 +266,8 @@ void goto_symext::symex_function_call_code(
 
     if(call.lhs().is_not_nil())
     {
-      side_effect_expr_nondett rhs(call.lhs().type());
-      rhs.add_source_location()=call.source_location();
+      const auto rhs =
+        side_effect_expr_nondett(call.lhs().type(), call.source_location());
       code_assignt code(call.lhs(), rhs);
       symex_assign(state, code);
     }
