@@ -34,7 +34,8 @@ void goto_symext::havoc_rec(
 
     code_assignt assignment;
     assignment.lhs()=lhs;
-    assignment.rhs()=side_effect_expr_nondett(dest.type());
+    assignment.rhs() =
+      side_effect_expr_nondett(dest.type(), state.source.pc->source_location);
 
     symex_assign(state, assignment);
   }
@@ -78,7 +79,7 @@ void goto_symext::symex_other(
 {
   const goto_programt::instructiont &instruction=*state.source.pc;
 
-  const codet &code=to_code(instruction.code);
+  const codet &code = instruction.code;
 
   const irep_idt &statement=code.get_statement();
 
@@ -101,7 +102,7 @@ void goto_symext::symex_other(
   {
     codet clean_code=code;
     clean_expr(clean_code, state, false);
-    symex_printf(state, nil_exprt(), clean_code);
+    symex_printf(state, clean_code);
   }
   else if(statement==ID_input)
   {
