@@ -6,8 +6,11 @@ Author: Michael Tautschnig, tautschn@amazon.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_JSIL_ENTRY_POINT_H
-#define CPROVER_JSIL_ENTRY_POINT_H
+/// \file
+/// Jsil Language
+
+#ifndef CPROVER_JSIL_JSIL_ENTRY_POINT_H
+#define CPROVER_JSIL_JSIL_ENTRY_POINT_H
 
 class message_handlert;
 class symbol_tablet;
@@ -16,4 +19,4 @@ bool jsil_entry_point(
   class symbol_tablet &symbol_table,
   class message_handlert &message_handler);
 
-#endif
+#endif // CPROVER_JSIL_JSIL_ENTRY_POINT_H
