@@ -6,24 +6,12 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <fstream>
-
 #include "json_parser.h"
 
+#include <fstream>
+
 json_parsert json_parser;
 
-/*******************************************************************\
-
-Function: parse_json
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 // 'do it all' function
 bool parse_json(
   std::istream &in,
@@ -45,30 +33,19 @@ bool parse_json(
   // save some memory
   json_parser.clear();
 
-  return result;  
+  return result;
 }
 
-/*******************************************************************\
-
-Function: parse_json
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 // 'do it all' function
 bool parse_json(
   const std::string &filename,
   message_handlert &message_handler,
   jsont &dest)
 {
-  std::ifstream in(filename.c_str());
-  
-  if(!in) return true;
- 
+  std::ifstream in(filename);
+
+  if(!in)
+    return true;
+
   return parse_json(in, filename, message_handler, dest);
 }
