@@ -6,8 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef JSON_PARSER_H
-#define JSON_PARSER_H
+
+#ifndef CPROVER_JSON_JSON_PARSER_H
+#define CPROVER_JSON_JSON_PARSER_H
 
 #include <cassert>
 #include <stack>
@@ -16,26 +17,27 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <util/json.h>
 
 int yyjsonparse();
+void yyjsonrestart(FILE *input_file);
 
 class json_parsert:public parsert
 {
 public:
   typedef std::stack<jsont, std::vector<jsont> > stackt;
   stackt stack;
-  
-  inline jsont &top() { return stack.top(); }
-  
+
+  jsont &top() { return stack.top(); }
+
   virtual bool parse() override
   {
     return yyjsonparse()!=0;
   }
-  
-  inline void push(const jsont &x)
+
+  void push(const jsont &x)
   {
     stack.push(x);
   }
 
-  inline void pop(jsont &dest)
+  void pop(jsont &dest)
   {
     assert(!stack.empty());
     dest.swap(stack.top());
@@ -45,6 +47,7 @@ public:
   virtual void clear() override
   {
     stack=stackt();
+    yyjsonrestart(nullptr);
   }
 };
 
@@ -64,4 +67,4 @@ bool parse_json(
   message_handlert &message_handler,
   jsont &dest);
 
-#endif
+#endif // CPROVER_JSON_JSON_PARSER_H
