@@ -6,14 +6,16 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
 #ifndef CPROVER_LINKING_STATIC_LIFETIME_INIT_H
 #define CPROVER_LINKING_STATIC_LIFETIME_INIT_H
 
-#include <util/symbol_table.h>
-#include <util/message.h>
-#include <util/source_location.h>
 #include <util/cprover_prefix.h>
 
+class message_handlert;
+class source_locationt;
+class symbol_tablet;
+
 bool static_lifetime_init(
   symbol_tablet &symbol_table,
   const source_locationt &source_location,
@@ -21,4 +23,4 @@ bool static_lifetime_init(
 
 #define INITIALIZE_FUNCTION CPROVER_PREFIX "initialize"
 
-#endif
+#endif // CPROVER_LINKING_STATIC_LIFETIME_INIT_H
