@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_CBMC_PARSEOPTIONS_H
-#define CPROVER_CBMC_PARSEOPTIONS_H
+/// \file
+/// mmcc Command Line Option Processing
+
+#ifndef CPROVER_MEMORY_MODELS_MMCC_PARSE_OPTIONS_H
+#define CPROVER_MEMORY_MODELS_MMCC_PARSE_OPTIONS_H
 
 #include <util/parse_options.h>
 
@@ -28,4 +31,4 @@ protected:
   int convert(std::istream &, const std::string &);
 };
 
-#endif
+#endif // CPROVER_MEMORY_MODELS_MMCC_PARSE_OPTIONS_H
