@@ -6,21 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+/// \file
+/// Pointer Dereferencing
+
 #include "dereference_callback.h"
 
-/*******************************************************************\
-
-Function: dereference_callbackt::~dereference_callbackt
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 dereference_callbackt::~dereference_callbackt()
 {
 }
-
