@@ -6,19 +6,12 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+/// \file
+/// Pointer Analysis
+
 #include "pointer_offset_sum.h"
 
-/*******************************************************************\
-
-Function: pointer_offset_sum
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <util/std_expr.h>
 
 exprt pointer_offset_sum(const exprt &a, const exprt &b)
 {
@@ -31,10 +24,9 @@ exprt pointer_offset_sum(const exprt &a, const exprt &b)
   else if(b.is_zero())
     return a;
 
-  exprt new_offset(ID_plus, a.type());
-  new_offset.copy_to_operands(a, b);
+  plus_exprt new_offset(a, b);
 
-  if(new_offset.op1().type()!=a.type())
+  if(b.type() != a.type())
     new_offset.op1().make_typecast(a.type());
 
   return new_offset;
