@@ -6,22 +6,14 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/std_expr.h>
+/// \file
+/// Pointer Dereferencing
 
 #include "rewrite_index.h"
 
-/*******************************************************************\
-
-Function: rewrite_index
-
-  Inputs:
-
- Outputs:
-
- Purpose: rewrite a[i] to *(a+i)
-
-\*******************************************************************/
+#include <util/std_expr.h>
 
+/// rewrite a[i] to *(a+i)
 dereference_exprt rewrite_index(const index_exprt &index_expr)
 {
   dereference_exprt result;
