@@ -21,9 +21,9 @@ Author: Daniel Kroening, kroening@kroening.com
 class xmlt;
 
 void value_sets_to_xml(
-  std::function<const value_sett &(goto_programt::const_targett)> get_value_set,
+  const std::function<const value_sett &(goto_programt::const_targett)>
+    &get_value_set,
   const goto_programt &goto_program,
-  const irep_idt &identifier,
   xmlt &dest);
 
 template<class VSDT>
@@ -40,15 +40,19 @@ public:
   {
   }
 
+  const value_sett &get_value_set(goto_programt::const_targett t)
+  {
+    return (*this)[t].value_set;
+  }
+
   void convert(
     const goto_programt &goto_program,
-    const irep_idt &identifier,
     xmlt &dest) const
   {
+    using std::placeholders::_1;
     value_sets_to_xml(
-      [this](locationt l) { return (*this)[l].value_set; },
+      std::bind(&value_set_analysis_templatet::get_value_set, *this, _1),
       goto_program,
-      identifier,
       dest);
   }
 
