@@ -32,7 +32,7 @@ public:
   }
 
   virtual void initialize(
-    const namespacet &ns)
+    const namespacet &)
   {
     value_set.clear();
   }
