@@ -7,10 +7,16 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef VALUE_SET_FI_H_
-#define VALUE_SET_FI_H_
+/// \file
+/// Value Set (Flow Insensitive, Sharing)
 
+#ifndef CPROVER_POINTER_ANALYSIS_VALUE_SET_FI_H
+#define CPROVER_POINTER_ANALYSIS_VALUE_SET_FI_H
+
+#include <list>
+#include <map>
 #include <set>
+#include <unordered_set>
 
 #include <util/mp_arith.h>
 #include <util/namespace.h>
@@ -21,7 +27,10 @@ Author: Daniel Kroening, kroening@kroening.com
 class value_set_fit
 {
 public:
-  value_set_fit()
+  value_set_fit():
+  changed(false)
+  // to_function, to_target_index are set by set_to()
+  // from_function, from_target_index are set by set_from()
   {
   }
 
@@ -29,139 +38,169 @@ public:
   unsigned to_target_index, from_target_index;
   static object_numberingt object_numbering;
   static hash_numbering<irep_idt, irep_id_hash> function_numbering;
-  
-  void set_from(const irep_idt& function, unsigned inx)
+
+  void set_from(const irep_idt &function, unsigned inx)
   {
     from_function = function_numbering.number(function);
     from_target_index = inx;
   }
-  
+
   void set_to(const irep_idt &function, unsigned inx)
   {
-    to_function = function_numbering.number(function);      
+    to_function = function_numbering.number(function);
     to_target_index = inx;
   }
 
   typedef irep_idt idt;
-  
-  class objectt
+
+  /// Represents the offset into an object: either a unique integer offset,
+  /// or an unknown value, represented by `!offset`.
+  typedef optionalt<mp_integer> offsett;
+  bool offset_is_zero(const offsett &offset) const
   {
-  public:
-    objectt():offset_is_set(false)
-    {
-    }
-  
-    explicit objectt(const mp_integer &_offset):
-      offset(_offset),
-      offset_is_set(true)
-    {
-    }
-  
-    mp_integer offset;
-    bool offset_is_set;
-    bool offset_is_zero() const
-    { return offset_is_set && offset.is_zero(); }
-  };
-  
-  class object_map_dt:public std::map<unsigned, objectt>
-  {
-  public:
-    object_map_dt() {}
-    const static object_map_dt blank;
-  };
-  
-  exprt to_expr(object_map_dt::const_iterator it) const;
-  
-  typedef reference_counting<object_map_dt> object_mapt;
-  
-  void set(object_mapt &dest, object_map_dt::const_iterator it) const
-  {
-    dest.write()[it->first]=it->second;
+    return offset && offset->is_zero();
   }
 
-  bool insert(object_mapt &dest, object_map_dt::const_iterator it) const
+  class object_map_dt
   {
-    return insert(dest, it->first, it->second);
+    typedef std::map<object_numberingt::number_type, offsett> data_typet;
+    data_typet data;
+
+  public:
+    // NOLINTNEXTLINE(readability/identifiers)
+    typedef data_typet::iterator iterator;
+    // NOLINTNEXTLINE(readability/identifiers)
+    typedef data_typet::const_iterator const_iterator;
+    // NOLINTNEXTLINE(readability/identifiers)
+    typedef data_typet::value_type value_type;
+
+    iterator begin() { return data.begin(); }
+    const_iterator begin() const { return data.begin(); }
+    const_iterator cbegin() const { return data.cbegin(); }
+
+    iterator end() { return data.end(); }
+    const_iterator end() const { return data.end(); }
+    const_iterator cend() const { return data.cend(); }
+
+    size_t size() const { return data.size(); }
+
+    offsett &operator[](object_numberingt::number_type i)
+    {
+      return data[i];
+    }
+
+    template <typename It>
+    void insert(It b, It e) { data.insert(b, e); }
+
+    template <typename T>
+    const_iterator find(T &&t) const { return data.find(std::forward<T>(t)); }
+
+    static const object_map_dt blank;
+
+  protected:
+    ~object_map_dt()=default;
+  };
+
+  exprt to_expr(const object_map_dt::value_type &it) const;
+
+  typedef reference_counting<object_map_dt> object_mapt;
+
+  void set(object_mapt &dest, const object_map_dt::value_type &it) const
+  {
+    dest.write()[it.first]=it.second;
+  }
+
+  bool insert(object_mapt &dest, const object_map_dt::value_type &it) const
+  {
+    return insert(dest, it.first, it.second);
   }
 
   bool insert(object_mapt &dest, const exprt &src) const
   {
-    return insert(dest, object_numbering.number(src), objectt());
+    return insert(dest, object_numbering.number(src), offsett());
   }
-  
-  bool insert(object_mapt &dest, const exprt &src, const mp_integer &offset) const
+
+  bool insert(
+    object_mapt &dest,
+    const exprt &src,
+    const mp_integer &offset_value) const
   {
-    return insert(dest, object_numbering.number(src), objectt(offset));
+    return insert(dest, object_numbering.number(src), offsett(offset_value));
   }
-  
-  bool insert(object_mapt &dest, unsigned n, const objectt &object) const
-  {    
+
+  bool insert(
+    object_mapt &dest,
+    object_numberingt::number_type n,
+    const offsett &offset) const
+  {
     if(dest.read().find(n)==dest.read().end())
     {
       // new
-      dest.write()[n]=object;
+      dest.write()[n] = offset;
       return true;
     }
     else
     {
-      objectt &old=dest.write()[n];
-      
-      if(old.offset_is_set && object.offset_is_set)
+      offsett &old_offset = dest.write()[n];
+
+      if(old_offset && offset)
       {
-        if(old.offset==object.offset)
+        if(*old_offset == *offset)
           return false;
         else
         {
-          old.offset_is_set=false;
+          old_offset.reset();
           return true;
         }
       }
-      else if(!old.offset_is_set)
+      else if(!old_offset)
         return false;
       else
       {
-        old.offset_is_set=false;
+        old_offset.reset();
         return true;
       }
     }
   }
-  
-  bool insert(object_mapt &dest, const exprt &expr, const objectt &object) const
+
+  bool insert(object_mapt &dest, const exprt &expr, const offsett &offset) const
   {
-    return insert(dest, object_numbering.number(expr), object);
+    return insert(dest, object_numbering.number(expr), offset);
   }
-  
+
   struct entryt
   {
     object_mapt object_map;
     idt identifier;
     std::string suffix;
-    
+
     entryt()
     {
     }
-    
+
     entryt(const idt &_identifier, const std::string _suffix):
       identifier(_identifier),
       suffix(_suffix)
     {
     }
   };
-  
-  typedef hash_set_cont<exprt, irep_hash> expr_sett;
 
-  #ifdef USE_DSTRING   
+  typedef std::unordered_set<exprt, irep_hash> expr_sett;
+
+  typedef std::unordered_set<unsigned int> dynamic_object_id_sett;
+
+  #ifdef USE_DSTRING
   typedef std::map<idt, entryt> valuest;
   typedef std::set<idt> flatten_seent;
-  typedef hash_set_cont<idt, irep_id_hash> gvs_recursion_sett;
-  typedef hash_set_cont<idt, irep_id_hash> recfind_recursion_sett;
-  typedef hash_set_cont<idt, irep_id_hash> assign_recursion_sett;
+  typedef std::unordered_set<idt> gvs_recursion_sett;
+  typedef std::unordered_set<idt> recfind_recursion_sett;
+  typedef std::unordered_set<idt> assign_recursion_sett;
   #else
-  typedef hash_map_cont<idt, entryt, string_hash> valuest;
-  typedef hash_set_cont<idt, string_hash> flatten_seent;
-  typedef hash_set_cont<idt, string_hash> gvs_recursion_sett;
-  typedef hash_set_cont<idt, string_hash> recfind_recursion_sett;
-  typedef hash_set_cont<idt, string_hash> assign_recursion_sett;
+  typedef std::unordered_map<idt, entryt, string_hash> valuest;
+  typedef std::unordered_set<idt, string_hash> flatten_seent;
+  typedef std::unordered_set<idt, string_hash> gvs_recursion_sett;
+  typedef std::unordered_set<idt, string_hash> recfind_recursion_sett;
+  typedef std::unordered_set<idt, string_hash> assign_recursion_sett;
   #endif
 
   void get_value_set(
@@ -177,12 +216,12 @@ public:
   {
     values.clear();
   }
-  
+
   void clear()
   {
     values.clear();
   }
-  
+
   void add_var(const idt &id, const std::string &suffix)
   {
     get_entry(id, suffix);
@@ -192,12 +231,12 @@ public:
   {
     get_entry(e.identifier, e.suffix);
   }
-  
+
   entryt &get_entry(const idt &id, const std::string &suffix)
   {
     return get_entry(entryt(id, suffix));
   }
-  
+
   entryt &get_entry(const entryt &e)
   {
     std::string index=id2string(e.identifier)+e.suffix;
@@ -207,7 +246,7 @@ public:
 
     return r.first->second;
   }
-  
+
   void add_vars(const std::list<entryt> &vars)
   {
     for(std::list<entryt>::const_iterator
@@ -220,23 +259,23 @@ public:
   void output(
     const namespacet &ns,
     std::ostream &out) const;
-    
+
   valuest values;
-  
+
   bool changed;
-  
-  // true = added s.th. new
+
+  // true = added something new
   bool make_union(object_mapt &dest, const object_mapt &src) const;
 
-  // true = added s.th. new
+  // true = added something new
   bool make_union(const valuest &new_values);
 
-  // true = added s.th. new
+  // true = added something new
   bool make_union(const value_set_fit &new_values)
   {
     return make_union(new_values.values);
   }
-  
+
   void apply_code(
     const exprt &code,
     const namespacet &ns);
@@ -266,7 +305,7 @@ protected:
     const exprt &expr,
     expr_sett &expr_set,
     const namespacet &ns) const;
-    
+
   void get_value_set_rec(
     const exprt &expr,
     object_mapt &dest,
@@ -308,12 +347,13 @@ protected:
   void do_free(
     const exprt &op,
     const namespacet &ns);
-    
+
   void flatten(const entryt &e, object_mapt &dest) const;
-  
-  void flatten_rec( const entryt&, 
-                    object_mapt&, 
-                    flatten_seent&) const;
+
+  void flatten_rec(
+    const entryt&,
+    object_mapt&,
+    flatten_seent&) const;
 };
 
-#endif /*VALUE_SET_FI_H_*/
+#endif // CPROVER_POINTER_ANALYSIS_VALUE_SET_FI_H
