@@ -6,30 +6,17 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <iostream>
-
-#include <util/std_types.h>
-
 #include "boolbv.h"
 
-#include "../floatbv/float_utils.h"
+#include <util/invariant.h>
+#include <util/std_types.h>
 
-/*******************************************************************\
-
-Function: boolbvt::convert_add_sub
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <solvers/floatbv/float_utils.h>
 
 bvt boolbvt::convert_add_sub(const exprt &expr)
 {
   const typet &type=ns.follow(expr.type());
-  
+
   if(type.id()!=ID_unsignedbv &&
      type.id()!=ID_signedbv &&
      type.id()!=ID_fixedbv &&
@@ -40,22 +27,18 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
     return conversion_failed(expr);
 
   std::size_t width=boolbv_width(type);
-  
+
   if(width==0)
     return conversion_failed(expr);
-    
+
   const exprt::operandst &operands=expr.operands();
 
   if(operands.empty())
     throw "operator "+expr.id_string()+" takes at least one operand";
 
   const exprt &op0=expr.op0();
-
-  if(op0.type()!=type)
-  {
-    std::cerr << expr.pretty() << std::endl;
-    throw "add/sub with mixed types";
-  }
+  DATA_INVARIANT(
+    op0.type() == type, "add/sub with mixed types:\n" + expr.pretty());
 
   bvt bv=convert_bv(op0);
 
@@ -64,7 +47,7 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
 
   bool subtract=(expr.id()==ID_minus ||
                  expr.id()=="no-overflow-minus");
-                 
+
   bool no_overflow=(expr.id()=="no-overflow-plus" ||
                     expr.id()=="no-overflow-minus");
 
@@ -74,18 +57,15 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
 
   bv_utilst::representationt rep=
     (arithmetic_type.id()==ID_signedbv ||
-     arithmetic_type.id()==ID_fixedbv)?bv_utilst::SIGNED:
-                                       bv_utilst::UNSIGNED;
+     arithmetic_type.id()==ID_fixedbv)?bv_utilst::representationt::SIGNED:
+                                       bv_utilst::representationt::UNSIGNED;
 
   for(exprt::operandst::const_iterator
       it=operands.begin()+1;
       it!=operands.end(); it++)
   {
-    if(it->type()!=type)
-    {
-      std::cerr << expr.pretty() << std::endl;
-      throw "add/sub with mixed types";
-    }
+    DATA_INVARIANT(
+      it->type() == type, "add/sub with mixed types:\n" + expr.pretty());
 
     const bvt &op=convert_bv(*it);
 
@@ -95,7 +75,7 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
     if(type.id()==ID_vector || type.id()==ID_complex)
     {
       const typet &subtype=ns.follow(type.subtype());
-    
+
       std::size_t sub_width=boolbv_width(subtype);
 
       if(sub_width==0 || width%sub_width!=0)
@@ -114,7 +94,7 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
           assert(i*sub_width+j<op.size());
           tmp_op[j]=op[i*sub_width+j];
         }
-        
+
         bvt tmp_result;
         tmp_result.resize(sub_width);
 
@@ -123,19 +103,18 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
           assert(i*sub_width+j<bv.size());
           tmp_result[j]=bv[i*sub_width+j];
         }
-        
+
         if(type.subtype().id()==ID_floatbv)
         {
           // needs to change due to rounding mode
-          float_utilst float_utils(prop);
-          float_utils.spec=to_floatbv_type(subtype);
+          float_utilst float_utils(prop, to_floatbv_type(subtype));
           tmp_result=float_utils.add_sub(tmp_result, tmp_op, subtract);
         }
         else
           tmp_result=bv_utils.add_sub(tmp_result, tmp_op, subtract);
-      
+
         assert(tmp_result.size()==sub_width);
-        
+
         for(std::size_t j=0; j<tmp_result.size(); j++)
         {
           assert(i*sub_width+j<bv.size());
@@ -146,8 +125,7 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
     else if(type.id()==ID_floatbv)
     {
       // needs to change due to rounding mode
-      float_utilst float_utils(prop);
-      float_utils.spec=to_floatbv_type(arithmetic_type);
+      float_utilst float_utils(prop, to_floatbv_type(arithmetic_type));
       bv=float_utils.add_sub(bv, op, subtract);
     }
     else if(no_overflow)
@@ -155,7 +133,6 @@ bvt boolbvt::convert_add_sub(const exprt &expr)
     else
       bv=bv_utils.add_sub(bv, op, subtract);
   }
-  
+
   return bv;
 }
-
