@@ -6,20 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
 #include "boolbv.h"
 
-/*******************************************************************\
-
-Function: boolbvt::convert_constraint_select_one
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt boolbvt::convert_constraint_select_one(const exprt &expr)
 {
   const exprt::operandst &operands=expr.operands();
@@ -34,7 +23,7 @@ bvt boolbvt::convert_constraint_select_one(const exprt &expr)
     throw "constraint_select_one expects matching types";
 
   bvt bv;
- 
+
   if(prop.has_set_to())
   {
     std::size_t width=boolbv_width(expr.type());
@@ -77,7 +66,6 @@ bvt boolbvt::convert_constraint_select_one(const exprt &expr)
       op_nr++;
     }
   }
-  
+
   return bv;
 }
-
