@@ -6,26 +6,14 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+#include "boolbv.h"
+
 #include <algorithm>
 #include <iostream>
 
 #include <util/std_types.h>
 
-#include "boolbv.h"
-
-#include "../floatbv/float_utils.h"
-
-/*******************************************************************\
-
-Function: boolbvt::convert_floatbv_typecast
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <solvers/floatbv/float_utils.h>
 
 bvt boolbvt::convert_floatbv_typecast(const floatbv_typecast_exprt &expr)
 {
@@ -37,66 +25,57 @@ bvt boolbvt::convert_floatbv_typecast(const floatbv_typecast_exprt &expr)
 
   const typet &src_type=ns.follow(expr.op0().type());
   const typet &dest_type=ns.follow(expr.type());
-  
+
   if(src_type==dest_type) // redundant type cast?
     return bv0;
 
   float_utilst float_utils(prop);
-  
+
   float_utils.set_rounding_mode(convert_bv(op1));
-  
+
   if(src_type.id()==ID_floatbv &&
      dest_type.id()==ID_floatbv)
   {
-    float_utils.spec=to_floatbv_type(src_type);
-    return float_utils.conversion(bv0, to_floatbv_type(dest_type));
+    float_utils.spec=ieee_float_spect(to_floatbv_type(src_type));
+    return
+      float_utils.conversion(
+        bv0,
+        ieee_float_spect(to_floatbv_type(dest_type)));
   }
   else if(src_type.id()==ID_signedbv &&
           dest_type.id()==ID_floatbv)
   {
-    float_utils.spec=to_floatbv_type(dest_type);
+    float_utils.spec=ieee_float_spect(to_floatbv_type(dest_type));
     return float_utils.from_signed_integer(bv0);
   }
   else if(src_type.id()==ID_unsignedbv &&
           dest_type.id()==ID_floatbv)
   {
-    float_utils.spec=to_floatbv_type(dest_type);
+    float_utils.spec=ieee_float_spect(to_floatbv_type(dest_type));
     return float_utils.from_unsigned_integer(bv0);
   }
   else if(src_type.id()==ID_floatbv &&
           dest_type.id()==ID_signedbv)
   {
     std::size_t dest_width=to_signedbv_type(dest_type).get_width();
-    float_utils.spec=to_floatbv_type(src_type);
+    float_utils.spec=ieee_float_spect(to_floatbv_type(src_type));
     return float_utils.to_signed_integer(bv0, dest_width);
   }
   else if(src_type.id()==ID_floatbv &&
           dest_type.id()==ID_unsignedbv)
   {
     std::size_t dest_width=to_unsignedbv_type(dest_type).get_width();
-    float_utils.spec=to_floatbv_type(src_type);
+    float_utils.spec=ieee_float_spect(to_floatbv_type(src_type));
     return float_utils.to_unsigned_integer(bv0, dest_width);
   }
   else
     return conversion_failed(expr);
 }
 
-/*******************************************************************\
-
-Function: boolbvt::convert_floatbv_op
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt boolbvt::convert_floatbv_op(const exprt &expr)
 {
   const exprt::operandst &operands=expr.operands();
-  
+
   if(operands.size()!=3)
     throw "operator "+expr.id_string()+" takes three operands";
 
@@ -109,20 +88,17 @@ bvt boolbvt::convert_floatbv_op(const exprt &expr)
   bvt bv2=convert_bv(op2);
 
   const typet &type=ns.follow(expr.type());
-
-  if(op0.type()!=type || op1.type()!=type)
-  {
-    std::cerr << expr.pretty() << std::endl;
-    throw "float op with mixed types";
-  }
+  DATA_INVARIANT(
+    op0.type() == type && op1.type() == type,
+    "float op with mixed types:\n" + expr.pretty());
 
   float_utilst float_utils(prop);
-  
+
   float_utils.set_rounding_mode(bv2);
 
   if(type.id()==ID_floatbv)
   {
-    float_utils.spec=to_floatbv_type(expr.type());
+    float_utils.spec=ieee_float_spect(to_floatbv_type(expr.type()));
 
     if(expr.id()==ID_floatbv_plus)
       return float_utils.add_sub(bv0, bv1, false);
@@ -135,15 +111,15 @@ bvt boolbvt::convert_floatbv_op(const exprt &expr)
     else if(expr.id()==ID_floatbv_rem)
       return float_utils.rem(bv0, bv1);
     else
-      assert(false);
+      throw "unexpected operator "+expr.id_string();
   }
   else if(type.id()==ID_vector || type.id()==ID_complex)
   {
     const typet &subtype=ns.follow(type.subtype());
-    
+
     if(subtype.id()==ID_floatbv)
     {
-      float_utils.spec=to_floatbv_type(subtype);
+      float_utils.spec=ieee_float_spect(to_floatbv_type(subtype));
 
       std::size_t width=boolbv_width(type);
       std::size_t sub_width=boolbv_width(subtype);
@@ -158,7 +134,7 @@ bvt boolbvt::convert_floatbv_op(const exprt &expr)
       for(std::size_t i=0; i<size; i++)
       {
         bvt tmp_bv0, tmp_bv1, tmp_bv;
-        
+
         tmp_bv0.assign(bv0.begin()+i*sub_width, bv0.begin()+(i+1)*sub_width);
         tmp_bv1.assign(bv1.begin()+i*sub_width, bv1.begin()+(i+1)*sub_width);
 
@@ -177,7 +153,7 @@ bvt boolbvt::convert_floatbv_op(const exprt &expr)
         assert(i*sub_width+sub_width-1<bv.size());
         std::copy(tmp_bv.begin(), tmp_bv.end(), bv.begin()+i*sub_width);
       }
-      
+
       return bv;
     }
     else
@@ -186,4 +162,3 @@ bvt boolbvt::convert_floatbv_op(const exprt &expr)
   else
     return conversion_failed(expr);
 }
-
