@@ -6,20 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
 #include "boolbv.h"
 
-/*******************************************************************\
-
-Function: boolbvt::convert_if
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt boolbvt::convert_if(const if_exprt &expr)
 {
   std::size_t width=boolbv_width(expr.type());
@@ -28,7 +17,7 @@ bvt boolbvt::convert_if(const if_exprt &expr)
     return bvt(); // An empty bit-vector if.
 
   literalt cond=convert(expr.cond());
-  
+
   const bvt &op1_bv=convert_bv(expr.true_case());
   const bvt &op2_bv=convert_bv(expr.false_case());
 
