@@ -6,26 +6,15 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
 #include "boolbv.h"
 
-/*******************************************************************\
-
-Function: boolbvt::convert_power
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt boolbvt::convert_power(const binary_exprt &expr)
 {
   const typet &type=ns.follow(expr.type());
 
   std::size_t width=boolbv_width(type);
-  
+
   if(width==0)
     return conversion_failed(expr);
 
@@ -38,12 +27,12 @@ bvt boolbvt::convert_power(const binary_exprt &expr)
 
     literalt eq_2=
       bv_utils.equal(op0, bv_utils.build_constant(2, op0.size()));
-    
+
     bvt one=bv_utils.build_constant(1, width);
-    bvt shift=bv_utils.shift(one, bv_utilst::LEFT, op1);
-    
+    bvt shift=bv_utils.shift(one, bv_utilst::shiftt::SHIFT_LEFT, op1);
+
     bvt nondet=prop.new_variables(width);
-    
+
     return bv_utils.select(eq_2, shift, nondet);
   }
 
