@@ -6,26 +6,14 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/arith_tools.h>
-
 #include "boolbv.h"
 
-/*******************************************************************\
-
-Function: boolbvt::convert_replication
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <util/arith_tools.h>
 
 bvt boolbvt::convert_replication(const replication_exprt &expr)
 {
   std::size_t width=boolbv_width(expr.type());
-  
+
   if(width==0)
     return conversion_failed(expr);
 
@@ -49,10 +37,10 @@ bvt boolbvt::convert_replication(const replication_exprt &expr)
       bv[i+offset]=op[i];
 
     offset+=op.size();
-  }    
+  }
 
   if(offset!=bv.size())
     throw "replication operand width too small";
-    
+
   return bv;
 }
