@@ -6,34 +6,23 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+#include "boolbv.h"
+
 #include <cassert>
 
 #include <util/std_types.h>
 
-#include "boolbv.h"
+#include <solvers/floatbv/float_utils.h>
+
 #include "boolbv_type.h"
 #include "c_bit_field_replacement_type.h"
 
-#include "../floatbv/float_utils.h"
-
-/*******************************************************************\
-
-Function: boolbvt::convert_bv_typecast
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt boolbvt::convert_bv_typecast(const typecast_exprt &expr)
 {
   const typet &expr_type=ns.follow(expr.type());
   const exprt &op=expr.op();
   const typet &op_type=ns.follow(op.type());
-  const bvt &op_bv=convert_bv(op);  
+  const bvt &op_bv=convert_bv(op);
 
   bvt bv;
 
@@ -43,39 +32,35 @@ bvt boolbvt::convert_bv_typecast(const typecast_exprt &expr)
   return bv;
 }
 
-/*******************************************************************\
-
-Function: boolbvt::type_conversion
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bool boolbvt::type_conversion(
   const typet &src_type, const bvt &src,
   const typet &dest_type, bvt &dest)
 {
   bvtypet dest_bvtype=get_bvtype(dest_type);
   bvtypet src_bvtype=get_bvtype(src_type);
-  
-  if(src_bvtype==IS_C_BIT_FIELD)
-    return type_conversion(
-      c_bit_field_replacement_type(to_c_bit_field_type(src_type), ns), src, dest_type, dest);
 
-  if(dest_bvtype==IS_C_BIT_FIELD)
-    return type_conversion(
-      src_type, src, c_bit_field_replacement_type(to_c_bit_field_type(dest_type), ns), dest);
+  if(src_bvtype==bvtypet::IS_C_BIT_FIELD)
+    return
+      type_conversion(
+        c_bit_field_replacement_type(to_c_bit_field_type(src_type), ns),
+        src,
+        dest_type,
+        dest);
+
+  if(dest_bvtype==bvtypet::IS_C_BIT_FIELD)
+    return
+      type_conversion(
+        src_type,
+        src,
+        c_bit_field_replacement_type(to_c_bit_field_type(dest_type), ns),
+        dest);
 
   std::size_t src_width=src.size();
   std::size_t dest_width=boolbv_width(dest_type);
-  
+
   if(dest_width==0 || src_width==0)
     return true;
-  
+
   dest.clear();
   dest.reserve(dest_width);
 
@@ -98,15 +83,23 @@ bool boolbvt::type_conversion(
       bvt lower, upper, lower_res, upper_res;
       lower.assign(src.begin(), src.begin()+src.size()/2);
       upper.assign(src.begin()+src.size()/2, src.end());
-      type_conversion(ns.follow(src_type.subtype()), lower, ns.follow(dest_type.subtype()), lower_res);
-      type_conversion(ns.follow(src_type.subtype()), upper, ns.follow(dest_type.subtype()), upper_res);
+      type_conversion(
+        ns.follow(src_type.subtype()),
+        lower,
+        ns.follow(dest_type.subtype()),
+        lower_res);
+      type_conversion(
+        ns.follow(src_type.subtype()),
+        upper,
+        ns.follow(dest_type.subtype()),
+        upper_res);
       assert(lower_res.size()+upper_res.size()==dest_width);
       dest=lower_res;
       dest.insert(dest.end(), upper_res.begin(), upper_res.end());
       return false;
     }
   }
-  
+
   if(src_type.id()==ID_complex)
   {
     assert(dest_type.id()!=ID_complex);
@@ -125,13 +118,13 @@ bool boolbvt::type_conversion(
       return type_conversion(src_type.subtype(), tmp_src, dest_type, dest);
     }
   }
-  
+
   switch(dest_bvtype)
   {
-  case IS_RANGE:
-    if(src_bvtype==IS_UNSIGNED ||
-       src_bvtype==IS_SIGNED ||
-       src_bvtype==IS_C_BOOL)
+  case bvtypet::IS_RANGE:
+    if(src_bvtype==bvtypet::IS_UNSIGNED ||
+       src_bvtype==bvtypet::IS_SIGNED ||
+       src_bvtype==bvtypet::IS_C_BOOL)
     {
       mp_integer dest_from=to_range_type(dest_type).get_from();
 
@@ -145,7 +138,7 @@ bool boolbvt::type_conversion(
         return false;
       }
     }
-    else if(src_bvtype==IS_RANGE) // range to range
+    else if(src_bvtype==bvtypet::IS_RANGE) // range to range
     {
       mp_integer src_from=to_range_type(src_type).get_from();
       mp_integer dest_from=to_range_type(dest_type).get_from();
@@ -169,31 +162,31 @@ bool boolbvt::type_conversion(
       return false;
     }
     break;
-    
-  case IS_FLOAT: // to float
+
+  case bvtypet::IS_FLOAT: // to float
     {
       float_utilst float_utils(prop);
-      
+
       switch(src_bvtype)
       {
-      case IS_FLOAT: // float to float
+      case bvtypet::IS_FLOAT: // float to float
         // we don't have a rounding mode here,
         // which is why we refuse.
         break;
 
-      case IS_SIGNED: // signed to float
-      case IS_C_ENUM:
-        float_utils.spec=to_floatbv_type(dest_type);
+      case bvtypet::IS_SIGNED: // signed to float
+      case bvtypet::IS_C_ENUM:
+        float_utils.spec=ieee_float_spect(to_floatbv_type(dest_type));
         dest=float_utils.from_signed_integer(src);
         return false;
 
-      case IS_UNSIGNED: // unsigned to float
-      case IS_C_BOOL: // _Bool to float
-        float_utils.spec=to_floatbv_type(dest_type);
+      case bvtypet::IS_UNSIGNED: // unsigned to float
+      case bvtypet::IS_C_BOOL: // _Bool to float
+        float_utils.spec=ieee_float_spect(to_floatbv_type(dest_type));
         dest=float_utils.from_unsigned_integer(src);
         return false;
 
-      case IS_BV:
+      case bvtypet::IS_BV:
         assert(src_width==dest_width);
         dest=src;
         return false;
@@ -202,37 +195,38 @@ bool boolbvt::type_conversion(
         if(src_type.id()==ID_bool)
         {
           // bool to float
-          
+
           // build a one
-          ieee_floatt f;
-          f.spec=to_floatbv_type(dest_type);
+          ieee_floatt f(to_floatbv_type(dest_type));
           f.from_integer(1);
-          
+
           dest=convert_bv(f.to_expr());
 
           assert(src_width==1);
-          
+
           Forall_literals(it, dest)
             *it=prop.land(*it, src[0]);
-            
+
           return false;
         }
       }
     }
     break;
 
-  case IS_FIXED:
-    if(src_bvtype==IS_FIXED)
+  case bvtypet::IS_FIXED:
+    if(src_bvtype==bvtypet::IS_FIXED)
     {
       // fixed to fixed
-      
-      std::size_t dest_fraction_bits=to_fixedbv_type(dest_type).get_fraction_bits(),
-                  dest_int_bits=dest_width-dest_fraction_bits;
-      std::size_t op_fraction_bits=to_fixedbv_type(src_type).get_fraction_bits(),
-                  op_int_bits=src_width-op_fraction_bits;
-      
+
+      std::size_t dest_fraction_bits=
+        to_fixedbv_type(dest_type).get_fraction_bits();
+      std::size_t dest_int_bits=dest_width-dest_fraction_bits;
+      std::size_t op_fraction_bits=
+        to_fixedbv_type(src_type).get_fraction_bits();
+      std::size_t op_int_bits=src_width-op_fraction_bits;
+
       dest.resize(dest_width);
-      
+
       // i == position after dot
       // i == 0: first position after dot
 
@@ -240,10 +234,10 @@ bool boolbvt::type_conversion(
       {
         // position in bv
         std::size_t p=dest_fraction_bits-i-1;
-      
+
         if(i<op_fraction_bits)
           dest[p]=src[op_fraction_bits-i-1];
-        else 
+        else
           dest[p]=const_literal(false); // zero padding
       }
 
@@ -252,25 +246,25 @@ bool boolbvt::type_conversion(
         // position in bv
         std::size_t p=dest_fraction_bits+i;
         assert(p<dest_width);
-      
+
         if(i<op_int_bits)
           dest[p]=src[i+op_fraction_bits];
-        else 
+        else
           dest[p]=src[src_width-1]; // sign extension
       }
 
       return false;
     }
-    else if(src_bvtype==IS_BV)
+    else if(src_bvtype==bvtypet::IS_BV)
     {
       assert(src_width==dest_width);
       dest=src;
       return false;
     }
-    else if(src_bvtype==IS_UNSIGNED ||
-            src_bvtype==IS_SIGNED ||
-            src_bvtype==IS_C_BOOL ||
-            src_bvtype==IS_C_ENUM)
+    else if(src_bvtype==bvtypet::IS_UNSIGNED ||
+            src_bvtype==bvtypet::IS_SIGNED ||
+            src_bvtype==bvtypet::IS_C_BOOL ||
+            src_bvtype==bvtypet::IS_C_ENUM)
     {
       // integer to fixed
 
@@ -283,17 +277,17 @@ bool boolbvt::type_conversion(
       for(std::size_t i=0; i<dest_width-dest_fraction_bits; i++)
       {
         literalt l;
-      
+
         if(i<src_width)
           l=src[i];
         else
         {
-          if(src_bvtype==IS_SIGNED || src_bvtype==IS_C_ENUM)
+          if(src_bvtype==bvtypet::IS_SIGNED || src_bvtype==bvtypet::IS_C_ENUM)
             l=src[src_width-1]; // sign extension
           else
             l=const_literal(false); // zero extension
         }
-        
+
         dest.push_back(l);
       }
 
@@ -318,18 +312,18 @@ bool boolbvt::type_conversion(
       return false;
     }
     break;
-  
-  case IS_UNSIGNED:
-  case IS_SIGNED:
-  case IS_C_ENUM:
+
+  case bvtypet::IS_UNSIGNED:
+  case bvtypet::IS_SIGNED:
+  case bvtypet::IS_C_ENUM:
     switch(src_bvtype)
     {
-    case IS_FLOAT: // float to integer
+    case bvtypet::IS_FLOAT: // float to integer
       // we don't have a rounding mode here,
       // which is why we refuse.
       break;
-     
-    case IS_FIXED: // fixed to integer
+
+    case bvtypet::IS_FIXED: // fixed to integer
       {
         std::size_t op_fraction_bits=
           to_fixedbv_type(src_type).get_fraction_bits();
@@ -340,16 +334,16 @@ bool boolbvt::type_conversion(
             dest.push_back(src[i+op_fraction_bits]);
           else
           {
-            if(dest_bvtype==IS_SIGNED)
+            if(dest_bvtype==bvtypet::IS_SIGNED)
               dest.push_back(src[src_width-1]); // sign extension
             else
               dest.push_back(const_literal(false)); // zero extension
           }
         }
-        
+
         // we might need to round up in case of negative numbers
         // e.g., (int)(-1.00001)==1
-        
+
         bvt fraction_bits_bv=src;
         fraction_bits_bv.resize(op_fraction_bits);
         literalt round_up=
@@ -360,17 +354,17 @@ bool boolbvt::type_conversion(
         return false;
       }
 
-    case IS_UNSIGNED: // integer to integer
-    case IS_SIGNED:
-    case IS_C_ENUM:
-    case IS_C_BOOL:
+    case bvtypet::IS_UNSIGNED: // integer to integer
+    case bvtypet::IS_SIGNED:
+    case bvtypet::IS_C_ENUM:
+    case bvtypet::IS_C_BOOL:
       {
         // We do sign extension for any source type
         // that is signed, independently of the
         // destination type.
         // E.g., ((short)(ulong)(short)-1)==-1
         bool sign_extension=
-          src_bvtype==IS_SIGNED || src_bvtype==IS_C_ENUM;
+          src_bvtype==bvtypet::IS_SIGNED || src_bvtype==bvtypet::IS_C_ENUM;
 
         for(std::size_t i=0; i<dest_width; i++)
         {
@@ -384,8 +378,8 @@ bool boolbvt::type_conversion(
 
         return false;
       }
-      
-    case IS_VERILOG_UNSIGNED: // verilog_unsignedbv to signed/unsigned/enum
+    // verilog_unsignedbv to signed/unsigned/enum
+    case bvtypet::IS_VERILOG_UNSIGNED:
       {
         for(std::size_t i=0; i<dest_width; i++)
         {
@@ -400,8 +394,8 @@ bool boolbvt::type_conversion(
         return false;
       }
       break;
-      
-    case IS_VERILOG_SIGNED: // verilog_signedbv to signed/unsigned/enum
+
+    case bvtypet::IS_VERILOG_SIGNED: // verilog_signedbv to signed/unsigned/enum
       {
         for(std::size_t i=0; i<dest_width; i++)
         {
@@ -416,7 +410,7 @@ bool boolbvt::type_conversion(
         return false;
       }
       break;
-      
+
     default:
       if(src_type.id()==ID_bool)
       {
@@ -436,10 +430,10 @@ bool boolbvt::type_conversion(
       }
     }
     break;
-    
-  case IS_VERILOG_UNSIGNED:
-    if(src_bvtype==IS_UNSIGNED ||
-       src_bvtype==IS_C_BOOL ||
+
+  case bvtypet::IS_VERILOG_UNSIGNED:
+    if(src_bvtype==bvtypet::IS_UNSIGNED ||
+       src_bvtype==bvtypet::IS_C_BOOL ||
        src_type.id()==ID_bool)
     {
       for(std::size_t i=0, j=0; i<dest_width; i+=2, j++)
@@ -454,7 +448,7 @@ bool boolbvt::type_conversion(
 
       return false;
     }
-    else if(src_bvtype==IS_SIGNED)
+    else if(src_bvtype==bvtypet::IS_SIGNED)
     {
       for(std::size_t i=0, j=0; i<dest_width; i+=2, j++)
       {
@@ -468,7 +462,7 @@ bool boolbvt::type_conversion(
 
       return false;
     }
-    else if(src_bvtype==IS_VERILOG_UNSIGNED)
+    else if(src_bvtype==bvtypet::IS_VERILOG_UNSIGNED)
     {
       // verilog_unsignedbv to verilog_unsignedbv
       dest=src;
@@ -488,27 +482,26 @@ bool boolbvt::type_conversion(
     }
     break;
 
-  case IS_BV:
+  case bvtypet::IS_BV:
     assert(src_width==dest_width);
     dest=src;
     return false;
-    
-  case IS_C_BOOL:
+
+  case bvtypet::IS_C_BOOL:
     dest.resize(dest_width, const_literal(false));
 
-    if(src_bvtype==IS_FLOAT)
+    if(src_bvtype==bvtypet::IS_FLOAT)
     {
-      float_utilst float_utils(prop);
-      float_utils.spec=to_floatbv_type(src_type);
+      float_utilst float_utils(prop, to_floatbv_type(src_type));
       dest[0]=!float_utils.is_zero(src);
     }
-    else if(src_bvtype==IS_C_BOOL)
+    else if(src_bvtype==bvtypet::IS_C_BOOL)
       dest[0]=src[0];
     else
       dest[0]=!bv_utils.is_zero(src);
 
     return false;
-    
+
   default:
     if(dest_type.id()==ID_array)
     {
@@ -520,8 +513,7 @@ bool boolbvt::type_conversion(
     }
     else if(dest_type.id()==ID_struct)
     {
-      const struct_typet &dest_struct =
-        to_struct_type(dest_type);
+      const struct_typet &dest_struct=to_struct_type(dest_type);
 
       if(src_type.id()==ID_struct)
       {
@@ -529,8 +521,7 @@ bool boolbvt::type_conversion(
 
         dest.resize(dest_width, const_literal(false));
 
-        const struct_typet &op_struct =
-          to_struct_type(src_type);
+        const struct_typet &op_struct=to_struct_type(src_type);
 
         const struct_typet::componentst &dest_comp=
           dest_struct.components();
@@ -539,10 +530,8 @@ bool boolbvt::type_conversion(
           op_struct.components();
 
         // build offset maps
-        offset_mapt op_offsets, dest_offsets;
-
-        build_offset_map(op_struct, op_offsets);
-        build_offset_map(dest_struct, dest_offsets);
+        const offset_mapt op_offsets = build_offset_map(op_struct);
+        const offset_mapt dest_offsets = build_offset_map(dest_struct);
 
         // build name map
         typedef std::map<irep_idt, std::size_t> op_mapt;
@@ -558,7 +547,8 @@ bool boolbvt::type_conversion(
         {
           std::size_t offset=dest_offsets[i];
           std::size_t comp_width=boolbv_width(dest_comp[i].type());
-          if(comp_width==0) continue;
+          if(comp_width==0)
+            continue;
 
           op_mapt::const_iterator it=
             op_map.find(dest_comp[i].get_name());
@@ -592,28 +582,16 @@ bool boolbvt::type_conversion(
         return false;
       }
     }
-
   }
 
   return true;
 }
 
-/*******************************************************************\
-
-Function: boolbvt::convert_typecast
-
-  Inputs:
-
- Outputs:
-
- Purpose: conversion from bitvector types to boolean
-
-\*******************************************************************/
-
+/// conversion from bitvector types to boolean
 literalt boolbvt::convert_typecast(const typecast_exprt &expr)
 {
   assert(expr.operands().size()==1);
-  
+
   if(expr.op0().type().id()==ID_range)
   {
     mp_integer from=string2integer(expr.op0().type().get_string(ID_from));
@@ -626,7 +604,7 @@ literalt boolbvt::convert_typecast(const typecast_exprt &expr)
   }
 
   const bvt &bv=convert_bv(expr.op0());
-  
+
   if(!bv.empty())
     return prop.lor(bv);
 
