@@ -6,23 +6,12 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/arith_tools.h>
-#include <util/config.h>
-#include <util/endianness_map.h>
-
 #include "boolbv.h"
 
-/*******************************************************************\
+#include <util/arith_tools.h>
+#include <util/config.h>
 
-Function: boolbvt::convert_union
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include "bv_endianness_map.h"
 
 bvt boolbvt::convert_union(const union_exprt &expr)
 {
@@ -38,7 +27,7 @@ bvt boolbvt::convert_union(const union_exprt &expr)
 
   bvt bv;
   bv.resize(width);
-  
+
   if(config.ansi_c.endianness==configt::ansi_ct::endiannesst::IS_LITTLE_ENDIAN)
   {
     for(std::size_t i=0; i<op_bv.size(); i++)
@@ -50,10 +39,11 @@ bvt boolbvt::convert_union(const union_exprt &expr)
   }
   else
   {
-    assert(config.ansi_c.endianness==configt::ansi_ct::endiannesst::IS_BIG_ENDIAN);
+    assert(
+      config.ansi_c.endianness==configt::ansi_ct::endiannesst::IS_BIG_ENDIAN);
 
-    endianness_mapt map_u(expr.type(), false, ns);
-    endianness_mapt map_op(expr.op0().type(), false, ns);
+    bv_endianness_mapt map_u(expr.type(), false, ns, boolbv_width);
+    bv_endianness_mapt map_op(expr.op0().type(), false, ns, boolbv_width);
 
     for(std::size_t i=0; i<op_bv.size(); i++)
       bv[map_u.map_bit(i)]=op_bv[map_op.map_bit(i)];
@@ -62,6 +52,6 @@ bvt boolbvt::convert_union(const union_exprt &expr)
     for(std::size_t i=op_bv.size(); i<bv.size(); i++)
       bv[map_u.map_bit(i)]=prop.new_variable();
   }
-  
+
   return bv;
 }
