@@ -6,8 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_FLATTEN_BYTE_OPERATORS_H
-#define CPROVER_FLATTEN_BYTE_OPERATORS_H
+
+#ifndef CPROVER_SOLVERS_FLATTENING_FLATTEN_BYTE_OPERATORS_H
+#define CPROVER_SOLVERS_FLATTENING_FLATTEN_BYTE_OPERATORS_H
 
 class byte_extract_exprt;
 class byte_update_exprt;
@@ -22,8 +23,10 @@ exprt flatten_byte_update(
   const byte_update_exprt &src,
   const namespacet &ns);
 
-exprt flatten_byte_operators(const exprt &src, const namespacet &ns);
+exprt flatten_byte_operators(
+  const exprt &src,
+  const namespacet &ns);
 
 bool has_byte_operator(const exprt &src);
 
-#endif
+#endif // CPROVER_SOLVERS_FLATTENING_FLATTEN_BYTE_OPERATORS_H
