@@ -6,8 +6,11 @@ Author: Michael Tautschnig, michael.tautschnig@qmul.ac.uk
 
 \*******************************************************************/
 
-#ifndef CPROVER_BDD_EXPR_H
-#define CPROVER_BDD_EXPR_H
+/// \file
+/// Conversion between exprt and miniBDD
+
+#ifndef CPROVER_SOLVERS_PROP_BDD_EXPR_H
+#define CPROVER_SOLVERS_PROP_BDD_EXPR_H
 
 /*! \file solvers/prop/bdd_expr.h
  * \brief Binary decision diagram
@@ -20,6 +23,8 @@ Author: Michael Tautschnig, michael.tautschnig@qmul.ac.uk
 
 #include <solvers/miniBDD/miniBDD.h>
 
+#include <unordered_map>
+
 class namespacet;
 
 /*! \brief TO_BE_DOCUMENTED
@@ -27,25 +32,23 @@ class namespacet;
 class bdd_exprt
 {
 public:
-  bdd_exprt(const namespacet &_ns):ns(_ns) { }
+  explicit bdd_exprt(const namespacet &_ns):ns(_ns) { }
 
   void from_expr(const exprt &expr);
   exprt as_expr() const;
 
-  typedef miniBDD::BDD BDDt;
-
 protected:
   const namespacet &ns;
-  miniBDD::mgr bdd_mgr;  
-  BDDt root;
+  mini_bdd_mgrt bdd_mgr;
+  mini_bddt root;
 
-  typedef hash_map_cont<exprt, BDDt, irep_hash> expr_mapt;
+  typedef std::unordered_map<exprt, mini_bddt, irep_hash> expr_mapt;
   expr_mapt expr_map;
   typedef std::map<unsigned, exprt> node_mapt;
   node_mapt node_map;
 
-  BDDt from_expr_rec(const exprt &expr);
-  exprt as_expr(const BDDt &r) const;
+  mini_bddt from_expr_rec(const exprt &expr);
+  exprt as_expr(const mini_bddt &r) const;
 };
 
-#endif
+#endif // CPROVER_SOLVERS_PROP_BDD_EXPR_H
