@@ -6,7 +6,8 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <util/i2string.h>
+#include "bv_refinement.h"
+
 #include <util/bv_arithmetic.h>
 #include <util/ieee_float.h>
 #include <util/expr_util.h>
@@ -14,26 +15,13 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include <langapi/language_util.h>
 
+#include <solvers/refinement/string_refinement_invariant.h>
 #include <solvers/floatbv/float_utils.h>
 
-#include "bv_refinement.h"
-
 // Parameters
 #define MAX_INTEGER_UNDERAPPROX 3
 #define MAX_FLOAT_UNDERAPPROX 10
 
-/*******************************************************************\
-
-Function: bv_refinementt::approximationt::add_over_assumption
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void bv_refinementt::approximationt::add_over_assumption(literalt l)
 {
   // if it's a constant already, give up
@@ -41,18 +29,6 @@ void bv_refinementt::approximationt::add_over_assumption(literalt l)
     over_assumptions.push_back(l);
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::approximationt::add_under_assumption
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void bv_refinementt::approximationt::add_under_assumption(literalt l)
 {
   // if it's a constant already, give up
@@ -60,23 +36,11 @@ void bv_refinementt::approximationt::add_under_assumption(literalt l)
     under_assumptions.push_back(l);
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::convert_floatbv_op
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt bv_refinementt::convert_floatbv_op(const exprt &expr)
 {
-  if(!do_arithmetic_refinement)
+  if(!config_.refine_arithmetic)
     return SUB::convert_floatbv_op(expr);
-  
+
   if(ns.follow(expr.type()).id()!=ID_floatbv ||
      expr.operands().size()!=3)
     return SUB::convert_floatbv_op(expr);
@@ -86,31 +50,19 @@ bvt bv_refinementt::convert_floatbv_op(const exprt &expr)
   return bv;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::convert_mult
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt bv_refinementt::convert_mult(const exprt &expr)
 {
-  if(!do_arithmetic_refinement || expr.type().id()==ID_fixedbv)
+  if(!config_.refine_arithmetic || expr.type().id()==ID_fixedbv)
     return SUB::convert_mult(expr);
-  
+
   // we catch any multiplication
   // unless it involves a constant
 
   const exprt::operandst &operands=expr.operands();
-  
+
   const typet &type=ns.follow(expr.type());
 
-  assert(operands.size()>=2);
+  PRECONDITION(operands.size()>=2);
 
   if(operands.size()>2)
     return convert_mult(make_binary(expr)); // make binary
@@ -133,7 +85,7 @@ bvt bv_refinementt::convert_mult(const exprt &expr)
     literalt res_zero=bv_utils.is_zero(a.result_bv);
     prop.l_set_to_true(
       prop.limplies(prop.lor(op0_zero, op1_zero), res_zero));
-    
+
     // x*1==x and 1*x==x
     literalt op0_one=bv_utils.is_one(a.op0_bv);
     literalt op1_one=bv_utils.is_one(a.op1_bv);
@@ -142,31 +94,19 @@ bvt bv_refinementt::convert_mult(const exprt &expr)
     prop.l_set_to_true(prop.limplies(op0_one, res_op1));
     prop.l_set_to_true(prop.limplies(op1_one, res_op0));
   }
-  
+
   return bv;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::convert_div
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt bv_refinementt::convert_div(const div_exprt &expr)
 {
-  if(!do_arithmetic_refinement || expr.type().id()==ID_fixedbv)
+  if(!config_.refine_arithmetic || expr.type().id()==ID_fixedbv)
     return SUB::convert_div(expr);
 
   // we catch any division
   // unless it's integer division by a constant
-  
-  assert(expr.operands().size()==2);
+
+  PRECONDITION(expr.operands().size()==2);
 
   if(expr.op1().is_constant())
     return SUB::convert_div(expr);
@@ -176,27 +116,15 @@ bvt bv_refinementt::convert_div(const div_exprt &expr)
   return bv;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::convert_mod
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bvt bv_refinementt::convert_mod(const mod_exprt &expr)
 {
-  if(!do_arithmetic_refinement || expr.type().id()==ID_fixedbv)
+  if(!config_.refine_arithmetic || expr.type().id()==ID_fixedbv)
     return SUB::convert_mod(expr);
 
   // we catch any mod
   // unless it's integer + constant
 
-  assert(expr.operands().size()==2);
+  PRECONDITION(expr.operands().size()==2);
 
   if(expr.op1().is_constant())
     return SUB::convert_mod(expr);
@@ -206,18 +134,6 @@ bvt bv_refinementt::convert_mod(const mod_exprt &expr)
   return bv;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::get_values
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void bv_refinementt::get_values(approximationt &a)
 {
   std::size_t o=a.expr.operands().size();
@@ -236,24 +152,13 @@ void bv_refinementt::get_values(approximationt &a)
     a.op2_value=get_value(a.op2_bv);
   }
   else
-    assert(0);
+    UNREACHABLE;
 
   a.result_value=get_value(a.result_bv);
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::check_SAT
-
-  Inputs:
-
- Outputs:
-
- Purpose: inspect if satisfying assignment extends to original
-          formula, otherwise refine overapproximation
-
-\*******************************************************************/
-
+/// inspect if satisfying assignment extends to original formula, otherwise
+/// refine overapproximation
 void bv_refinementt::check_SAT(approximationt &a)
 {
   // get values
@@ -262,25 +167,28 @@ void bv_refinementt::check_SAT(approximationt &a)
   // see if the satisfying assignment is spurious in any way
 
   const typet &type=ns.follow(a.expr.type());
-  
+
   if(type.id()==ID_floatbv)
   {
-    // these are all trinary
-    assert(a.expr.operands().size()==3);
+    // these are all ternary
+    INVARIANT(
+      a.expr.operands().size()==3,
+      string_refinement_invariantt("all floatbv typed exprs are ternary"));
 
-    if(a.over_state==MAX_STATE) return;
+    if(a.over_state==MAX_STATE)
+      return;
 
     ieee_float_spect spec(to_floatbv_type(type));
     ieee_floatt o0(spec), o1(spec);
 
     o0.unpack(a.op0_value);
     o1.unpack(a.op1_value);
-    
+
     // get actual rounding mode
     mp_integer rounding_mode_int;
     exprt rounding_mode_expr = get(a.expr.op2());
     to_integer(rounding_mode_expr, rounding_mode_int);
-    ieee_floatt::rounding_modet rounding_mode = 
+    ieee_floatt::rounding_modet rounding_mode =
       (ieee_floatt::rounding_modet)integer2ulong(rounding_mode_int);
 
     ieee_floatt result=o0;
@@ -297,15 +205,15 @@ void bv_refinementt::check_SAT(approximationt &a)
     else if(a.expr.id()==ID_floatbv_div)
       result/=o1;
     else
-      assert(false);
+      UNREACHABLE;
 
     if(result.pack()==a.result_value) // ok
       return;
-      
+
     #ifdef DEBUG
     ieee_floatt rr(spec);
     rr.unpack(a.result_value);
-    
+
     debug() << "S1: " << o0 << " " << a.expr.id() << " " << o1
               << " != " << rr << eom;
     debug() << "S2: " << integer2binary(a.op0_value, spec.width())
@@ -317,28 +225,26 @@ void bv_refinementt::check_SAT(approximationt &a)
                            integer2binary(a.op1_value, spec.width())
               << "==" << integer2binary(result.pack(), spec.width()) << eom;
     #endif
-  
-    //if(a.over_state==1) { debug() << "DISAGREEMENT!\n"; exit(1); }
-    
-    if(a.over_state<max_node_refinement)
+
+    if(a.over_state<config_.max_node_refinement)
     {
       bvt r;
       float_utilst float_utils(prop);
       float_utils.spec=spec;
       float_utils.rounding_mode_bits.set(rounding_mode);
-      
+
       literalt op0_equal=
         bv_utils.equal(a.op0_bv, float_utils.build_constant(o0));
-      
+
       literalt op1_equal=
         bv_utils.equal(a.op1_bv, float_utils.build_constant(o1));
-        
+
       literalt result_equal=
         bv_utils.equal(a.result_bv, float_utils.build_constant(result));
-      
+
       literalt op0_and_op1_equal=
         prop.land(op0_equal, op1_equal);
-      
+
       prop.l_set_to_true(
         prop.limplies(op0_and_op1_equal, result_equal));
     }
@@ -348,7 +254,7 @@ void bv_refinementt::check_SAT(approximationt &a)
       // remove any previous over-approximation
       a.over_assumptions.clear();
       a.over_state=MAX_STATE;
-    
+
       bvt r;
       float_utilst float_utils(prop);
       float_utils.spec=spec;
@@ -365,9 +271,9 @@ void bv_refinementt::check_SAT(approximationt &a)
       else if(a.expr.id()==ID_floatbv_div)
         r=float_utils.div(op0, op1);
       else
-        assert(0);
+        UNREACHABLE;
 
-      assert(r.size()==res.size());
+      CHECK_RETURN(r.size()==res.size());
       bv_utils.set_equal(r, res);
     }
   }
@@ -375,11 +281,14 @@ void bv_refinementt::check_SAT(approximationt &a)
           type.id()==ID_unsignedbv)
   {
     // these are all binary
-    assert(a.expr.operands().size()==2);
+    INVARIANT(
+      a.expr.operands().size()==2,
+      string_refinement_invariantt("all (un)signedbv typed exprs are binary"));
 
     // already full interpretation?
-    if(a.over_state>0) return;
-  
+    if(a.over_state>0)
+      return;
+
     bv_spect spec(type);
     bv_arithmetict o0(spec), o1(spec);
     o0.unpack(a.op0_value);
@@ -398,7 +307,7 @@ void bv_refinementt::check_SAT(approximationt &a)
     else if(a.expr.id()==ID_mod)
       o0%=o1;
     else
-      assert(false);
+      UNREACHABLE;
 
     if(o0.pack()==a.result_value) // ok
       return;
@@ -411,36 +320,42 @@ void bv_refinementt::check_SAT(approximationt &a)
       {
         r=bv_utils.multiplier(
           a.op0_bv, a.op1_bv,
-          a.expr.type().id()==ID_signedbv?bv_utilst::SIGNED:bv_utilst::UNSIGNED);
+          a.expr.type().id()==ID_signedbv?
+            bv_utilst::representationt::SIGNED:
+            bv_utilst::representationt::UNSIGNED);
       }
       else if(a.expr.id()==ID_div)
       {
         r=bv_utils.divider(
           a.op0_bv, a.op1_bv,
-          a.expr.type().id()==ID_signedbv?bv_utilst::SIGNED:bv_utilst::UNSIGNED);
+          a.expr.type().id()==ID_signedbv?
+            bv_utilst::representationt::SIGNED:
+            bv_utilst::representationt::UNSIGNED);
       }
       else if(a.expr.id()==ID_mod)
       {
         r=bv_utils.remainder(
           a.op0_bv, a.op1_bv,
-          a.expr.type().id()==ID_signedbv?bv_utilst::SIGNED:bv_utilst::UNSIGNED);
+          a.expr.type().id()==ID_signedbv?
+            bv_utilst::representationt::SIGNED:
+            bv_utilst::representationt::UNSIGNED);
       }
       else
-        assert(0);
+        UNREACHABLE;
 
       bv_utils.set_equal(r, a.result_bv);
     }
     else
-      assert(0);
+      UNREACHABLE;
   }
   else if(type.id()==ID_fixedbv)
   {
-    //TODO: not implemented
-    assert(0);
+    // TODO: not implemented
+    TODO;
   }
   else
   {
-    assert(0);
+    UNREACHABLE;
   }
 
   status() << "Found spurious `" << a.as_string()
@@ -451,35 +366,25 @@ void bv_refinementt::check_SAT(approximationt &a)
     a.over_state++;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::check_UNSAT
-
-  Inputs:
-
- Outputs:
-
- Purpose: inspect if proof holds on original formula,
-          otherwise refine underapproximation
-
-\*******************************************************************/
-
+/// inspect if proof holds on original formula, otherwise refine
+/// underapproximation
 void bv_refinementt::check_UNSAT(approximationt &a)
 {
   // part of the conflict?
-  if(!is_in_conflict(a)) return;
+  if(!this->conflicts_with(a))
+    return;
 
   status() << "Found assumption for `" << a.as_string()
            << "' in proof (state " << a.under_state << ")" << eom;
 
-  assert(!a.under_assumptions.empty());
+  PRECONDITION(!a.under_assumptions.empty());
 
   a.under_assumptions.clear();
 
   if(a.expr.type().id()==ID_floatbv)
   {
     const floatbv_typet &floatbv_type=to_floatbv_type(a.expr.type());
-    ieee_float_spect spec=floatbv_type;
+    ieee_float_spect spec(floatbv_type);
 
     a.under_assumptions.reserve(a.op0_bv.size()+a.op1_bv.size());
 
@@ -489,7 +394,7 @@ void bv_refinementt::check_UNSAT(approximationt &a)
     // the fraction without hidden bit
     const bvt fraction0=float_utils.get_fraction(a.op0_bv);
     const bvt fraction1=float_utils.get_fraction(a.op1_bv);
-    
+
     if(a.under_state==0)
     {
       // we first set sign and exponent free,
@@ -505,7 +410,7 @@ void bv_refinementt::check_UNSAT(approximationt &a)
     {
       // now fraction: make this grow quadratically
       unsigned x=a.under_state*a.under_state;
-  
+
       if(x>=MAX_FLOAT_UNDERAPPROX && x>=a.result_bv.size())
       {
         // make it free altogether, this guarantees progress
@@ -528,7 +433,7 @@ void bv_refinementt::check_UNSAT(approximationt &a)
   else
   {
     unsigned x=a.under_state+1;
-  
+
     if(x>=MAX_INTEGER_UNDERAPPROX && x>=a.result_bv.size())
     {
       // make it free altogether, this guarantees progress
@@ -550,19 +455,8 @@ void bv_refinementt::check_UNSAT(approximationt &a)
   progress=true;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::is_in_conflict
-
-  Inputs:
-
- Outputs:
-
- Purpose: check if an under-approximation is part of the conflict
-
-\*******************************************************************/
-
-bool bv_refinementt::is_in_conflict(approximationt &a)
+/// check if an under-approximation is part of the conflict
+bool bv_refinementt::conflicts_with(approximationt &a)
 {
   for(std::size_t i=0; i<a.under_assumptions.size(); i++)
     if(prop.is_in_conflict(a.under_assumptions[i]))
@@ -571,18 +465,6 @@ bool bv_refinementt::is_in_conflict(approximationt &a)
   return false;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::initialize
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void bv_refinementt::initialize(approximationt &a)
 {
   a.over_state=a.under_state=0;
@@ -598,27 +480,15 @@ void bv_refinementt::initialize(approximationt &a)
     a.add_under_assumption(!a.op1_bv[i]);
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::add_approximation
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 bv_refinementt::approximationt &
 bv_refinementt::add_approximation(
   const exprt &expr, bvt &bv)
 {
   approximations.push_back(approximationt(approximations.size()));
-  approximationt &a=approximations.back(); // stable!
+  approximationt &a=approximations.back();
 
   std::size_t width=boolbv_width(expr.type());
-  assert(width!=0);
+  PRECONDITION(width!=0);
 
   a.expr=expr;
   a.result_bv=prop.new_variables(width);
@@ -647,33 +517,20 @@ bv_refinementt::add_approximation(
     set_frozen(a.op2_bv);
   }
   else
-    assert(false);
-    
+    UNREACHABLE;
+
   bv=a.result_bv;
 
   initialize(a);
-  
+
   return a;
 }
 
-/*******************************************************************\
-
-Function: bv_refinementt::approximationt::as_string
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string bv_refinementt::approximationt::as_string() const
 {
   #if 0
   return from_expr(expr);
   #else
-  return i2string(id_nr)+"/"+id2string(expr.id());
+  return std::to_string(id_nr)+"/"+id2string(expr.id());
   #endif
 }
-
