@@ -165,6 +165,22 @@ public:
     const array_string_exprt &s1,
     const array_string_exprt &s2,
     const exprt &offset);
+  exprt add_axioms_for_string_of_int_with_radix(
+    const array_string_exprt &res,
+    const exprt &input_int,
+    const exprt &radix,
+    size_t max_size = 0);
+  exprt add_axioms_for_set_char(
+    const array_string_exprt &res,
+    const array_string_exprt &str,
+    const exprt &position,
+    const exprt &character);
+  exprt add_axioms_for_to_lower_case(
+    const array_string_exprt &res,
+    const array_string_exprt &str);
+  exprt add_axioms_for_to_upper_case(
+    const array_string_exprt &res,
+    const array_string_exprt &expr);
 
 private:
   symbol_exprt fresh_boolean(const irep_idt &prefix);
@@ -258,15 +274,10 @@ private:
     const exprt &guard);
   exprt add_axioms_from_literal(const function_application_exprt &f);
   exprt add_axioms_from_int(const function_application_exprt &f);
-  exprt add_axioms_from_int(
+  exprt add_axioms_for_string_of_int(
     const array_string_exprt &res,
     const exprt &input_int,
     size_t max_size = 0);
-  exprt add_axioms_from_int_with_radix(
-    const array_string_exprt &res,
-    const exprt &input_int,
-    const exprt &radix,
-    size_t max_size = 0);
   exprt add_axioms_from_int_hex(const array_string_exprt &res, const exprt &i);
   exprt add_axioms_from_int_hex(const function_application_exprt &f);
   exprt add_axioms_from_long(const function_application_exprt &f);
@@ -330,9 +341,6 @@ private:
   exprt add_axioms_for_substring(const function_application_exprt &f);
   exprt add_axioms_for_to_lower_case(const function_application_exprt &f);
   exprt add_axioms_for_to_upper_case(const function_application_exprt &f);
-  exprt add_axioms_for_to_upper_case(
-    const array_string_exprt &res,
-    const array_string_exprt &expr);
   exprt add_axioms_for_trim(const function_application_exprt &f);
 
   exprt add_axioms_for_code_point(
@@ -365,7 +373,6 @@ private:
     const exprt &radix,
     const unsigned long radix_ul);
   void add_axioms_for_correct_number_format(
-    const exprt &input_int,
     const array_string_exprt &str,
     const exprt &radix_as_char,
     const unsigned long radix_ul,
@@ -457,7 +464,7 @@ exprt length_constraint_for_concat_substr(
 exprt length_constraint_for_insert(
   const array_string_exprt &res,
   const array_string_exprt &s1,
-  const array_string_exprt &s2,
-  const exprt &offset);
+  const array_string_exprt &s2);
 
+exprt zero_if_negative(const exprt &expr);
 #endif
