@@ -6,8 +6,9 @@ Author: Alex Groce
 
 \*******************************************************************/
 
-#ifndef CPROVER_PBS_DIMACS_CNF_H
-#define CPROVER_PBS_DIMACS_CNF_H
+
+#ifndef CPROVER_SOLVERS_SAT_PBS_DIMACS_CNF_H
+#define CPROVER_SOLVERS_SAT_PBS_DIMACS_CNF_H
 
 #include <set>
 #include <map>
@@ -17,7 +18,7 @@ Author: Alex Groce
 
 class pbs_dimacs_cnft:public dimacs_cnft
 {
- public:
+public:
   pbs_dimacs_cnft():
     optimize(false),
     maximize(false),
@@ -30,7 +31,7 @@ class pbs_dimacs_cnft:public dimacs_cnft
   virtual ~pbs_dimacs_cnft()
   {
   }
- 
+
   virtual void write_dimacs_pb(std::ostream &out);
 
   bool optimize;
@@ -42,7 +43,7 @@ class pbs_dimacs_cnft:public dimacs_cnft
   int goal;
   int opt_sum;
 
-  std::map<literalt,unsigned> pb_constraintmap;
+  std::map<literalt, unsigned> pb_constraintmap;
 
   bool pbs_solve();
 
@@ -51,13 +52,14 @@ class pbs_dimacs_cnft:public dimacs_cnft
   virtual tvt l_get(literalt a) const;
 
   // dummy functions
-  
+
   virtual const std::string solver_text()
-    { return "PBS - Pseudo Boolean/CNF Solver and Optimizer"; }
-
- protected:
+  {
+    return "PBS - Pseudo Boolean/CNF Solver and Optimizer";
+  }
 
+protected:
   std::set<int> assigned;
 };
 
-#endif
+#endif // CPROVER_SOLVERS_SAT_PBS_DIMACS_CNF_H
