@@ -6,22 +6,10 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#include <cassert>
-#include <stack>
-
 #include "resolution_proof.h"
 
-/*******************************************************************\
-
-Function: resolution_prooft::build_core
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+#include <cassert>
+#include <stack>
 
 template<class T>
 void resolution_prooft<T>::build_core(std::vector<bool> &in_core)
@@ -30,21 +18,22 @@ void resolution_prooft<T>::build_core(std::vector<bool> &in_core)
   std::vector<bool> seen;
 
   assert(!clauses.empty());
-  
+
   seen.resize(clauses.size(), false);
-  
+
   s.push(clauses.size()-1);
-  
+
   while(!s.empty())
   {
     typename clausest::size_type c_id=s.top();
     s.pop();
 
-    if(seen[c_id]) continue;
+    if(seen[c_id])
+      continue;
     seen[c_id]=true;
-    
+
     const T &c=clauses[c_id];
-    
+
     if(c.is_root)
     {
       for(std::size_t i=0; i<c.root_clause.size(); i++)
