@@ -6,24 +6,16 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+/// \file
+/// Misc Utilities
+
 #include "array_name.h"
+
 #include "expr.h"
 #include "namespace.h"
 #include "symbol.h"
 #include "ssa_expr.h"
 
-/*******************************************************************\
-
-Function: goto_checkt::array_name
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string array_name(
   const namespacet &ns,
   const exprt &expr)
@@ -43,7 +35,7 @@ std::string array_name(
   }
   else if(expr.id()==ID_symbol)
   {
-    const symbolt &symbol=ns.lookup(expr);
+    const symbolt &symbol = ns.lookup(to_symbol_expr(expr));
     return "array `"+id2string(symbol.base_name)+"'";
   }
   else if(expr.id()==ID_string_constant)
@@ -59,4 +51,3 @@ std::string array_name(
 
   return "array";
 }
-
