@@ -6,23 +6,13 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+#include "byte_operators.h"
+
 #include <cassert>
 
-#include "byte_operators.h"
+#include "invariant.h"
 #include "config.h"
 
-/*******************************************************************\
-
-Function: byte_extract_id
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 irep_idt byte_extract_id()
 {
   switch(config.ansi_c.endianness)
@@ -34,22 +24,10 @@ irep_idt byte_extract_id()
     return ID_byte_extract_big_endian;
 
   default:
-    assert(false);
+    UNREACHABLE;
   }
 }
 
-/*******************************************************************\
-
-Function: byte_update_id
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 irep_idt byte_update_id()
 {
   switch(config.ansi_c.endianness)
@@ -61,6 +39,6 @@ irep_idt byte_update_id()
     return ID_byte_update_big_endian;
 
   default:
-    assert(false);
+    UNREACHABLE;
   }
 }
