@@ -155,11 +155,11 @@ void configt::ansi_ct::set_arch_spec_i386()
   switch(mode)
   {
   case flavourt::GCC:
-  case flavourt::APPLE:
+  case flavourt::CLANG:
     defines.push_back("i386");
     defines.push_back("__i386");
     defines.push_back("__i386__");
-    if(mode==flavourt::APPLE)
+    if(mode == flavourt::CLANG)
       defines.push_back("__LITTLE_ENDIAN__");
     break;
 
@@ -188,14 +188,15 @@ void configt::ansi_ct::set_arch_spec_x86_64()
   switch(mode)
   {
   case flavourt::GCC:
-  case flavourt::APPLE:
+  case flavourt::CLANG:
     defines.push_back("__LP64__");
     defines.push_back("__x86_64");
     defines.push_back("__x86_64__");
     defines.push_back("_LP64");
     defines.push_back("__amd64__");
     defines.push_back("__amd64");
-    if(mode==flavourt::APPLE)
+
+    if(os == ost::OS_MACOS)
       defines.push_back("__LITTLE_ENDIAN__");
     break;
 
@@ -233,13 +234,13 @@ void configt::ansi_ct::set_arch_spec_power(const irep_idt &subarch)
   switch(mode)
   {
   case flavourt::GCC:
-  case flavourt::APPLE:
+  case flavourt::CLANG:
     defines.push_back("__powerpc");
     defines.push_back("__powerpc__");
     defines.push_back("__POWERPC__");
     defines.push_back("__ppc__");
 
-    if(mode==flavourt::APPLE)
+    if(os == ost::OS_MACOS)
       defines.push_back("__BIG_ENDIAN__");
 
     if(subarch!="powerpc")
@@ -295,7 +296,7 @@ void configt::ansi_ct::set_arch_spec_arm(const irep_idt &subarch)
   switch(mode)
   {
   case flavourt::GCC:
-  case flavourt::APPLE:
+  case flavourt::CLANG:
     if(subarch=="arm64")
       defines.push_back("__aarch64__");
     else
@@ -336,7 +337,7 @@ void configt::ansi_ct::set_arch_spec_alpha()
     defines.push_back("_M_ALPHA");
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -386,7 +387,7 @@ void configt::ansi_ct::set_arch_spec_mips(const irep_idt &subarch)
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -415,7 +416,7 @@ void configt::ansi_ct::set_arch_spec_s390()
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -443,7 +444,7 @@ void configt::ansi_ct::set_arch_spec_s390x()
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -483,7 +484,7 @@ void configt::ansi_ct::set_arch_spec_sparc(const irep_idt &subarch)
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -514,7 +515,7 @@ void configt::ansi_ct::set_arch_spec_ia64()
     defines.push_back("_M_IA64");
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -549,7 +550,7 @@ void configt::ansi_ct::set_arch_spec_x32()
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -603,7 +604,7 @@ void configt::ansi_ct::set_arch_spec_hppa()
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -633,7 +634,7 @@ void configt::ansi_ct::set_arch_spec_sh4()
     UNREACHABLE; // not supported by Visual Studio
     break;
 
-  case flavourt::APPLE:
+  case flavourt::CLANG:
   case flavourt::CODEWARRIOR:
   case flavourt::ARM:
   case flavourt::ANSI:
@@ -890,7 +891,7 @@ bool configt::set(const cmdlinet &cmdline)
   {
     ansi_c.lib=configt::ansi_ct::libt::LIB_FULL;
     ansi_c.os=configt::ansi_ct::ost::OS_MACOS;
-    ansi_c.mode=ansi_ct::flavourt::APPLE;
+    ansi_c.mode = ansi_ct::flavourt::CLANG;
     ansi_c.preprocessor=ansi_ct::preprocessort::CLANG;
   }
   else if(os=="linux" || os=="solaris")
@@ -904,7 +905,7 @@ bool configt::set(const cmdlinet &cmdline)
   {
     ansi_c.lib=configt::ansi_ct::libt::LIB_FULL;
     ansi_c.os=configt::ansi_ct::ost::OS_LINUX;
-    ansi_c.mode=ansi_ct::flavourt::GCC;
+    ansi_c.mode=ansi_ct::flavourt::CLANG;
     ansi_c.preprocessor=ansi_ct::preprocessort::CLANG;
   }
   else
@@ -1217,17 +1218,17 @@ irep_idt configt::this_architecture()
 
   #ifdef __alpha__
   this_arch="alpha";
-  #elif __armel__
+  #elif defined(__armel__)
   this_arch="armel";
-  #elif __aarch64__
+  #elif defined(__aarch64__)
   this_arch="arm64";
-  #elif __arm__
+  #elif defined(__arm__)
     #ifdef __ARM_PCS_VFP
     this_arch="armhf"; // variant of arm with hard float
     #else
     this_arch="arm";
     #endif
-  #elif __mipsel__
+  #elif defined(__mipsel__)
     #if _MIPS_SIM==_ABIO32
     this_arch="mipsel";
     #elif _MIPS_SIM==_ABIN32
@@ -1235,7 +1236,7 @@ irep_idt configt::this_architecture()
     #else
     this_arch="mips64el";
     #endif
-  #elif __mips__
+  #elif defined(__mips__)
     #if _MIPS_SIM==_ABIO32
     this_arch="mips";
     #elif _MIPS_SIM==_ABIN32
@@ -1243,7 +1244,7 @@ irep_idt configt::this_architecture()
     #else
     this_arch="mips64";
     #endif
-  #elif __powerpc__
+  #elif defined(__powerpc__)
     #if defined(__ppc64__) || defined(__PPC64__) || \
         defined(__powerpc64__) || defined(__POWERPC64__)
       #ifdef __LITTLE_ENDIAN__
@@ -1254,33 +1255,33 @@ irep_idt configt::this_architecture()
     #else
     this_arch="powerpc";
     #endif
-  #elif __sparc__
+  #elif defined(__sparc__)
     #ifdef __arch64__
     this_arch="sparc64";
     #else
     this_arch="sparc";
     #endif
-  #elif __ia64__
+  #elif defined(__ia64__)
   this_arch="ia64";
-  #elif __s390x__
+  #elif defined(__s390x__)
   this_arch="s390x";
-  #elif __s390__
+  #elif defined(__s390__)
   this_arch="s390";
-  #elif __x86_64__
+  #elif defined(__x86_64__)
     #ifdef __ILP32__
     this_arch="x32"; // variant of x86_64 with 32-bit pointers
     #else
     this_arch="x86_64";
     #endif
-  #elif __i386__
+  #elif defined(__i386__)
   this_arch="i386";
-  #elif _WIN64
+  #elif defined(_WIN64)
   this_arch="x86_64";
-  #elif _WIN32
+  #elif defined(_WIN32)
   this_arch="i386";
-  #elif __hppa__
+  #elif defined(__hppa__)
   this_arch="hppa";
-  #elif __sh__
+  #elif defined(__sh__)
   this_arch="sh4";
   #else
   // something new and unknown!
