@@ -10,3 +10,10 @@ Author: Daniel Kroening, kroening@kroening.com
 /// Container for C-Strings
 
 #include "dstring.h"
+
+#include <ostream>
+
+std::ostream &dstringt::operator<<(std::ostream &out) const
+{
+  return out << as_string();
+}
