@@ -30,6 +30,9 @@ class symbolt;
 class typet;
 class namespacet;
 
+/// Returns true iff the argument is (syntactically) an lvalue.
+bool is_lvalue(const exprt &expr);
+
 /// splits an expression with >=3 operands into nested binary expressions
 exprt make_binary(const exprt &);
 
@@ -72,4 +75,7 @@ bool has_subtype(const typet &, const irep_idt &id, const namespacet &);
 /// lift up an if_exprt one level
 if_exprt lift_if(const exprt &, std::size_t operand_number);
 
+/// find the expression nested inside typecasts, if any
+const exprt &skip_typecast(const exprt &expr);
+
 #endif // CPROVER_UTIL_EXPR_UTIL_H
