@@ -19,4 +19,7 @@ std::string get_current_working_directory();
 std::string concat_dir_file(const std::string &directory,
                             const std::string &file_name);
 
+// C++17 will allow us to use std::filesystem::is_directory()
+bool is_directory(const std::string &path);
+
 #endif // CPROVER_UTIL_FILE_UTIL_H
