@@ -6,25 +6,15 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
 #include "format_constant.h"
+
 #include "arith_tools.h"
 #include "fixedbv.h"
 #include "ieee_float.h"
 #include "expr.h"
 #include "std_expr.h"
 
-/*******************************************************************\
-
-Function: format_constantt::operator()
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 std::string format_constantt::operator()(const exprt &expr)
 {
   if(expr.is_constant())
@@ -35,7 +25,8 @@ std::string format_constantt::operator()(const exprt &expr)
        expr.type().id()==ID_signedbv)
     {
       mp_integer i;
-      if(to_integer(expr, i)) return "(number conversion failed)";
+      if(to_integer(to_constant_expr(expr), i))
+        return "(number conversion failed)";
 
       return integer2string(i);
     }
@@ -53,4 +44,3 @@ std::string format_constantt::operator()(const exprt &expr)
 
   return "(format-constant failed: "+expr.id_string()+")";
 }
-
