@@ -6,10 +6,14 @@ Author: Peter Schrammel
 
 \*******************************************************************/
 
-#ifndef CPROVER_JSON_EXPR_H
-#define CPROVER_JSON_EXPR_H
+/// \file
+/// Expressions in JSON
+
+#ifndef CPROVER_UTIL_JSON_EXPR_H
+#define CPROVER_UTIL_JSON_EXPR_H
 
 #include "json.h"
+#include "irep.h"
 
 class source_locationt;
 class typet;
@@ -18,12 +22,14 @@ class namespacet;
 
 json_objectt json(
   const exprt &,
-  const namespacet &);
+  const namespacet &,
+  const irep_idt &mode);
 
 json_objectt json(
   const typet &,
-  const namespacet &);
+  const namespacet &,
+  const irep_idt &mode);
 
 json_objectt json(const source_locationt &);
 
-#endif
+#endif // CPROVER_UTIL_JSON_EXPR_H
