@@ -6,8 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_PARSE_OPTIONS_H
-#define CPROVER_PARSE_OPTIONS_H
+
+#ifndef CPROVER_UTIL_PARSE_OPTIONS_H
+#define CPROVER_UTIL_PARSE_OPTIONS_H
 
 #include <string>
 
@@ -20,17 +21,21 @@ public:
     const std::string &optstring, int argc, const char **argv);
 
   cmdlinet cmdline;
-  
+
   virtual void help();
   virtual void usage_error();
-  
+
   virtual int doit()=0;
-  
+
   virtual int main();
   virtual ~parse_options_baset() { }
-  
+
 private:
+  void unknown_option_msg();
   bool parse_result;
 };
 
-#endif
+std::string
+banner_string(const std::string &front_end, const std::string &version);
+
+#endif // CPROVER_UTIL_PARSE_OPTIONS_H
