@@ -6,6 +6,10 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+
+#ifndef CPROVER_UTIL_RENAME_H
+#define CPROVER_UTIL_RENAME_H
+
 //
 // automated variable renaming
 //
@@ -18,12 +22,10 @@ class symbolt;
 
 void get_new_name(symbolt &symbol,
                   const namespacet &ns);
-  
-void get_new_name(irep_idt &new_name,
-                  const namespacet &ns);
-  
-// true: did nothing
-// false: renamed something in the expression
 
-bool rename(exprt &expr, const irep_idt &old_name,
-            const irep_idt &new_name);
+void get_new_name(
+  irep_idt &new_name,
+  const namespacet &ns,
+  char delimiter = '_');
+
+#endif // CPROVER_UTIL_RENAME_H
