@@ -6,29 +6,14 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+#include "std_expr.h"
+
 #include <cassert>
 
 #include "arith_tools.h"
 #include "byte_operators.h"
-#include "config.h"
-#include "namespace.h"
+#include "c_types.h"
 #include "pointer_offset_size.h"
-#include "i2string.h"
-
-#include "std_types.h"
-#include "std_expr.h"
-
-/*******************************************************************\
-
-Function: constant_exprt::value_is_zero_string
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
 
 bool constant_exprt::value_is_zero_string() const
 {
@@ -36,18 +21,6 @@ bool constant_exprt::value_is_zero_string() const
   return val.find_first_not_of('0')==std::string::npos;
 }
 
-/*******************************************************************\
-
-Function: disjunction
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 exprt disjunction(const exprt::operandst &op)
 {
   if(op.empty())
@@ -62,17 +35,15 @@ exprt disjunction(const exprt::operandst &op)
   }
 }
 
-/*******************************************************************\
+void dynamic_object_exprt::set_instance(unsigned int instance)
+{
+  op0()=from_integer(instance, typet(ID_natural));
+}
 
-Function: conjunction
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
+unsigned int dynamic_object_exprt::get_instance() const
+{
+  return std::stoul(id2string(to_constant_expr(op0()).get_value()));
+}
 
 exprt conjunction(const exprt::operandst &op)
 {
@@ -88,25 +59,12 @@ exprt conjunction(const exprt::operandst &op)
   }
 }
 
-/*******************************************************************\
-
-Function: build_object_descriptor_rec
-
-  Inputs:
-
- Outputs:
-
- Purpose: Build an object_descriptor_exprt from a given expr
-
-\*******************************************************************/
-
+/// Build an object_descriptor_exprt from a given expr
 static void build_object_descriptor_rec(
   const namespacet &ns,
   const exprt &expr,
   object_descriptor_exprt &dest)
 {
-  const signedbv_typet index_type(config.ansi_c.pointer_width);
-
   if(expr.id()==ID_index)
   {
     const index_exprt &index=to_index_expr(expr);
@@ -118,8 +76,8 @@ static void build_object_descriptor_rec(
 
     dest.offset()=
       plus_exprt(dest.offset(),
-                 mult_exprt(typecast_exprt(index.index(), index_type),
-                            typecast_exprt(sub_size, index_type)));
+                 mult_exprt(typecast_exprt(index.index(), index_type()),
+                            typecast_exprt(sub_size, index_type())));
   }
   else if(expr.id()==ID_member)
   {
@@ -133,7 +91,7 @@ static void build_object_descriptor_rec(
 
     dest.offset()=
       plus_exprt(dest.offset(),
-                 typecast_exprt(offset, index_type));
+                 typecast_exprt(offset, index_type()));
   }
   else if(expr.id()==ID_byte_extract_little_endian ||
           expr.id()==ID_byte_extract_big_endian)
@@ -147,7 +105,7 @@ static void build_object_descriptor_rec(
     dest.offset()=
       plus_exprt(dest.offset(),
                  typecast_exprt(to_byte_extract_expr(expr).offset(),
-                                index_type));
+                                index_type()));
   }
   else if(expr.id()==ID_typecast)
   {
@@ -159,18 +117,7 @@ static void build_object_descriptor_rec(
   }
 }
 
-/*******************************************************************\
-
-Function: object_descriptor_exprt::build
-
-  Inputs:
-
- Outputs:
-
- Purpose: Build an object_descriptor_exprt from a given expr
-
-\*******************************************************************/
-
+/// Build an object_descriptor_exprt from a given expr
 void object_descriptor_exprt::build(
   const exprt &expr,
   const namespacet &ns)
@@ -179,82 +126,29 @@ void object_descriptor_exprt::build(
   object()=expr;
 
   if(offset().id()==ID_unknown)
-    offset()=from_integer(0, signedbv_typet(config.ansi_c.pointer_width));
+    offset()=from_integer(0, index_type());
 
   build_object_descriptor_rec(ns, expr, *this);
 
   assert(root_object().type().id()!=ID_empty);
 }
 
-/*******************************************************************\
-
-Function: constant_exprt::integer_constant
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
-constant_exprt constant_exprt::integer_constant(unsigned v)
-{
-  return constant_exprt(i2string(v), integer_typet());
-}
-
-/*******************************************************************\
-
-Function: shift_exprt::shift_exprt
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 shift_exprt::shift_exprt(
   const exprt &_src,
   const irep_idt &_id,
   const std::size_t _distance):
-  binary_exprt(_src, _id, constant_exprt::integer_constant(_distance))
+  binary_exprt(_src, _id, from_integer(_distance, integer_typet()))
 {
 }
 
-/*******************************************************************\
-
-Function: extractbit_exprt::extractbit_exprt
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 extractbit_exprt::extractbit_exprt(
   const exprt &_src,
   const std::size_t _index):
   binary_predicate_exprt(
-    _src, ID_extractbit, constant_exprt::integer_constant(_index))
+    _src, ID_extractbit, from_integer(_index, integer_typet()))
 {
 }
 
-/*******************************************************************\
-
-Function: extractbit_exprt::extractbits_exprt
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 extractbits_exprt::extractbits_exprt(
   const exprt &_src,
   const std::size_t _upper,
@@ -265,7 +159,11 @@ extractbits_exprt::extractbits_exprt(
   assert(_upper>=_lower);
   operands().resize(3);
   src()=_src;
-  upper()=constant_exprt::integer_constant(_upper);
-  lower()=constant_exprt::integer_constant(_lower);
+  upper()=from_integer(_upper, integer_typet());
+  lower()=from_integer(_lower, integer_typet());
 }
 
+address_of_exprt::address_of_exprt(const exprt &_op):
+  unary_exprt(ID_address_of, _op, pointer_type(_op.type()))
+{
+}
