@@ -553,13 +553,13 @@ public:
   }
 };
 
-/*! \brief Cast a generic typet to a \ref union_tag_typet
+/*! \brief Cast a generic typet to a \ref struct_tag_typet
  *
  * This is an unchecked conversion. \a type must be known to be \ref
- * union_tag_typet.
+ * struct_tag_typet.
  *
  * \param type Source type
- * \return Object of type \ref union_tag_typet
+ * \return Object of type \ref struct_tag_typet
  *
  * \ingroup gr_std_types
 */
@@ -974,6 +974,12 @@ public:
   }
 };
 
+template <>
+inline bool can_cast_type<code_typet>(const typet &type)
+{
+  return type.id() == ID_code;
+}
+
 /*! \brief Cast a generic typet to a \ref code_typet
  *
  * This is an unchecked conversion. \a type must be known to be \ref
@@ -986,7 +992,8 @@ public:
 */
 inline const code_typet &to_code_type(const typet &type)
 {
-  PRECONDITION(type.id()==ID_code);
+  PRECONDITION(can_cast_type<code_typet>(type));
+  validate_type(type);
   return static_cast<const code_typet &>(type);
 }
 
@@ -995,10 +1002,12 @@ inline const code_typet &to_code_type(const typet &type)
 */
 inline code_typet &to_code_type(typet &type)
 {
-  PRECONDITION(type.id()==ID_code);
+  PRECONDITION(can_cast_type<code_typet>(type));
+  validate_type(type);
   return static_cast<code_typet &>(type);
 }
 
+
 /*! \brief arrays with given size
 */
 class array_typet:public type_with_subtypet
