@@ -6,8 +6,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_SYMBOL_H
-#define CPROVER_SYMBOL_H
+
+#ifndef CPROVER_UTIL_SYMBOL_H
+#define CPROVER_UTIL_SYMBOL_H
 
 /*! \file util/symbol.h
  * \brief Symbol table entry
@@ -16,9 +17,6 @@ Author: Daniel Kroening, kroening@kroening.com
  * \date   Sun Jul 31 21:54:44 BST 2011
 */
 
-/*! \defgroup gr_symbol_table Symbol Table
-*/
-
 #include <iosfwd>
 
 #include "expr.h"
@@ -34,37 +32,37 @@ class symbolt
 public:
   /// Type of symbol
   typet type;
-  
+
   /// Initial value of symbol
   exprt value;
-  
+
   /// Source code location of definition of symbol
   source_locationt location;
-  
+
   /// The unique identifier
   irep_idt name;
-  
+
   /// Name of module the symbol belongs to
   irep_idt module;
-  
+
   /// Base (non-scoped) name
   irep_idt base_name;
-  
+
   /// Language mode
   irep_idt mode;
-  
+
   /// Language-specific display name
   irep_idt pretty_name;
-  
+
   const irep_idt &display_name() const
   {
     return pretty_name.empty()?name:pretty_name;
   }
-  
+
   // global use
   bool is_type, is_macro, is_exported,
        is_input, is_output, is_state_var, is_property;
-       
+
   // ANSI-C
   bool is_static_lifetime, is_thread_local;
   bool is_lvalue, is_file_local, is_extern, is_volatile,
@@ -74,7 +72,7 @@ public:
   {
     clear();
   }
-  
+
   void clear()
   {
     type.make_nil();
@@ -89,47 +87,29 @@ public:
     is_lvalue=is_file_local=is_extern=is_volatile=
     is_parameter=is_auxiliary=is_weak=false;
   }
-     
+
   void swap(symbolt &b);
   void show(std::ostream &out) const;
 
-  // serialization
-  irept to_irep() const;
-  void from_irep(const irept &src);
-  
   class symbol_exprt symbol_expr() const;
-  
-  inline bool is_shared() const
+
+  bool is_shared() const
   {
     return !is_thread_local;
   }
-  
-  inline bool is_procedure_local() const
+
+  bool is_procedure_local() const
   {
     return !is_static_lifetime;
   }
+
+  bool is_function() const
+  {
+    return !is_type && !is_macro && type.id()==ID_code;
+  }
 };
 
-std::ostream &operator<<(std::ostream &out,
-                         const symbolt &symbol);
-
-#include <list>
- 
-typedef std::list<symbolt> symbol_listt;
-
-#define forall_symbol_list(it, expr) \
-  for(symbol_listt::const_iterator it=(expr).begin(); \
-      it!=(expr).end(); ++it)
-
-typedef std::list<const symbolt *> symbolptr_listt;
-
-#define forall_symbolptr_list(it, list) \
-  for(symbolptr_listt::const_iterator it=(list).begin(); \
-      it!=(list).end(); ++it)
-
-#define Forall_symbolptr_list(it, list) \
-  for(symbolptr_listt::iterator it=(list).begin(); \
-      it!=(list).end(); ++it)
+std::ostream &operator<<(std::ostream &out, const symbolt &symbol);
 
 /*! \brief Symbol table entry describing a data type
     \ingroup gr_symbol_table
@@ -139,7 +119,7 @@ typedef std::list<const symbolt *> symbolptr_listt;
 class type_symbolt:public symbolt
 {
 public:
-  type_symbolt(const typet &_type)
+  explicit type_symbolt(const typet &_type)
   {
     type=_type;
     is_type=true;
@@ -163,6 +143,14 @@ public:
     is_file_local=true;
     is_auxiliary=true;
   }
+
+  auxiliary_symbolt(const irep_idt &name, const typet &type):
+    auxiliary_symbolt()
+  {
+    this->name=name;
+    this->base_name=name;
+    this->type=type;
+  }
 };
 
 /*! \brief Symbol table entry of function parameter
@@ -183,4 +171,4 @@ public:
   }
 };
 
-#endif
+#endif // CPROVER_UTIL_SYMBOL_H
