@@ -6,55 +6,38 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_TYPECHECK_H
-#define CPROVER_TYPECHECK_H
 
-#include "message_stream.h"
+#ifndef CPROVER_UTIL_TYPECHECK_H
+#define CPROVER_UTIL_TYPECHECK_H
 
-class legacy_typecheckt:public legacy_message_streamt
-{
-public:
-  legacy_typecheckt(message_handlert &_message_handler):
-    legacy_message_streamt(_message_handler) { }
-  virtual ~legacy_typecheckt() { }
-  
-protected:
-  // main function -- overload this one
-  virtual void typecheck()=0;
-
-public:
-  // call that one
-  virtual bool typecheck_main();
-};
+#include "expr.h"
+#include "message.h"
 
 class typecheckt:public messaget
 {
 public:
   explicit typecheckt(message_handlert &_message_handler):
-    messaget(_message_handler),
-    error_found(false)
+    messaget(_message_handler)
   {
   }
 
   virtual ~typecheckt() { }
 
-  inline mstreamt &error()
+  // not pretty, but makes transition easier
+  void err_location(const source_locationt &loc)
   {
-    error_found=true;
-    return messaget::error();
+    messaget::error().source_location=loc;
   }
 
-  // not pretty, but makes transition easier  
-  inline void err_location(const exprt &src)
+  // not pretty, but makes transition easier
+  void err_location(const exprt &src)
   {
-    error().source_location=src.find_source_location();
+    err_location(src.find_source_location());
   }
 
-  bool error_found;
-  
-  inline bool get_error_found() const
+  void err_location(const typet &src)
   {
-    return error_found;
+    err_location(src.source_location());
   }
 
 protected:
@@ -66,4 +49,4 @@ public:
   virtual bool typecheck_main();
 };
 
-#endif
+#endif // CPROVER_UTIL_TYPECHECK_H
