@@ -6,23 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
+#include "xml.h"
+
 #include <ostream>
 
 #include "string2int.h"
-#include "i2string.h"
-#include "xml.h"
-
-/*******************************************************************\
-
-Function: xmlt::clear
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
 
 void xmlt::clear()
 {
@@ -32,18 +20,6 @@ void xmlt::clear()
   elements.clear();
 }
 
-/*******************************************************************\
-
-Function: xmlt::swap
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::swap(xmlt &xml)
 {
   xml.data.swap(data);
@@ -52,36 +28,26 @@ void xmlt::swap(xmlt &xml)
   xml.name.swap(name);
 }
 
-/*******************************************************************\
-
-Function: xmlt::output
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::output(std::ostream &out, unsigned indent) const
 {
   // 'name' needs to be set, or we produce mal-formed
   // XML.
-  
-  if(name=="") return;
+
+  if(name=="")
+    return;
 
   do_indent(out, indent);
 
   out << '<' << name;
 
-  for(const auto & it : attributes)
+  for(const auto &attribute : attributes)
   {
     // it.first needs to be non-empty
-    if(it.first=="") continue;
-    out << ' ' << it.first
+    if(attribute.first.empty())
+      continue;
+    out << ' ' << attribute.first
         << '=' << '"';
-    escape_attribute(it.second, out);
+    escape_attribute(attribute.second, out);
     out << '"';
   }
 
@@ -99,8 +65,8 @@ void xmlt::output(std::ostream &out, unsigned indent) const
   {
     out << "\n";
 
-    for(const auto & it : elements)
-      it.output(out, indent+2);
+    for(const auto &element : elements)
+      element.output(out, indent+2);
 
     do_indent(out, indent);
   }
@@ -108,18 +74,7 @@ void xmlt::output(std::ostream &out, unsigned indent) const
   out << '<' << '/' << name << '>' << "\n";
 }
 
-/*******************************************************************\
-
-Function: xmlt::escape
-
-  Inputs:
-
- Outputs:
-
- Purpose: escaping for XML elements
-
-\*******************************************************************/
-
+/// escaping for XML elements
 void xmlt::escape(const std::string &s, std::ostream &out)
 {
   for(const auto ch : s)
@@ -137,10 +92,10 @@ void xmlt::escape(const std::string &s, std::ostream &out)
     case '>':
       out << "&gt;";
       break;
-    
+
     case '\r':
       break; // drop!
-    
+
     case '\n':
       out << '\n';
       break;
@@ -148,30 +103,18 @@ void xmlt::escape(const std::string &s, std::ostream &out)
     default:
       // &#0; isn't allowed, but what shall we do?
       if((ch>=0 && ch<' ') || ch==127)
-        out << "&#"+i2string((unsigned char)ch)+";";
+        out << "&#"+std::to_string((unsigned char)ch)+";";
       else
         out << ch;
     }
   }
 }
 
-/*******************************************************************\
-
-Function: xmlt::escape_attribute
-
-  Inputs:
-
- Outputs:
-
- Purpose: escaping for XML attributes, assuming that
-          double quotes " are used consistently,
-          not single quotes
-
-\*******************************************************************/
-
+/// escaping for XML attributes, assuming that double quotes " are used
+/// consistently, not single quotes
 void xmlt::escape_attribute(const std::string &s, std::ostream &out)
 {
-  for(const auto & ch : s)
+  for(const auto ch : s)
   {
     switch(ch)
     {
@@ -194,43 +137,18 @@ void xmlt::escape_attribute(const std::string &s, std::ostream &out)
     default:
       // &#0; isn't allowed, but what shall we do?
       if((ch>=0 && ch<' ') || ch==127)
-        out << "&#"+i2string((unsigned char)ch)+";";
+        out << "&#"+std::to_string((unsigned char)ch)+";";
       else
         out << ch;
     }
   }
 }
 
-/*******************************************************************\
-
-Function: xmlt::do_indent
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::do_indent(std::ostream &out, unsigned indent)
 {
-  for(unsigned i=0; i<indent; i++)
-    out << ' ';
+  out << std::string(indent, ' ');
 }
 
-/*******************************************************************\
-
-Function: xmlt::find
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 xmlt::elementst::const_iterator xmlt::find(const std::string &name) const
 {
   for(elementst::const_iterator it=elements.begin();
@@ -242,18 +160,6 @@ xmlt::elementst::const_iterator xmlt::find(const std::string &name) const
   return elements.end();
 }
 
-/*******************************************************************\
-
-Function: xmlt::find
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 xmlt::elementst::iterator xmlt::find(const std::string &name)
 {
   for(elementst::iterator it=elements.begin();
@@ -265,83 +171,35 @@ xmlt::elementst::iterator xmlt::find(const std::string &name)
   return elements.end();
 }
 
-/*******************************************************************\
-
-Function: xmlt::set_attribute
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::set_attribute(
   const std::string &attribute,
   unsigned value)
 {
-  set_attribute(attribute, i2string(value));
+  set_attribute(attribute, std::to_string(value));
 }
 
-/*******************************************************************\
-
-Function: xmlt::set_attribute
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::set_attribute(
   const std::string &attribute,
   unsigned long value)
 {
-  set_attribute(attribute, i2string(value));
+  set_attribute(attribute, std::to_string(value));
 }
 
-/*******************************************************************\
-
-Function: xmlt::set_attribute
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::set_attribute(
   const std::string &attribute,
   unsigned long long value)
 {
-  set_attribute(attribute, i2string(value));
+  set_attribute(attribute, std::to_string(value));
 }
 
-/*******************************************************************\
-
-Function: xmlt::set_attribute
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
 void xmlt::set_attribute(
   const std::string &attribute,
   const std::string &value)
 {
-  if ((value[0]=='\"' && value[value.size()-1]=='\"') ||
+  if((value[0]=='\"' && value[value.size()-1]=='\"') ||
       (value[0]=='\'' && value[value.size()-1]=='\''))
   {
-    attributes[attribute]=value.substr(1,value.size()-2);
+    attributes[attribute]=value.substr(1, value.size()-2);
   }
   else
   {
@@ -349,18 +207,9 @@ void xmlt::set_attribute(
   }
 }
 
-/*******************************************************************\
-
-Function: xmlt::unescape
-
-  Inputs: a string
-
- Outputs: the unescaped string
-
- Purpose: takes a string and unescapes any xml style escaped symbols
-
-\*******************************************************************/
-
+/// takes a string and unescapes any xml style escaped symbols
+/// \par parameters: a string
+/// \return the unescaped string
 std::string xmlt::unescape(const std::string &str)
 {
   std::string result("");
@@ -379,16 +228,19 @@ std::string xmlt::unescape(const std::string &str)
       while(it!=str.end() && *it!=';')
         tmp+=*it++;
 
-      if(tmp=="gt") result+='>';
-      else if(tmp=="lt") result+='<';
-      else if(tmp=="amp") result+='&';
+      if(tmp=="gt")
+        result+='>';
+      else if(tmp=="lt")
+        result+='<';
+      else if(tmp=="amp")
+        result+='&';
       else if(tmp[0]=='#' && tmp[1]!='x')
       {
         char c=unsafe_string2int(tmp.substr(1, tmp.size()-1));
         result+=c;
       }
       else
-        throw "XML escape code not implemented";
+        throw "XML escape code not implemented"; // NOLINT(readability/throw)
     }
     else
       result+=*it;
