@@ -1,35 +1,44 @@
+/*******************************************************************\
+
+Module: A minimalistic BDD library, following Bryant's original paper
+        and Andersen's lecture notes
+
+Author: Daniel Kroening, kroening@kroening.com
+
+\*******************************************************************/
+
 #include <iostream>
 
+#include <util/format_expr.h>
+
 #include <solvers/miniBDD/miniBDD.h>
 
-using namespace miniBDD;
-
 void test1()
 {
-  mgr mgr;
+  mini_bdd_mgrt mgr;
 
-  BDD x=mgr.Var("x");
-  BDD y=mgr.Var("y");
-  BDD z=mgr.Var("z");
-  BDD f=(x&y&z)|(!x&!y&z);
+  mini_bddt x=mgr.Var("x");
+  mini_bddt y=mgr.Var("y");
+  mini_bddt z=mgr.Var("z");
+  mini_bddt f=(x&y&z)|((!x)&(!y)&z);
   y.clear();
   x.clear();
   z.clear();
 
-  //mgr.DumpDot(std::cout);
+  // mgr.DumpDot(std::cout);
   mgr.DumpTikZ(std::cout);
 }
 
 void test2()
 {
-  mgr mgr;
-  
-  BDD a=mgr.Var("a");
-  BDD b=mgr.Var("b");
-  BDD c=mgr.Var("c");
-  BDD d=mgr.Var("d");
-  
-  BDD final=(a == b) & (c == d);  
+  mini_bdd_mgrt mgr;
+
+  mini_bddt a=mgr.Var("a");
+  mini_bddt b=mgr.Var("b");
+  mini_bddt c=mgr.Var("c");
+  mini_bddt d=mgr.Var("d");
+
+  mini_bddt final=(a==b)&(c==d);
 
   a.clear();
   b.clear();
@@ -41,13 +50,15 @@ void test2()
 
 void test3()
 {
-  mgr mgr;
-  
-  BDD final=mgr.Var("x") & mgr.Var("y");
+  mini_bdd_mgrt mgr;
+
+  mini_bddt final=mgr.Var("x")&mgr.Var("y");
 
   mgr.DumpDot(std::cout);
-  //mgr.DumpTikZ(std::cout);
-  //mgr.DumpTable(std::cout);
+  #if 0
+  mgr.DumpTikZ(std::cout);
+  mgr.DumpTable(std::cout);
+  #endif
 }
 
 #include <langapi/language_util.h>
@@ -62,8 +73,6 @@ void test3()
 
 void test4()
 {
-  register_language(new_ansi_c_language);
-
   symbol_exprt a("a", bool_typet());
   symbol_exprt b("b", bool_typet());
 
@@ -72,12 +81,12 @@ void test4()
   symbol_tablet symbol_table;
   namespacet ns(symbol_table);
 
-  std::cout << from_expr(ns, "", o) << std::endl;
+  std::cout << format(o) << std::endl;
 
   bdd_exprt t(ns);
   t.from_expr(o);
 
-  std::cout << from_expr(ns, "", t.as_expr()) << std::endl;
+  std::cout << format(t.as_expr()) << std::endl;
 }
 
 int main()
